<?php

function verowa_templates_configuration_page() {
	global $wpdb;

	// default values for new Templates
	$arr_template = [
			'template_id' => 0,
			'template_name' => '',
			'info_text' => '',
			'type' => 'eventlist',
			'display_where' => '',
			'header' => '',
			'entry' => '',
			'separator' => '',
			'footer' => ''
		];

	$arr_placeholder = [
			'eventlist' => [
				'current' => [
					'TITLE',
					'EVENT_ID',
					'LAYER_IDS',
					'CATEGORIES',
					'DATE_FROM_8',
					'DATE_FROM_LONG',
					'TIME_MIXED_LONG',
					'ORGANIZER_NAME',
					'COORGANIZER_NAMES',
					'WEEKDAY',
					'DATETIME_LONG',
					'EVENT_DATETIME_TEXT',
					'LOCATION_WITH_ROOM',
					'IMAGE_URL',
					'CALENDAR_EXPORT',
					'SUPSCRIPTION_BUTTON',
					'DETAILS_BUTTON_TEXT'
				],
				'deprecated' =>[
					'EVENT_TITLE',
					'EVENT-CATS',
					'DATE_FROM',
					'EVENT_DATE',
					'EVENT_TIME',
					'LOCATIONS'
				]
			],
			'eventdetails' => [
				'current' => [
					'TITLE',
					'IMAGE_URL',
					'TOPIC',
					'DATETIME_FROM_LONG',
					'LOCATION_WITH_ROOM',
					'WITH_SACRAMENT',
					'SHORT_DESC',
					'LONG_DESC',
					'FILE_LIST',
					'COORGANIZERS',
					'SUBSCRIPTION_INFO',
					'SERVICE_4_PERSONS',
					'COLLECTION',
					'BAPTISM_OFFER',
					'CHILDCARE',
					'CATERING',
					'ORGANIZER'
				],
				'deprecated' =>[
					'EVENT_TITLE',
					'EVENT_DATETIME',
					'LOCATIONS',
					'FILES',
					'COORGANIZER',
					'SUBSCRIPTION',
					'ORGANIST',
					'EVENT_PERSON'
				]
			],
			'personlist' => [
				'current' => [
					'PERSON_ID',
					'IMAGE_URL',
					'PERSON_NAME',
					'FUNCTION_IN_GROUP',
					'SHORT_DESC',
					'PROFESSION',
					'ADDRESS',
					'ZIP_CITY',
					'EMAIL',
					'PHONE'
				],
				'deprecated' =>[]
			],
			'persondetails' => [
				'current' => [
					'NAME',
					'PERSON_NAME',
					'PROFESSION',
					'SHORT_DESC',
					'DESC_TASKS',
					'HAS_PRIVATE_ADDRESS',
					'PRIVATE_STREET',
					'PRIVATE_ZIP_CITY',
					'HAS_BUSINESS_ADDRESS',
					'BUSINESS_STREET',
					'BUSINESS_ZIP_CITY',
					'EMAIL',
					'BUSINESS_PHONE',
					'PRIVATE_PHONE',
					'MOBILE_PHONE',
					'DESC_PERSONAL'
				],
				'deprecated' =>[
					'NAME'
				]
			]
		];

	// settings for template list
	$option = 'per_page';
	$args = [
		'label' => 'Templates',
		'default' => 10,
		'option' => 'Templates_per_page'
	];

	add_screen_option( $option, $args );


	// post will be saved in DB
	if (isset($_REQUEST['btn_save_template']))
	{
		$template_id = 0;

		if($_REQUEST['template_id'] == 0)
		{
			verowa_insert_template_in_db($_POST);
		}
		else
		{
			verowa_update_template_in_db($_POST);
		}
	} else {
		$template_id = isset($_GET['t']) ? intval($_GET['t']) : 0;
	}

	// load template data
	if ($template_id > 0)
	{
		$query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_templates` ' .
			'WHERE `template_id` = ' . $template_id;
		$arr_template = $wpdb->get_results( $query, 'ARRAY_A' )[0];

		// List of placeholders depending on the template
		$str_placeholder_html = '';

		// List of deprecated placeholders depending on the template
		$str_deprecated_placeholder_html = '';

		$str_placeholder_html .= '<div id="verowa_current_placeholder" >';
		foreach ($arr_placeholder[$arr_template['type']]['current'] as $single_placeholder){
			// $str_placeholder_html .= '<button type="button">' . $single_placeholder . '</button>';
			$str_placeholder_html .= '<span>' . $single_placeholder . '</span>';
		}
		$str_placeholder_html .= '</div>';

		$arr_found_deprecated_placeholder = [];
		foreach ($arr_placeholder[$arr_template['type']]['deprecated'] as $single_placeholder){
			if( strpos($arr_template['entry'], '{' . $single_placeholder . '}') !== false){
				$arr_found_deprecated_placeholder [] = $single_placeholder;
			}
		}

		if(count($arr_found_deprecated_placeholder) > 0) {
			$str_deprecated_placeholder_html = '<div id="verowa_deprecated_placeholder" >' .
				'<span class="label" >Folgende Platzhalter sind veraltet</span> <span class="placeholders">' . implode(', ', $arr_found_deprecated_placeholder)  .
				'</span></div>';
		}
	}

	if ( isset($_GET['n']) || $template_id > 0 )
	{
		$show_edit_form = true;
		$show_overview = false;
	}
	else
	{
		$show_edit_form = false;
		$show_overview = true;
	}

	$obj_templates = new Verowa_Templates_List();

?>
<div class="wrap">
	<h2>Verowa Templates</h2>
	<?php
	if ($show_overview){
	?>
	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">
			<div id="post-body-content">
				<a href="options-general.php?page=verowa-options-templates&n=1">add new</a>
				<div class="meta-box-sortables ui-sortable">
					<form method="post">
						<?php
							$obj_templates->prepare_items();
							$obj_templates->display(); 
						?>
					</form>
				</div>
			</div>
		</div>
		<br class="clear" />
	</div>
	<?php 
	}

	if ( $show_edit_form )
	{
	?>
	<form id="template_edit_form" action="?page=verowa-options-templates" method="post" class="postbox verowa_form">
		<input type="hidden" name="template_id" value="<?= $arr_template['template_id']; ?>" />
		<div class="row">
			<label>Name</label>
			<input type="text" name="template_name" value="<?= $arr_template['template_name']; ?>" />
		</div>
		<div class="row">
			<label>Info-Text</label>
			<input type="text" name="info_text" value="<?= $arr_template['info_text']; ?>" />
		</div>
		<div class="row">
			<label>Type</label>
			<?php
				$arr_types = [
					'eventlist' => 'Eventdetails',
					'eventdetails' => 'Eventlist',
					'personlist' => 'Personlist',
					'persondetails' => 'Persondetails'
					];
				verowa_show_dropdown('type', $arr_types, $arr_template['type']);
			?>
		</div>
		<div class="row">
			<label>Anzeige Einschränkung</label>
			<?php
				$arr_display_where = [
					'' => 'keine',
					'content' => 'Inhalt',
					'widget' => 'Widget',
					];
				verowa_show_dropdown('display_where', $arr_display_where, $arr_template['display_where']);
			?>
		</div>
		<div class="row">
			<label>Header</label>
			<textarea id="verowa_header" name="verowa_header"><?= $arr_template['header']; ?></textarea>
		</div>
		<div class="row">
			<label>Entry</label>
			<?= $str_deprecated_placeholder_html ?>
			<textarea id="verowa_entry" name="verowa_entry"><?= $arr_template['entry']; ?></textarea>
			<?= $str_placeholder_html ?>			
		</div>
		<div class="row">
			<label>Separator</label>
			<textarea id="verowa_separator" name="verowa_separator"><?= $arr_template['separator']; ?></textarea>
		</div>
		<div class="row">
			<label>Footer</label>
			<textarea id="verowa_footer" name="verowa_footer"><?= $arr_template['footer']; ?></textarea>
		</div>
		<div class="row">
			<input type="button" class="button button-secondary button-large" id="btn_save_template"
				   onclick="location.href = '?page=verowa-options-templates';" value="abbrechen" />
			<input type="submit" class="button button-primary button-large" id="btn_save_template" name="btn_save_template" value="speichern" />
		</div>
	</form>
	<?php  
	}
	?>
</div>
<script type="text/javascript">
	// Load Code Mirror
	var editor_entry;

	jQuery(document).ready(function ($) {
		wp.codeEditor.initialize($('#verowa_header'), cm_settings);
		editor_entry = wp.codeEditor.initialize($('#verowa_entry'), cm_settings);
		wp.codeEditor.initialize($('#verowa_separator'), cm_settings);
		wp.codeEditor.initialize($('#verowa_footer'), cm_settings);

		//jQuery("#verowa_current_placeholder span").click(function () {
		//	alert(jQuery(this).text());
		//});
		
	});

</script>
<?php
}

/**
 *
 *
 * @param array $arr_template
 *
 * @return void;
 */
function verowa_insert_template_in_db($arr_template){
	global $wpdb;

	$str_template_tablename = $wpdb->prefix . 'verowa_templates';
		$arr_template_data_formats = [ '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s'];

		$arr_template_data = [
			'template_name' => $arr_template['template_name'],
			'info_text' => $arr_template['info_text'],
			'type' => $arr_template['type'],
			'display_where' => $arr_template['display_where'],
			'header' => $arr_template['verowa_header'],
			'entry' => $arr_template['verowa_entry'],
			'separator' => $arr_template['verowa_separator'],
			'footer' => $arr_template['verowa_footer'],
		];

		$wpdb->insert(
			$str_template_tablename,
			$arr_template_data,
			$arr_template_data_formats
		);
}



/**
 *
 * @param array $arr_template
 *
 * @return void
 *
 */
function verowa_update_template_in_db($arr_template){
	global $wpdb;

	$str_template_tablename = $wpdb->prefix . 'verowa_templates';
		$arr_template_data_formats = [ '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s'];
		$arr_template_where_formats = [ '%d' ];

		$arr_template_data = [
			'template_name' => $arr_template['template_name'],
			'info_text' => $arr_template['info_text'],
			'type' => $arr_template['type'],
			'display_where' => $arr_template['display_where'],
			'header' => stripcslashes($arr_template['verowa_header']),
			'entry' => stripcslashes($arr_template['verowa_entry']),
			'separator' => stripcslashes($arr_template['verowa_separator']),
			'footer' => stripcslashes($arr_template['verowa_footer']),
		];

		$wpdb->update(
			$str_template_tablename,
			$arr_template_data,
			array(
				'template_id' => $arr_template['template_id']
			),
			$arr_template_data_formats,
			$arr_template_where_formats
		);
}

/**
 * Auxiliary function to avoid dependency on the subscription and rental forms.
 * 
 *
 * @param string $str_name
 * @param array $arr_options
 * @param string $str_ff_value
 */
function verowa_show_dropdown($str_name, $arr_options, $str_ff_value)
{
	echo '<select name="' . $str_name .'">';

	foreach($arr_options as $str_value => $str_diplay) {
		$str_selected = $str_value == $str_ff_value ?  ' selected ' : '';
		echo '<option value="' . $str_value . '" ' . $str_selected . '>' . $str_diplay . '</option>';
	}

	echo '</select>';
}