<?php
/**
 * Agenda-Shortcode, um eine Agenda dynamisch anzuzeigen.
 */

add_shortcode( 'verowa_dynamic_agenda', 'verowa_dynamic_agenda' );

function verowa_dynamic_agenda() {
	global $wp_query;
	ob_start();

	$int_return_event_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

	$arr_list_ids = [];
	$date10_displays_from = isset($_GET['date']) ?
		verowa_date8_to_date10ch($_GET['date']) : current_time( 'd.m.Y' );
	$int_events_to_load = get_option( 'verowa_agenda_batch_size', 50 );

	// Benutzer kommt von der Agenda zurück
	$arr_verowa_agenda_filter = key_exists('verowa_agenda_filter', $_SESSION) ? $_SESSION['verowa_agenda_filter'] : [];
	$arr_list_ids = key_exists('arr_list_ids', $arr_verowa_agenda_filter) ? $arr_verowa_agenda_filter['arr_list_ids'] : [];

	if( key_exists('date8_displays_from', $arr_verowa_agenda_filter) )
	{
		$date10_displays_from = verowa_date8_to_date10ch($arr_verowa_agenda_filter['date8_displays_from']);
	}

	// When returning from an event, it must be ensured that it is loaded.
	$int_events_to_load = isset($_SESSION['verowa_agenda_current_batch']) ?
		$_SESSION['verowa_agenda_current_batch'] * get_option( 'verowa_agenda_batch_size', 50 ) :
		get_option( 'verowa_agenda_batch_size', 50 );

	$date_obj_from = DateTime::createFromFormat('d.m.Y', $date10_displays_from);

	// We get it all from our cache because this process with the filter takes too long
	$arr_verowa_groups = json_decode( get_option( 'verowa_dynamic_agenda_filter', false ), true);

	echo '<section id="verowa_event_filters" class="verowa-filter">';

	$dropdown_count = 1;
	$nb_dropdowns = get_option( 'how_many_verowa_dropdowns', false );

	while ( $dropdown_count <= $nb_dropdowns ) {
		$str_html = '<div class="row">';
		$filter_name = get_option( 'verowa_dropdown_' . $dropdown_count . '_title', true );
		$str_html .= '<div class="column"><label>' . $filter_name . ':</label></div>' .
			'<ul class="column list_filter option-set" data-filter-group="' . $filter_name . '">' .
			'<li>[[ALL_BUTTON]]</li>';
		$filter_options = explode( ', ', get_option( 'verowa_dropdown_' . $dropdown_count, true ) );
		$has_selected_buttons = false;
		foreach ( $filter_options as $group_id ) {
			$group_key = array_search( $group_id, array_column( $arr_verowa_groups, 'list_id' ) );
			$str_selected = '';
			if( in_array($arr_verowa_groups[$group_key]['list_id'], $arr_list_ids) )
			{
				$str_selected .= ' selected';
				$has_selected_buttons = true;
			}

			$str_html .= '<li><a class="filter-button' . $str_selected . '" href="#filter-' . $filter_name .
				'-' . preg_replace( '/[^a-zA-Z0-9]+/', '', $arr_verowa_groups[$group_key]['name']) . '"' .
				' data-filter-value=".events-' . $arr_verowa_groups[$group_key]['list_id'] . '">' .
				$arr_verowa_groups[$group_key]['name'] . '</a></li>';
		}

		// If a filter was selected, the all button should not be selected
		$str_selected_all = 'selected ';
		if($has_selected_buttons)
		{
			$str_selected_all = '';
			$has_selected_buttons = false;
		}

		$str_all_button = '<a class="filter-button ' . $str_selected_all . 'no-filter" data-filter-value="">Alle</a>';
		$str_html = str_replace('[[ALL_BUTTON]]', $str_all_button, $str_html);

		$str_html .= '</ul></div>'; // row
		echo $str_html;
		$dropdown_count++;
	}

	// Datepicker von früher
	echo '<div class="row date-row">' .
		'<div class="date_filter column">' .
		'<label for="verowa_datum">' . __( 'Show from', 'verowa-connect' ) . ':</label>' .
		'</div>' .
		'<div class="date_filter_picker column">' .
		'<input type="text" name="verowa_datum" value="' . $date10_displays_from . '"' .
	' id="verowa_connect_datepicker" />' .
		'</div>' .
		'<div class="verowa_agenda_filter_reset_wrapper" >' .
		'<a href="javascript:verowa_agenda_filter_reset();" id="verowa-agenda-filter-reset" >Filter zurücksetzen</a>' .
		'</div></div>' .
		'</section>'; // row


	$arr_events = verowa_get_agenda_events_from_db( '', implode(',', $arr_list_ids), $int_events_to_load, 0, $date_obj_from);
	$int_agenda_offset = count($arr_events);

	// Spezialfall für vorgewählte Kategorien
	echo '<input type="hidden" id="dynamic-agenda-cat" value="' . ( $_GET['cat'] ?? 0 ) . '"/>';

	echo '<div class="event_list_wrapper grid event_list_dynamic_agenda">';

	foreach ( $arr_events as $arr_single_event ) {
		echo show_single_verowa_event( $arr_single_event );
	}

	echo '</div>';

	$str_no_event_style = count($arr_events) !== 0 ? 'style="display:none;"' : '';

	// Meldung vorbereiten, falls es keine Treffer gibt
	echo '<div class="event_list_item" ' . $str_no_event_style . ' id="no-events-box">' .
		'<i>' . __( 'Unfortunately no events were found for your criteria. Please change your settings.',
		'verowa-connect' ) . '</i>' .
		'</div>';

	echo '<div class="event_list_item" style="display:none;text-align: center;" id="infinite-scroll-loader">' .
	'<img src="/wp-content/plugins/verowa-connect/images/ajax-loader.gif" />' .
	'</div>';

	echo '<script>
			g_current_agenda_offset = ' . $int_agenda_offset . ';
			bind_infinite_scroll();
			scroll_to_event(' . $int_return_event_id . ');
		</script>';

	return ob_get_clean();
}


?>