<?php
/**
 * Agenda-Shortcode, um eine Agenda auf jeder beliebigen Seite anzuzeigen.
 * Es ist möglich, eine voreingestellte Verowa-Liste als Attribut mit zu übergeben, z.B. [verowa_agenda liste="9"],
 * ausserdem kann man die max. Anzahl mitgeben, z.B. [verowa_agenda anzahl="5"]
 */
 
add_shortcode( 'verowa_agenda', 'verowa_agenda' );

function verowa_agenda( $atts ) {
	// falls nicht anders gesetzt, ist auch hier die Standardanzahl für Veranstaltungen pro Seite 10;
	// Seite werden bei diesem Shortcode vorrausgesetzt.
	$atts = shortcode_atts(
		array(
			'anzahl' => 10,
			'liste' => '',
		),
		$atts,
		'verowa_agenda'
	);
	
	ob_start();

	// statt einer einzigen ID können mehrere als CSV-String übergeben werden
	$str_listen_voreingestellt = $atts['liste'];

	$page_offset = abs( intval( $_GET['event_page'] ) );
	$str_listen_ids = '';

	if ( isset( $_GET['list_targets'] ) ) {
		$arr_listen_ids = $_GET['list_targets'];

		// ungültige (leere) IDs entfernen, die gültigen wieder zusammensetzen
		foreach ( $arr_listen_ids as $listen_id ) {
			if ( intval( $listen_id ) > 0 ) {
				$str_listen_ids .= $listen_id . ',';
			}
		}

		$str_listen_ids = rtrim( $str_listen_ids, ',' );
	} else {
		if ( '' != $str_listen_voreingestellt ) {
			$str_listen_ids = $str_listen_voreingestellt;
		}
	}

	// WICHTIG: falls wir keine ID haben, übergeben wir eine Leerstelle (muss in Form von "%20" sein),
	// weil sonst die Listen-Abfrage über die API nicht funktioniert
	if ( $str_listen_ids == '' ) {
		$str_listen_ids = '%20';
	}

	$page_offset *= $atts['anzahl'];

	// neue Funktion, um herauszufinden, ob das Datum gesetzt ist oder nicht
	if ( isset( $_GET['verowa_datum'] ) ) {
		$selected_day = new DateTime( $_GET['verowa_datum'] );
		$show_events_from_date = $selected_day->format( 'Ymd' );
	} else {
		$show_events_from_date = current_time( 'Ymd' );
	}

	$verowa_call_string = $str_listen_ids . '/' .  $page_offset . '/' . $atts['anzahl'];
	$arr_verowa_events = verowa_api_call( 'geteventsbylist', $verowa_call_string, true );
	$number_of_all_entries = $arr_verowa_events['total_events_nbr'];
	
	if ( $number_of_all_entries > $atts['anzahl'] ) {
		$html_seitenzahlen_zeile = verowa_seitenzahl_anzeige(
			$number_of_all_entries,
			$atts['anzahl'],
			$str_listen_ids
		);

		echo '<div class="events_page">' . $html_seitenzahlen_zeile . '</div>';
	}
	
	$str_show_to_time = get_option( 'show-to-time', false );

	if ( $number_of_all_entries > 0 ) {
         echo '<div class="event_list_wrapper">';
    }

	foreach ( $arr_verowa_events['events'] as $arr_verowa_single_event ) {
		// Der Link zur richtigen Veranstaltung (Permalink Force) > zur Detail-Seite
		echo '<div class="event_list_item"><a href="' . get_bloginfo( 'url' ) . '/veranstaltung/' . 
			$arr_verowa_single_event['event_id'] . '">';
		$verowa_date_from = new DateTime( $arr_verowa_single_event['date_from'] );
		$verowa_date_to = new DateTime( $arr_verowa_single_event['date_to'] );

		// Es wird überprüft, ob die Vernstaltung mehrtägig ist
		if ( ( $verowa_date_to->format( "U" ) - $verowa_date_from->format( "U" ) ) > 86400 ) {
			$date_format_string_from = 'l, j. F';
			$date_format_string_to = 'l, j. F Y';
			
			if ( date_i18n( 'FY', $verowa_date_from->format( 'U' ) ) ==
				date_i18n( 'FY', $verowa_date_to->format( 'U' ) ) ) {

				$date_format_string_from = 'l, j.';
			}

			echo '<div class="event_date_text">' . 
				date_i18n( $date_format_string_from, $verowa_date_from->format( 'U' ) ) . ', ' .
				_x( 'to', 'temporal', 'verowa-connect' ) . ' ' .
				date_i18n( $date_format_string_to, $verowa_date_to->format( 'U' ) ) . '</div>';
		}

		// falls die Bis-Zeit gezeigt werden soll, können wir den von Verowa
		// vorformatierten String verwenden; sonst müssen wir das Von-Datum selbst
		// zusammenbauen
		elseif ( get_option( 'show-to-time', false) == 'on' ) {
			echo '<div class="event_date_text">' . $arr_verowa_single_event['date_text'] . '</div>';
		} else {
			echo '<div class="event_date_text">' . date_i18n( 'l, j. F Y, G.i', $verowa_date_from->format( 'U' ) ) .
				' ' . __( 'o’clock', 'verowa-connect' ) . '</div>';
		}

		echo '<div class="event_title">' . $arr_verowa_single_event['title'] . '</div>';
		
		// Thema zeigen, falls vorhanden
		if ( '' != $arr_verowa_single_event['topic'] ) {
			echo '<div class="event_topic">' . $arr_verowa_single_event['topic'] . '</div>';
		}

		// 1. Raum ausgeben (den Link dazu gibts nur auf der Detailseite)
		echo '<div class="event_location">';

		if ( $arr_verowa_single_event['room']['location_name'] == $arr_verowa_single_event['room']['name'] ) {
			echo $arr_verowa_single_event['room']['name'];
		} else {
			if ( '' != $arr_verowa_single_event['room']['location_name'] &&
				'' != $arr_verowa_single_event['room']['name'] ) {

				echo $arr_verowa_single_event['room']['location_name'] . ', ' .
					$arr_verowa_single_event['room']['name'];

			} elseif ( '' != $arr_verowa_single_event['room']['location_name'] ) {
				echo $arr_verowa_single_event['room']['location_name'];
			} else {
				echo $arr_verowa_single_event['room']['name'];
			}
		}
			
		echo '</div></a></div>';
	}

	
	if ( $number_of_all_entries > 0 ) {
		echo '</div>';
	} else {
		echo '<div class="event_list_wrapper"><b>' . 
			__( 'Unfortunately no events were found for your criteria. Please change your settings.', 'verowa-connect' ) . 
			'</b></div>';
    }
	
	if ( $number_of_all_entries > $atts['anzahl'] ) {
		echo '<div class="events_page">' . $html_seitenzahlen_zeile . '</div>';
	}
	
	return ob_get_clean();
}

// Übernimmt die Seitenzahl-Anzeige der obigen Funktion
function verowa_seitenzahl_anzeige( $number_of_all_entries, $anzahl_pro_seite, $str_listen_ids ) {
	$get_zielliste_parameters = explode( ',' ,  $str_listen_ids );
	
	foreach ( $get_zielliste_parameters as $listennummer ) {
		$str_angezeigte_ziel_listen .= '&list_targets[]=' . $listennummer;
	}
		
	$seitenzahl_content .= '<div class="verowa-list-pages">' . __( 'Pages', 'verowa-connect' ) . ': ';

	$aktuelle_seitenzahl = $_GET['event_page'] + 1;

	$maximal_angezeigte_seiten = 10;
	$letzte_seitenzahl = ceil( $number_of_all_entries / $anzahl_pro_seite ) + 1;
	
	// die aktuelle Seite soll in der Seitenzahlenleiste etwa in der Mitte sein
	$seitenzahl_ganz_links = $aktuelle_seitenzahl - floor( ( $maximal_angezeigte_seiten - 1 ) / 2 );
	
	if ($seitenzahl_ganz_links < 1) {
		$seitenzahl_ganz_links = 1;
	}

	// provisorisch setzen wir die Seitenzahl ganz rechts auf unseren "Wunschwert"
	$seitenzahl_ganz_rechts = $seitenzahl_ganz_links + $maximal_angezeigte_seiten - 1;

	// falls es gar nicht so viele Seiten hat, nehmen wir das Maximum
	if ( $seitenzahl_ganz_rechts > $letzte_seitenzahl ) {
		$seitenzahl_ganz_rechts = $letzte_seitenzahl;

		// nun haben wir rechts abgeschnitten und können dafür evtl. links etwas anhängen
		$seitenzahl_ganz_links = $seitenzahl_ganz_rechts - $maximal_angezeigte_seiten  + 1;

		// evtl. hat es aber gar nicht $maximal_angezeigte_seiten, dann gehen wir einfach von 1 aus
		if ( $seitenzahl_ganz_links < 1 ) {
			$seitenzahl_ganz_links = 1;
		}
	}

	if ( isset( $_GET['verowa_datum'] ) ) {
		$get_parameter = '&verowa_datum=' . $_GET['verowa_datum'] . $str_angezeigte_ziel_listen;
	} else {
		$get_parameter = $str_angezeigte_ziel_listen;
	}

	// Link zur allerersten Seite
	$seitenzahl_content .= '<a href="?event_page=0' . $get_parameter . '" >&laquo;</a> ';

	// die verlinkten Seitenzahlen
	for ( $i = $seitenzahl_ganz_links; $i < $seitenzahl_ganz_rechts; $i++ ) {

		// die aktuelle Seitenzahl wird speziell formatiert
		if ( $i == $aktuelle_seitenzahl ) {
			$html_code_class = ' style="" class="current_page_item" ';
		} else {
			$html_code_class = '';
		}

		$seitenzahl_content .= '<a href="?event_page=' . ($i - 1) .
			$get_parameter . '" ' .
			$html_code_class . '>' . $i .  '</a> ';
	}

	// Link zur allerletzten Seite
	$seitenzahl_content .= '<a href="?event_page=' . ( $letzte_seitenzahl - 2 ) . 
		$get_parameter . $str_angezeigte_ziel_listen . '" >&raquo;</a> ';

	$seitenzahl_content .= '</div>';

	return $seitenzahl_content;
}
?>