<?php
/**
 * Fügt eine sogenannte Custom-Meta-Box hinzu, die für die Listen-Zuordnung benötigt wird.
 *
 */
 
add_action( 'add_meta_boxes', 'verowa_list_assign_add_meta_box' );
add_action( 'save_post', 'verowa_list_assign_save_meta_box_data' );
add_filter( 'the_content','add_verowa_list_if_selected', 8 );

function verowa_list_assign_add_meta_box() {
	$screens = array(
		'post',
		'page'
	);

	foreach ( $screens as $screen ) {
		add_meta_box( 'verowa_list_assign_sectionid', __( 'Event list mapping', 
			'verowa-connect' ), 'verowa_list_assign_meta_box_callback', $screen );
	}
}


// der Callback von der oben genannten Funktion
function verowa_list_assign_meta_box_callback( $post ) {
	// Add a nonce field so we can check for it later.
	wp_nonce_field( 'verowa_list_assign_meta_box', 'verowa_list_assign_meta_box_nonce' );

	echo '<table><tr><td>';

	$wp_verowa_listengruppe = get_option( 'verowa_wordpress_listengruppe', true );
	$arr_group_data = verowa_api_call( 'getlistsbygroup', $wp_verowa_listengruppe, true );
	$int_list_id = get_post_meta( $post->ID, '_verowa_list_assign', true );
	$max_events =  get_post_meta( $post->ID, '_max_events', true );
	$max_events_days =  get_post_meta( $post->ID, '_max_events_days', true );
	$str_list_title = get_post_meta( $post->ID, 'verowa_list_title', true );
	$int_eventlist_selected_template = get_post_meta( $post->ID, 'verowa_eventlist_template', true );

	echo __( 'List', 'verowa-connect' ) . ':</td>' .
		'<td><select id="pg" name="listen"><option value="0"> </option>';
	
	foreach ( $arr_group_data as $arr_group_single_data ) {
		echo '<option value="' . $arr_group_single_data['list_id'] . '"';

		if ( $int_list_id == $arr_group_single_data['list_id'] ) {
			echo ' selected';
		}

		echo '>' . $arr_group_single_data['list_id'] . ' ' . $arr_group_single_data['name'] . '</option>';
	}

	echo '</select></td></tr><tr>';
	
	if ( function_exists( 'verowa_layers_dropdown' ) ) {
		echo '<td>' . __( 'Layer', 'verowa-connect' ) . ':' . '</td>' .
			'<td>';
		verowa_layers_dropdown( $post->ID );
		echo '</td>';
	}
	
	echo '</tr>';
	
	// Neue Sektion für die Direktwahl einer Zielgruppe
	$target_groups = verowa_api_call( 'gettargetgroups', '', false );
	
	// Option
	$int_target_group_id = get_post_meta( $post->ID, '_verowa_target_group_assign', true );

	echo '<tr><td>' . __( 'Target groups / regions', 'verowa-connect' ) . ':</td>' .
		'<td><select name="target_groups"><option value="0"> </option>';

	foreach ( $target_groups as $target_group ) {
		echo '<option value="' . $target_group['group_id'] . '"';

		if ( $int_target_group_id == $target_group['group_id']) echo ' selected';

		echo '>' . $target_group['group_id'] . ' ' . $target_group['longname'] . '</option>';
	}

	echo '</select></td></tr>';

	// max. Tage im Voraus
	echo '<tr><td>' . __( 'max. Number', 'verowa-connect' ) . '</td>' . 
		'<td><input style="width: 20%;" type="number" value="' . $max_events . '" name="max_events" /></td></tr>';
	
	// max. Anzahl
	echo '<tr><td>' . __( 'max. days in advance', 'verowa-connect' ) . '</td>' . 
		'<td><input style="width: 20%;" type="number" value="' . $max_events_days . '" name="max_events_days" /></td></tr>';

	// Überschrift über der Liste
	echo '<tr><td>' . __( 'Caption', 'verowa-connect' ) . '</td>' . 
		'<td><input style="width: 70%;" type="text" name="verowa_list_title" value="' . $str_list_title . '" /></td></tr>';

	// List Template
	echo '<tr><td>' . __( 'Template', 'verowa-connect' ) . '</td>' . 
		'<td>' . verowa_show_template_dropdown( 'eventlist', $int_eventlist_selected_template ) . '</td></tr>';
		
	echo '</table>';
}



/**
 * Die Daten der oben erzeugten Metabox werden abgespeichert.
 * Da das zu 50% aus WP-eigenem Code besteht, werden die Original-Kommentare behalten.
 *
 * @param int     $post_id The ID of the post being saved.
 */

function verowa_list_assign_save_meta_box_data( $post_id ) {
	/*
	* We need to verify this came from our screen and with proper authorization,
	* because the save_post action can be triggered at other times.
	*/

	// Check if our nonce is set.
	if ( !isset( $_POST['verowa_list_assign_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( !wp_verify_nonce( $_POST['verowa_list_assign_meta_box_nonce'], 'verowa_list_assign_meta_box' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) ) {
			return;
		}
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */

	// Make sure that it is set.
	if ( !isset( $_POST['listen'] ) ) {
		return;
	}

	// Sanitize user input.
	$verowa_list_assign = sanitize_text_field( $_POST['listen'] );
	$verowa_layer_assign = sanitize_text_field( $_POST['bereiche'] );
	$verowa_tg_assign = sanitize_text_field( $_POST['target_groups'] );
	$max_events = intval( $_POST['max_events'] );
	$max_events_days = intval( $_POST['max_events_days'] );
	$str_verowa_list_title = sanitize_text_field( $_POST['verowa_list_title'] );

	// Update the meta field in the database.
	update_post_meta( $post_id, '_verowa_list_assign', $verowa_list_assign );
	update_post_meta( $post_id, '_verowa_layer_assign', $verowa_layer_assign );
	update_post_meta( $post_id, '_verowa_target_group_assign', $verowa_tg_assign );
	update_post_meta( $post_id, '_max_events', $max_events );
	update_post_meta( $post_id, '_max_events_days', $max_events_days );
	update_post_meta( $post_id, 'verowa_list_title', $str_verowa_list_title );

	// Eventlist Templates
	if ( isset( $_POST['verowa_select_template_eventlist'] ) ) {
		update_post_meta( $post_id, 'verowa_eventlist_template', intval( $_POST['verowa_select_template_eventlist'] ) );
	}
}



function add_verowa_list_if_selected( $content ) {
	global $post, $wp_query;
	
	$int_list_id = get_post_meta( $post->ID, '_verowa_list_assign', true );
	$int_layer_id = get_post_meta( $post->ID, '_verowa_layer_assign', true );
	$int_target_group_id = get_post_meta( $post->ID, '_verowa_target_group_assign', true );
	$int_max = get_post_meta( $post->ID,'_max_events', true );
	$int_max_days = get_post_meta( $post->ID,'_max_events_days', true );
	$str_list_title = get_post_meta( $post->ID, 'verowa_list_title', true );
	$str_extra_vars = '';

	$int_eventlist_template = intval( get_post_meta( $post->ID, 'verowa_eventlist_template', true ) );

	if ( $int_eventlist_template == 0 ) {
		$int_eventlist_template = intval( get_option( 'verowa_default_eventlist_template' ) );
	}

	$arr_template_in_content = verowa_get_template( $int_eventlist_template, '', 'content' );

	if ( count( $arr_template_in_content ) > 0 ) {
		// max events und max days verarbeiten
		if ( $int_max != 0 ) {
			$str_extra_vars .= ' pro-seite=' . $int_max . ' max=' . $int_max . ' ';
			
			if ( $int_max_days != 0 ) {
				$str_extra_vars .= 'max_days=' . $int_max_days . ' ';
			}
		}
	
		// Überschrift mitgeben
		if ( $str_list_title != '' ) {
			$str_extra_vars .= 'title="' . $str_list_title . '" ';
		}
	
		if ( $int_list_id > 0 && !$wp_query->is_search() ) {
			$content .=  '[verowa_event_list id=' . $int_list_id . ' ' . $str_extra_vars . ']';
		}
	
		if ( $int_layer_id > 0 && !$wp_query->is_search() )	{
			$content .= '[verowa_event_list layer_id=' . $int_layer_id . ' ' . $str_extra_vars . ']';
		}
	
		if ( $int_target_group_id > 0 && !$wp_query->is_search() ) {
			$content .= '[verowa_event_list target_group=' . $int_target_group_id . ' ' . $str_extra_vars . ']';
		}
	}

	return $content;
}
?>