<?php
/**
 * Generiert das Widget, dass für die Anzeige von zugeordneten Personen benötigt wird.
 * Die Logik der Anzeige wird aber in verowa-show-persons-shortcode.php festgelegt.
 * 
 */
function register_verowa_Eventlist_widget() {
	register_widget( 'verowa_Eventlist_Widget' );
}

add_action( 'widgets_init', 'register_verowa_Eventlist_widget' );

// Widget Klasse
class verowa_Eventlist_Widget extends WP_Widget {
	function __construct() {
		parent::__construct(
			'verowa_Eventlist_Widget', // Base ID
			__( 'Verowa: Show Events', 'verowa-connect' ), // Name
			array(
				'description' => __( 'This widget shows Events from Verowa.', 'verowa-connect' ) ,
			) // Args
		);
	}



	public function widget( $args, $instance ) {
		// Widget wird nicht angezeigt, wenn Shortcode verwendet wird oder es keine Person enthält
		global $post, $wpdb, $wp_query;
	
		$str_eventlist_shortcode = '';

		// Get the template id and the template for the Eventlist 
		$int_eventlist_template_id = intval( get_post_meta( $post->ID, 'verowa_eventlist_template', true ) );

		if ( $int_eventlist_template_id == 0 ) {
			$int_eventlist_template_id = intval( get_option( 'verowa_default_eventlist_template' ) );
		}

		$arr_eventlist_template = verowa_get_template( $int_eventlist_template_id, '', 'widget' );
		
		//echo '<pre>' . $arr_eventlist_template . '</pre>';
		// We only show the eventlists if a template with type "widget" ist selected
		if ( is_array( $arr_eventlist_template ) && count( $arr_eventlist_template ) > 0 ) {
			$int_list_id = get_post_meta( $post->ID, '_verowa_list_assign', true );
			$int_layer_id = get_post_meta( $post->ID, '_verowa_layer_assign', true );
			$int_target_group_id = get_post_meta( $post->ID, '_verowa_target_group_assign', true );
			$int_max = get_post_meta( $post->ID,'_max_events', true );
			$int_max_days = get_post_meta( $post->ID,'_max_events_days', true );
			$str_list_title = get_post_meta( $post->ID, 'verowa_list_title', true );
			$str_extra_vars = '';
		
			// max events und max days verarbeiten
			if ( $int_max != 0 ) {
				$str_extra_vars .= ' pro-seite=' . $int_max . ' max=' . $int_max . ' ';
				
				if ( $int_max_days != 0 ) {
					$str_extra_vars .= 'max_days=' . $int_max_days . ' ';
				}
			}
		
			// Überschrift mitgeben
			if ( $str_list_title != '' ) {
				$str_extra_vars .= 'title="' . $str_list_title . '" ';
			}
		
			if ( $int_list_id > 0 && !$wp_query->is_search() ) {
				$str_eventlist_shortcode .= '[verowa_event_list id=' . $int_list_id . ' ' . $str_extra_vars . ' ' . 
					'template_id=' . $int_eventlist_template_id . ']';
			}
		
			if ( $int_layer_id > 0 && !$wp_query->is_search() )	{
				$str_eventlist_shortcode .= '[verowa_event_list layer_id=' . $int_layer_id . ' ' . $str_extra_vars . ' ' . 
				'template_id=' . $int_eventlist_template_id . ']';
			}
		
			if ( $int_target_group_id > 0 && !$wp_query->is_search() ) {
				$str_eventlist_shortcode .= '[verowa_event_list target_group=' . $int_target_group_id . ' ' . 
				$str_extra_vars . ' ' . 'template_id=' . $int_eventlist_template_id . ']';
			}
		}

		if ( '' != $str_eventlist_shortcode ) {
			echo $args['before_widget'];

			if ( !empty( $instance['title'] ) ) {
				echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
			}

			echo do_shortcode( $str_eventlist_shortcode );

			echo $args['after_widget'];
		}
	}

	public function form( $instance ) {
		if ( !empty( $instance['title'] ) ) {
			$title = $instance['title'];
		}

		echo '<p><label for="' . $this->get_field_id( 'title' ) . '">' .
			__( 'Title', 'verowa-connect' ) . ':</label>'.
			'<input class="widefat" id="' . $this->get_field_id( 'title' ) . '" ' .
			'name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '"></p>';
	}
	
	public function update( $new_instance, $dummy ) {
		$instance = array();
		
		if ( !empty( $new_instance['title'] ) ) {
			$instance['title'] = strip_tags( $new_instance['title'] );
		} else {
			$instance['title'] = '';
		}
		
		return $instance;
	}
}