<?php


/**
 * get all layers in an array from the API
 *
 * @return mixed
 */
function verowa_get_layers_array() {
    return verowa_api_call( 'getlayers', '', true);
}



// helper function to insert post
// adds the layer shortcode to the content
// if content is present, we insert the content, used for the parent pages
function verowa_insert_layer_page( $layer, $page_parent, $content = '' ) {
	$post_content = $content != '' ? $content : '';

    $post_args =  array(
        'post_title'   => $layer['name'],
        'post_content' => $post_content,
        'post_status'  => 'publish',
        'post_type'    => 'page',
        'post_parent'  => $page_parent,
        'post_author'  => get_current_user_id(),
        'meta_input' => array(
            '_verowa_layer_assign' => $layer['layer_id'],
			)
        );

    $recently_inserted_post = wp_insert_post( $post_args );

    return $recently_inserted_post;
}



// helper function to update post
// just id and content, no scrubs
function verowa_update_layer_page( $id, $content = '' ) {
    if ( $content != '' ) {
        $post_content = $content;
        $post_args =  array(
            'ID'   => $id,
            'post_content' => $post_content,
        );

        wp_update_post( $post_args );
    }
}



/**
 * Determines the child layer IDs
 *
 * @param int $parent_layer_id
 * @return array
 */
function verowa_layer_get_children( $parent_layer_id ) {
    $layers_array = verowa_get_layers_array();
    $result = array();

    foreach ( $layers_array as $layer ) {
		if ( $layer['parent_id'] == $parent_layer_id ) {
            $result[] = $layer;
        }
    }

    return $result;
}



/**
 *
 * @param array $layers_array
 * @param id $parent_page_id
 *
 * @return array
 */
function verowa_create_layer_pages( $layers_array, $parent_page_id = 0 ) {
    global $already_created_layer_ids;

    // an Empty array for the child of childs
    $created_page_ids_of_children = array();

    foreach ( $layers_array as $layer ) {
        // Only do it if not in already created Pages
        if ( !in_array( $layer['layer_id'], $already_created_layer_ids ) ) {
            $layer_children = verowa_layer_get_children( $layer['layer_id'] );

            if ( count( $layer_children ) > 0 ) {
                // insert the parent page for this Layer
                $parent_page_of_children = verowa_insert_layer_page( $layer, $parent_page_id, '[verowa_sub_targets]' );
				$already_created_layer_ids[] = $layer['layer_id'];

                // now a new Array with Page-IDs of processed layers
                $child_pages = array();

                // create the page and get back the Page-ID -- move the already created layers
                // so that we dont loop that again
                $child_pages = verowa_create_layer_pages( $layer_children, $parent_page_of_children );

                // Now as we have all the child pages we update the content of our parent page
                // and give them pretty links to our subpages
                $child_pages_content = array();

                foreach ( $child_pages as $child_page ) {
                    $child_pages_content[] = $child_page;
                }

                update_post_meta( $parent_page_of_children, 'verowa_sub_targets', $child_pages_content );
            }
            // if the entire layer has no children we insert the layer page with the correspondending shortcode
            else {
                $newly_created_page_id = verowa_insert_layer_page( $layer, $parent_page_id, '' );
                $created_page_ids_of_children[] = $newly_created_page_id;
                $already_created_layer_ids[] = $layer['layer_id'];
            }
        }
    }

    return $created_page_ids_of_children;
}



/**
 * for configuration the panel is defined here
 *
 * @param mixed $instance
 * @param mixed $api_key
 */
function verowa_section_for_importing_layers( $instance, $api_key ) {
    // just works, if already instance and API Key is set
    if ( $instance != 1 && $api_key != 1 ) {
        // name the option, for testing purposes we can change this
        $import_option = 'verowa_already_imported_layers';

        $layers_array = verowa_get_layers_array();

        usort( $layers_array, function( $a, $b ) {
            return $a['parent_id'] <=> $b['parent_id'];
        });

        // get the option from the db with default value false
        $already_imported_layers = get_option( $import_option, false );

        // if it is false show the importer
        if ( !$already_imported_layers ) {
            echo '<div id="verowa-import-layers-wrap" style="display: block;">';
            echo '<h4 style="margin-bottom: 1px;">' . __( 'Import Verowa layers', 'verowa-connect' ) . '</h4>';

            // start import form
            //echo '<form method="post" action="" name="verowa-layer-import">' .

            echo '<label for="layer_page_select">' . __( 'Verowa layers as subpages of', 'verowa-connect' ) . ' </label>';

            echo '<div style="display: flex; flex-direction: row;">' .
                '<div style="display: flex; width: 75%;">';

			wp_dropdown_pages(
                array(
                    'name' => 'layer_page_select',
                    'id' => 'verowa-layers-select',
                    'show_option_none' => __( 'Main level', 'verowa-connect' )
                )
			);

            echo '</div>';

            echo '<div style="display: flex;width: 25%; padding-left:10px;">' .
            	'<input type="hidden" id="import-verowa-layers" name="import-verowa-layers" value="true" />' .
            	'<input type="button" id="import-verowa-layers-button" value="' .
                __( 'Import layer pages', 'verowa-connect' ) . '" class="button button-primary"/>'.
                '</div>' .
                '</div>' .
                '</div>';
                //'</form>' .
        }
    }
}


// A shortcode to show subtargets
add_shortcode( 'verowa_sub_targets', 'show_verowa_sub_targets' );

function show_verowa_sub_targets() {
    global $post;

	ob_start();

    $sub_targets = get_post_meta( $post->ID, 'verowa_sub_targets', true );

    if ( !empty( $sub_targets ) ) {
       echo '<div class="verowa-sub-targets">';

       foreach ( $sub_targets as $sub_target ) {
           $sub_post = get_post( $sub_target );

           if ( $sub_post->post_status == 'publish' ) {
                $title = $sub_post->post_title;
                $excerpt = $sub_post->post_excerpt;
                $link = $sub_post->guid;
                $image = get_the_post_thumbnail_url( $sub_target, 'thumbnail' ); // WordPress 5 needs post-thumbnail as size

                echo '<a href="' . $link . '" >';
                echo '<div class="sub-target">';
                echo '<div class="wrapper">';
                echo '<div class="sub-target-title">' . $title . '</div>';
                echo '<div class="sub-target-excerpt">' . $excerpt . '</div>';
                echo '</div>';
                echo '<div class="sub-target-image-container">';
                if ( $image != '' ) {
                    echo '<img class="sub-target-image" src="' . $image . '" />';
                }

                echo '</div>';
                echo '</div></a>';
            }
        }

        echo '</div>';
    }

    return ob_get_clean();
}



/**
 * functions for the creation of the Verowa Layer Dropdown.
 *
 * @param int $post_id
 */
function verowa_layers_dropdown( $post_id ) {


    $hierarchical_array_for_dropdown = verowa_get_hierarchical_layers_tree();

    $int_layer_id = get_post_meta( $post_id, '_verowa_layer_assign', true );

    echo '<select name="bereiche">';
    echo '<option value=""';
    if ( $int_layer_id == '' ) {
        echo '  selected=selected';
    }
    echo '></option>';
    verowa_dropdown_options( $hierarchical_array_for_dropdown, $int_layer_id );
    echo '</select>';
}


/**
 *
 *
 * @param array $hierarchical_layer_array
 * @param mixed $selected
 */
function verowa_dropdown_options( $hierarchical_layer_array, $selected) {

    foreach( $hierarchical_layer_array as $layer) {
        $space_before = str_repeat( '&nbsp;', $layer['node_level'] );
        if ( key_exists('children', $layer) && count( $layer['children'] ) > 0 && !empty( $layer['children'] ) ) {
            echo '<option value="' . $layer['layer_id'] . '"';

            if ( $selected == $layer['layer_id'] ) {
                echo ' selected=selected';
            }

            echo '>';
            echo $space_before . $layer['layer_id'] . ' ' .$layer['name'] . '</option>';
            verowa_dropdown_options( $layer['children'], $selected . $space_before ) ;
        } else {
            echo '<option value="' . $layer['layer_id'] . '"';

            if ( $selected == $layer['layer_id'] ) {
                echo ' selected=selected';
            }
            echo '>' . $space_before . $layer['layer_id'] . ' ' . $layer['name'] . '</option>';
        }
    }
}


/**
 * Summary of verowa_layers_buildArrayTree
 *
 * @param array $elements
 * @param int $parentId
 * @return array
 */
function verowa_get_hierarchical_layers_tree( $elements = [], $parentId = 0, $node_level = 0 ) {

    if(0 == count($elements))
	{
		$elements = verowa_get_layers_array();

		// we reorder the array
		usort( $elements, function( $a, $b ) {
			return $a['parent_id'] <=> $b['parent_id'];
		} );
	}

    $branch = array();
    $sub_node_level = $node_level + 1;
    foreach ( $elements as &$element ) {
        if ( $element['parent_id'] == $parentId ) {
            // The node level is used for the correct display in the dropdown.
            $children = verowa_get_hierarchical_layers_tree( $elements, $element['layer_id'], $sub_node_level);

			$element['node_level'] = $node_level;
            if ( $children ) {
                $element['children'] = $children;
            }

            $branch[$element['layer_id']] = $element;
            unset( $element );
        }
    }

    return $branch;
}

function verowa_get_sub_layer_ids($str_layer_ids, $hierarchical_layer_ids)
{

    $arr_layer_ids = explode(',', $str_layer_ids);

	$str_ret_layer_ids = $str_layer_ids;

	foreach($arr_layer_ids as $int_layer_id) {

		 $arr_tree_sub_layer_ids = verowa_get_arr_sub_layer_id($int_layer_id, $hierarchical_layer_ids);
         $str_ids = implode( ', ',  verowa_add_sub_layer_ids($arr_tree_sub_layer_ids) );
         if ( '' != $str_ids ) {
			 $str_ret_layer_ids .= ', ' . $str_ids;
		 }
	}

    return $str_ret_layer_ids;
}

/**
 * Search layer_id in tree and return ist children
 *
 * @param int $int_layer_id
 * @param array $hierarchical_layer_ids
 */
function verowa_get_arr_sub_layer_id($int_layer_id, $hierarchical_layer_ids)
{
    $arr_ret = [];
    // Bereichs Id ist eine Hauptgruppe
	if (key_exists($int_layer_id, $hierarchical_layer_ids)){
		$arr_ret = $hierarchical_layer_ids[$int_layer_id];
	} else {
        // search in child notes
        foreach ($hierarchical_layer_ids as $single_arr_sub_tree)
		{
            // Wurde was gefunden, dann muss nicht mehr weitergesucht werden
            if(0 !== count($arr_ret)){
				break;
			}

			if(key_exists('children', $single_arr_sub_tree) )
			{
				$arr_ret = verowa_get_arr_sub_layer_id( $int_layer_id, $single_arr_sub_tree['children'] );
			}
		}
	}

    return $arr_ret;
}

function verowa_add_sub_layer_ids($arr_tree_sub_layer_ids)
{
    $arr_ret = [];

	if ( key_exists('children', $arr_tree_sub_layer_ids) )
	{
        foreach ($arr_tree_sub_layer_ids['children'] as $single_arr_sub_tree)
	    {
            $arr_ret [] = $single_arr_sub_tree['layer_id'];
            $arr_sub = verowa_add_sub_layer_ids($single_arr_sub_tree);
            if(count($arr_sub) > 0)
			{
                $arr_ret = array_merge($arr_ret, $arr_sub);
			}
	    }
	}

	return $arr_ret;
}

// Unless already done
add_post_type_support( 'page', 'excerpt' );
?>