<?php
/**
 *  Setzt mit get_verowa_event_single_content den Inhalt für einzelne Verowa-Veranstaltungen zusammen.
 *	Setzt mit get_verowa_event_title den Titel des Events zusammen.
 */


// Der Aufruf via "event=" ist deprecated und nur als Fallback, falls die Veranstaltung via GET aufgerufen wird
// (z.B. ...?event=19765); neu: "/veranstaltung/19765/" um die Events auzurufen

add_action( 'init','retrieve_event_get' );

function retrieve_event_get() {
	if ( isset( $_GET['event'] ) ) {
		$location = get_bloginfo( 'url' ) . '/veranstaltung/' . $_GET['event'] . '/';
		wp_redirect( $location, 301 );
		exit;
	}
}



// get_verowa_event_title, um den Titel ausserhalb des Loops zu bekommen
function get_verowa_event_title( $id ) {
	$arr_event_data = verowa_api_call( 'geteventdetails', $id, true );
	return $arr_event_data[0]['title'];
}



// Die Zusammensetzung der Ausgabe für das einzelne Event
function get_verowa_event_single_content( $id ) {
	$arr_event_data = verowa_get_event_content_from_db( $id );
	$arr_placeholder = array();

	$int_eventdetails_default_template = get_option( 'verowa_default_eventdetails_template', 0 );

	$arr_eventdetails_template = verowa_get_template( $int_eventdetails_default_template );

	if ( empty( $arr_event_data ) ) {
		$content = __( 'This event doesn’t exist or it is already over.', 'verowa-connect');
	} else {
		$content = '';

		// Überprüft auf ein vorhandenes Bild
		$image = $arr_event_data['detail_image'];

		if ( $image != '' ) {
			$arr_placeholder['IMAGE_URL'] = $image;
		}

		// Event Title
		$arr_placeholder['TITLE'] = $arr_event_data['title'];
		$arr_placeholder['EVENT_TITLE'] = $arr_event_data['title']; /** @deprecated v 2.4.0 */

		// Topic
		if ( $arr_event_data['topic'] != '' ) {
			$arr_placeholder['TOPIC'] .= $arr_event_data['topic'];
		}

		$technical_date_from = new DateTime( $arr_event_data['date_from'] );
		$technical_date_to = new DateTime( $arr_event_data['date_to'] );

		// Wenn Bis-Zeit angeschaltet ist, zeige Verowas date_text an,
		// weil die schon nett vorformatiert ist; ansonsten bauen wir das Datum selbst zusammen
		if ( 'on' == get_option( 'show-to-time', false) ) {
			$arr_placeholder['EVENT_DATETIME'] = $arr_event_data['date_text']; /** @deprecated v 2.4.0 */
			$arr_placeholder['DATETIME_FROM_LONG'] = $arr_event_data['date_text'];
		} else {
			/** @deprecated v 2.4.0 */
			$arr_placeholder['EVENT_DATETIME'] = date_i18n( 'l, j. F Y, G.i', $technical_date_from->format( 'U' ) ) .
				' ' . __( 'o’clock', 'verowa-connect' );

			$arr_placeholder['DATETIME_FROM_LONG'] = date_i18n( 'l, j. F Y, G.i', $technical_date_from->format( 'U' ) ) .
				' ' . __( 'o’clock', 'verowa-connect' );
		}

		// falls ein Raum vorhanden ist, zeigen wir ihn an
		if ( $arr_event_data['rooms'] != '' ) {

			// Überprüft, ob es eine externe URL ist, andernfalls setze in $site die Blog-Adresse
			if ($arr_event_data['rooms'][0]['location_url_is_external'] == 0) {
				$site_name_present = get_bloginfo( 'url' );
			} else {
				$site_name_present = ''; // falls extern, steht alles in der Location-URL drin

				// Fallback, wenn dort ohne Protokoll eingetragen
				if ( false === strpos( $arr_event_data['rooms'][0]['location_url'], '//' ) ) {
					$site_name_present .= '//';
				}
			}

			if ( $arr_event_data['rooms'][0]['location_url'] != '' ) {
				$loc_link_part1 = '<a href="' . $site_name_present .
					$arr_event_data['rooms'][0]['location_url'] . '">';
				$loc_link_part2 = '</a>';
			} else {
				$loc_link_part1 = '';
				$loc_link_part2 = '';
			}

			$str_locations = __( 'Location', 'verowa-connect' ) . ': ' . $loc_link_part1;

			if ( $arr_event_data['rooms'][0]['location_name'] == $arr_event_data['rooms'][0]['name'] ) {
				$str_locations .= $arr_event_data['rooms'][0]['name'];
			} else {
				$str_locations .= $arr_event_data['rooms'][0]['location_name'] . ', '. $arr_event_data['rooms'][0]['name'];
			}

			$arr_placeholder['LOCATIONS'] = $str_locations . $loc_link_part2;  /** @deprecated v 2.4.0 */
			$arr_placeholder['LOCATION_WITH_ROOM'] = $str_locations . $loc_link_part2;
		}

		// Abendmahl (TODO: das kann je nach Konfig. der Gemeinde auch etwas anderes bedeuten!)
		if ( $arr_event_data['with_sacrament'] > 0 ) {
			$arr_placeholder['WITH_SACRAMENT'] = __( 'With sacrament', 'verowa-connect' );
		}

		// Kurzbeschreibung hinzufügen
		if ( $arr_event_data['short_desc'] != '' ) {
			$arr_placeholder['SHORT_DESC'] = $arr_event_data['short_desc'];
		}

		// Detailbeschreibung hinzufügen
		if ( $arr_event_data['long_desc'] != '' ) {
			$arr_placeholder['LONG_DESC'] = $arr_event_data['long_desc'];
		}

		// Überprüft, ob Flyer vorhanden sind
		$files = $arr_event_data['files'];
		$files_content = '';

		if ( '' != $files ) {
			foreach ( $files as $file ) {
				$files_content .= '<a href="' . $file['url'] . '">';
				$files_content .= ( '' != $file['desc'] ) ? $file['desc'] : $file['file_name'];

				// File Type and Size (Size wegen Verowa-Fehler bisher nicht da)
				// translators: context = e.g. "PDF file"; MB = abbrev. Megabytes
				$files_content .= ' (' . $file['file_type'] . __( ' file', 'verowa-connect' ) . ', ' .
					number_format( ( $file['filesize_kb'] / 1024 ), 1 ) . ' ' . __( 'MB', 'verowa-connect' ) . ')';
				$files_content .=  '</a>';
			}

			$arr_placeholder['FILES'] = $files_content; /** @deprecated v 2.4.0 */
			$arr_placeholder['FILE_LIST'] = $files_content;
		}

		// Noch nicht chic und alles hardgecoded
		// TODO: Überarbeitung
		//__( 'Further coorganizers', 'verowa-connect')
		if ( !empty( $arr_event_data['further_coorganizer'] ) || !empty( $arr_event_data['coorganizers'] ) ) {
			$str_further_coorganizers = __( 'Mitwirkende', 'verowa-connect') . ': ';

			if ( !empty( $arr_event_data['organizer'] ) ) {
				$str_further_coorganizers .= $arr_event_data['organizer']['name'] . ', ';
			}

			if ( !empty( $arr_event_data['coorganizers'] ) ) {
				foreach ( $arr_event_data['coorganizers'] as $coorganizer ) {
					$str_further_coorganizers .= $coorganizer['name'] . ', ';
				}
			}

			if ( !empty( $arr_event_data['further_coorganizer'] ) ) {
				$str_further_coorganizers .=  $arr_event_data['further_coorganizer'] . ', ';
			}

			$arr_placeholder['COORGANIZER'] = substr( $str_further_coorganizers, 0, -2 ); /** @deprecated v 2.4.0 */
			$arr_placeholder['COORGANIZERS'] = substr( $str_further_coorganizers, 0, -2 );
		}

		//Anmeldung
		$str_subs_time_date = '';
		$str_subs_time = '';
		$str_subs_date = new DateTime();
		$str_date_i18n_format = '';
		$str_datetime_now = date_i18n( 'Ymd' ) . date_i18n( 'His' );

		// Anmeldeschluss für die Ausgabe zusammensetzen
		if ( !empty( $arr_event_data['subscribe_date'] ) && !empty( $arr_event_data['subscribe_time'] ) ) {
			$str_date_i18n_format = 'l, j. F Y, G.i';
			$str_subs_date = new DateTime( substr( $arr_event_data['subscribe_date'], 0, 4 ) . '-' .
				substr( $arr_event_data['subscribe_date'], 4, 2 ) . '-' .
				substr( $arr_event_data['subscribe_date'], 6, 2 ) . ' ' .
				substr( $arr_event_data['subscribe_time'], 0, 2 ) . ':' .
				substr( $arr_event_data['subscribe_time'], 2, 2 ) . ':00' );
		} else if ( !empty( $arr_event_data['subscribe_date'] ) ) {

			// Wenn die Anmeldezeit leer ist wird sie nicht angezeigt
			$str_date_i18n_format = 'l, j. F Y';

			$str_subs_date = new DateTime( substr( $arr_event_data['subscribe_date'], 0, 4 ) . '-' .
				substr( $arr_event_data['subscribe_date'], 4, 2 ) . '-' .
					substr( $arr_event_data['subscribe_date'], 6, 2 ) . ' ' . '23:59:59' );
		}

		if ( !empty( $arr_event_data['subscribe_time'] ) || !empty( $arr_event_data['subscribe_date'] ) ) {

			$str_subs_time_date = __( 'Subscription until', 'verowa-connect' ) . ' ' .
				date_i18n( $str_date_i18n_format, $str_subs_date->format( "U" ) );
		}

		// Wenn die Anmeldezeit leer ist wird sie auf 23:59 gesetzt
		if ( empty( $arr_event_data['subscribe_time'] ) ) {
			$arr_event_data['subscribe_time'] = '2359';
		}

		$str_subscription_text = '';

		// Wenn das Anmeldemodul nicht aktiviert ist geben wir nur die Frist und die Anmeldeperson aus (falls vorhanden)
		if ( false == $arr_event_data['subscription_module_active'] ) {
			// Wir geben nur etwas aus wenn es eine Anmeldefrist gibt
			if ( !empty( $arr_event_data['subscribe_date'] ) ) {
				if ( $arr_event_data['subscribe_date'] . $arr_event_data['subscribe_time'] . '59' >= $str_datetime_now ) {

					$str_subscription_text .= '<div><p class="subscription-event-detail-datetime">' .
						$str_subs_time_date . '</p></div>';
				} else {
					$str_subscription_text .= '<p class="subscription-event-detail-deadline-over">' .
						sprintf( __( 'The registration deadline expired on %s.', 'verowa-connect' ),
						date_i18n( $str_date_i18n_format, $str_subs_date->format( "U" ) ) ) . '</p>';
				}
			}

			// Wenn eine Anmeldeperson angegeben ist. Sonst muss man sich über die Kontaktperson des Events anmelden
			if ( !empty( $arr_event_data['subscribe_person'] ) ) {
				$str_subscription_text .= ' ' . __( 'via e-mail', 'verowa-connect') . ' ' . _x( 'to', 'personal', 'verowa-connect') .
					' <a href="mailto:' . $arr_event_data['subscribe_person']['email'] . '">' .
					$arr_event_data['subscribe_person']['name'] . '</a>';
			}

		} else if ( $arr_event_data['subscribe_person_id'] != 0 || !empty( $arr_event_data['subscribe_date'] ) ) {

			// Link nur ausgeben wenn nicht "ohne Anmeldung" als Formular ausgewählt ist (subscribe_person_id == 1 )
			if ( $arr_event_data['subscribe_person_id'] != 1 ) {

				// Link zu Anmeldeformular ausgeben
				$str_anmeldelink = $arr_event_data['subscribe_person_id'] > 1 ?
					'<a class="subscription-button" href="https://' . $_SERVER['HTTP_HOST'] .
					'/subscription-form?subs_event_id=' . $id .'">' . __( 'to the registration form', 'verowa-connect' ) . '</a>' : '';

				// Prüfen ob das AM-Plugin installiert ist
				if ( empty( $arr_event_data['subscribe_date'] ) ||
					$arr_event_data['subscribe_date'] . $arr_event_data['subscribe_time'] . '59' >= $str_datetime_now ) {

					$str_subscription_text .= '<div class="subscription-link-box" style="margin: 30px 0px 30px;">' .
						'<p class="subscription-event-detail-datetime">' . $str_subs_time_date . '</p>' .
						$str_anmeldelink . '</div>';
				} else {
					$str_subscription_text .= '<p class="subscription-event-detail-deadline-over">' .
						sprintf( __( 'The registration deadline expired on %s', 'verowa-connect' ),
						date_i18n( $str_date_i18n_format, $str_subs_date->format( "U" ) ) ) . '</p>';
				}

			} else {
				$str_subscription_text .= '<div style="margin: 30px 0px 30px;"><p>' .
					__( 'No registration necessary.', 'verowa-connect' ) . '</p></div>';
			}
		}

		if ( strlen( $str_subscription_text ) > 0 ) {
			$arr_placeholder['SUBSCRIPTION'] = $str_subscription_text; /** @deprecated v 2.4.0 */
			$arr_placeholder['SUBSCRIPTION_INFO'] = $str_subscription_text;
		}



		// Organist (TODO: Diese Felder können alle auch anders bezeichnet sein, je nach Gemeinde!)
		if( !empty( $arr_event_data['organists'] ) ) {
			$str_organists = __( 'Music', 'verowa-connect' ) . ': ';

			foreach ( $arr_event_data['organists'] as $organists) {
				$str_organists .= $organists['name'] . ', ';
			}

			$arr_placeholder['ORGANIST'] = substr( $str_organists, 0, -2 ); /** @deprecated v 2.4.0 */
			$arr_placeholder['SERVICE_4_PERSONS'] = substr( $str_organists, 0, -2 );
		}

		// Kollekte
		if ( !empty( $arr_event_data['collection'] ) ) {
			$str_collection = __( 'Collection', 'verowa-connect' ) . ': ';

			if ( strlen( $arr_event_data['collection']['url'] ) > 0 ) {
				$collection_url = $arr_event_data['collection']['url'];

				if ( false === strpos( $collection_url, '//' ) ) {
					$collection_url = 'https://' . $collection_url;
			}

				$str_link_pre = '<a href="' . $collection_url . '" target="_blank">';
				$str_link_post = '</a>';
			} else {
				$str_link_pre = '';
				$str_link_post = '';
			}

			$arr_placeholder['COLLECTION'] = $str_collection . $str_link_pre .
				$arr_event_data['collection']['project'] . $str_link_post;
		}


		// Taufe
		if ( !empty( $arr_event_data['baptism_offer_text'] ) ) {
			$arr_placeholder['BAPTISM_OFFER'] = $arr_event_data['baptism_offer_text'];
		}


		// Kinderhütedienst
		if ( !empty( $arr_event_data['childcare_text'] ) ) {
			$str_childcare = '<br />' . $arr_event_data['childcare_text'];

			if ( !empty( $arr_event_data['childcare_person']['name'] ) ) {
				$str_childcare .= ': ' . $arr_event_data['childcare_person']['name'];
			}

			$arr_placeholder['CHILDCARE'] = $str_childcare;
		}

		// Gastronomie
		if ( !empty( $arr_event_data['catering'] ) ) {
			$arr_placeholder['CATERING'] = __( 'with', 'verowa-connect' ) . ' ' . $arr_event_data['catering'] . '</b>';
		}


		// Kontaktperson oder Seelsorger (kann auch ausgeschaltet sein)

		if ( 'on' == get_option( 'show_organizer', 'on' ) &&
			is_numeric( $arr_event_data['organizer']['person_id']) &&
			$arr_event_data['organizer']['person_id'] > 0 ) {

			// Titel nur zeigen, falls es ein Gottesdienst ist (HACK: via Hauptbereich!?)
			if ( false !== strpos( strtolower( $arr_event_data['layers'][0]['text'] ), 'gottesdienst' ) ) {
				$person_headline = '';
			} else {
				$person_headline = '<h3>' . __( 'Contact', 'verowa-connect' ) . '</h3>';
			}

			$person_content = '';
			$person_content = do_shortcode( '[verowa_person id="' .
				$arr_event_data['organizer']['person_id'] . '" comp_tag="th"]' ); // zeige die Person, falls öffentlich

			// falls die Person nicht ganz öffentlich war, sondern nur im Rahmen einer Veranstaltung,
			// zeigen wir einfach den Namen an
			if ( '' == $person_content ) {
				$person_content = '<div class="person"><div class="person-description">' .
					'<span class="name">' . $arr_event_data['organizer']['name'] . '</span></div></div>';
			}

			$arr_placeholder['EVENT_PERSON'] .= $person_headline . $person_content; /** @deprecated v 2.4.0 */
			$arr_placeholder['ORGANIZER'] .= $person_headline . $person_content;
		}

		// Microformat ist jetzt Standard
		$str_template_addon = '<script type="application/ld+json">
			{
			  "@type": "h-event",
			  "p-name": "' . $arr_event_data['title'] . '",
			  "location": "' . $arr_event_data['rooms'][0]['location_name'] . '",
			  "dt-start": "' . $technical_date_from->format( "Y-m-d h:m" ) . '",
			  "dt-end": "' . $technical_date_to->format( "Y-m-d h:m" ) . '",
			  "u-url": "' . get_bloginfo( 'url' ) . '/veranstaltung/' . $arr_event_data['event_id'] . '/",
			  "p-summary": "' . $arr_event_data['short_desc'] . '"
			}
			</script>';

		$str_template_addon .= '<script>jQuery("li:contains(\"' . __( 'Agenda', 'verowa-connect' ) . '\")").' .
			'addClass("current_page_item current-menu-item");</script>';

		// fake genesis breadcrumbs
		global $breadcrumb_title;
		$breadcrumb_title = $arr_event_data['title'];
		remove_action( 'genesis_before_loop', 'genesis_do_breadcrumbs' );
		add_action( 'genesis_before_loop', 'fake_breadcrumbs' );

		$str_output = $arr_eventdetails_template['header'] .
			verowa_parse_template( $arr_eventdetails_template['entry'] . $str_template_addon, $arr_placeholder ) .
			$arr_eventdetails_template['footer'];

		return $str_output;
	}

}



function fake_breadcrumbs() {
	global $breadcrumb_title;

	echo '<div class="breadcrumb" itemprop="breadcrumb" itemscope="" ' .
		'itemtype="http://schema.org/BreadcrumbList">' . __( 'Current page', 'verowa-connect') . ': ' .
		'<span class="breadcrumb-link-wrap" itemprop="itemListElement" itemscope="" ' .
		'itemtype="http://schema.org/ListItem"><a href="' . get_bloginfo( 'url' ) . '" itemprop="item">' .
		'<span itemprop="name">' . __( 'Frontpage', 'verowa-connect') . '</span></a></span> ' .
		'<span aria-label="breadcrumb separator">/</span> ' .
		'<span class="breadcrumb-link-wrap" itemprop="itemListElement" itemscope="" ' .
		'itemtype="http://schema.org/ListItem"><a href="' . get_bloginfo( 'url' ) . '/agenda" itemprop="item">' .
		'<span itemprop="name">' . __( 'Agenda', 'verowa-connect') . '</span></a></span> ' .
		'<span aria-label="breadcrumb separator">/</span> ' .
		$breadcrumb_title . '</div>';
}
?>