<?php
use UI\Controls\Check;
// Dieser Rest-Wrapper liefert uns den Inhalt für die Event-Details in der Event-Liste.
// Für die Listendarstellung wird zuerst per REST-Query mal die grobe Liste abgeholt; erst danach, wenn die
// Seite dargestellt ist, holen wir per JS zu jedem einzelnen Event auch noch die Details aus Verowa.

// Wir stellen den Request per jQuery nicht direkt an die Verowa-API, weil das den API Key verraten würde.

add_action(
	'rest_api_init',
	function () {
		register_rest_route(
			'verowa/v1',
			'/event/(?P<id>\d+)',
			array(
				'methods' => 'GET',
				'callback' => 'verowa_event_id_rest_wrapper',
			)
		);
	}
);

add_action(
	'rest_api_init',
	function () {
		register_rest_route(
			'verowa/v1',
			'/recharge/',
			array(
				'methods' => 'POST',
				'callback' => 'verowa_isotope_recharge',
			)
		);
	}
);



// Funktion, um Veranstaltungen nachzuladen

/**
 * @deprecated 2.4.0
 * 
 * @param mixed $data 
 * @return string
 */
function verowa_isotope_recharge( $data ) {
	$body = json_decode( $data->get_body() );
	$list_id = $body->list_id;
	$string_not_include_ids = substr( $body->ids_not, 0, -1 );
	$array_not_include_ids = explode( ',', $string_not_include_ids );

	$verowa_call_string =  $list_id . '/0/100'; // erstmal nur 100 Events aus der API
	$arr_verowa_events = verowa_api_call( 'geteventsbylist', $verowa_call_string, true );

	$events = array();
	$filter_array = get_option( 'verowa_dynamic_agenda_filter_array', true );

	foreach ( $arr_verowa_events['events'] as $key => $value ) {
		$temp_events_cat = '';

		foreach ( $filter_array as $filter ) {
			$temp_cat = array_search( $value['event_id'], $filter['event_ids'], true );

			if ( false !== $temp_cat ) {
			 	// möchte hier keine Duplicates haben
				if ( false === strpos( $temp_events_cat, ' .events-' . $filter['list_id'] ) ) {
					$temp_events_cat .= ' .events-' . $filter['list_id'];
				}
			}
		}

		$value['event_cats'] = $temp_events_cat;
		$events[] = $value;
	}

	$html_return = '';

	foreach ( $events as $event ) {

		if ( !in_array( $event['event_id'], $array_not_include_ids ) ) {
			$html_return .= show_single_verowa_event( $event );
		}
	}

	return $html_return;
}


// Callback-Funktion für den REST-Wrapper
function verowa_event_id_rest_wrapper( $data ) {
	$event_id = $data['id'];
	$arr_event_data = verowa_get_event_content_from_db($event_id);

	// falls der Kontakt nicht gezeigt werden soll, nehmen wir ihn hier heraus
	// (die Mitwirkenden sollen davon aber nicht betroffen sein!)
	if ('on' != get_option( 'show_organizer', 'on' ) ) {
		$arr_event_data['organizer'] = '';
	}

	return $arr_event_data;
}


// der Rest-Wrapper muss auch ical liefern
add_action(
	'rest_api_init',
	function () {
		register_rest_route(
			'verowa/v1',
			'/ical/(?P<id>\d+)',
			array(
				'methods' => 'GET',
				'callback' => 'verowa_event_ical_wrapper'
			)
		);
	}
);




/**
 * ical assemble
 *
 * @param array $data [id => event_id ]
 *
 * @return string
 *
 */
function verowa_event_ical_wrapper( $data ) {
	$event_id = $data['id'];
	$arr_event_data = verowa_get_event_content_from_db($event_id);
	$event = pp_create_ical( $arr_event_data );

	return $event;
}


// damit das funktioniert, braucht es einen Filter
add_filter( 'rest_pre_serve_request', 'multiformat_rest_pre_serve_request', 10, 4 );

function multiformat_rest_pre_serve_request( $served, $result, $request, $server ) {
	// assumes 'format' was passed into the intial API route
	// example: https://baconipsum.com/wp-json/baconipsum/test-response?format=text
	// the default JSON response will be handled automatically by WP-API
	switch ( $request['format'] ) {
		case 'ical':
			header( 'Content-type: text/calendar' );
			header( 'Content-Disposition: attachment; filename=event-' . $request['id'] . '.ics;' );

			echo $result->data;

			$served = true; // tells the WP-API that we sent the response already

			break;
	}

	return $served;
}



/**
 *
 *
 * @param array $event
 *
 * @return string
 */
function pp_create_ical( $event ) {
	$url = stripslashes( get_bloginfo( 'url' ) );
	$domain = 'verowa.ch';
	$ical_event =
		"BEGIN:VCALENDAR\r\n" .
		"VERSION:2.0\r\n" .
		"PRODID:-//" . get_bloginfo( 'name' ) . "//Online-Agenda v1.0//DE\r\n" .
		"TZID:Europe/Zurich\r\n" .
		"X-WR-TIMEZONE:Europe/Zurich\r\n" .
		"X-MICROSOFT-CDO-TZID:cdoParis\r\n" .
		"METHOD:PUBLISH\r\n";

	$ical_event .= "BEGIN:VEVENT\r\n" .
		"UID:" . crc32( $event['event_id']) . '@' . $domain . "\r\n";

	$begin = strtotime( $event['date_from'] );
	$end = strtotime( $event['date_to'] );

	$ical_event .=
		'DTSTAMP:' . date( 'Ymd', time() ) . 'T' . date( 'His', time() ) ."\r\n" .
		'DTSTART:' . date( 'Ymd', $begin) . 'T' . date( 'His', $begin ) ."\r\n" .
		'DTEND:' . date( 'Ymd', $end) . 'T' . date( 'His', $end ) . "\r\n" .
		'LOCATION: ' . $event['rooms'][0]['location_name'] . "\r\n" .
		'SUMMARY:' . $event['title'] . "\n";

	$content = strip_tags( $event['topic'] ."\n" . $event['long_desc'] );

	if ( $content != '' ) {
		$ical_event .= 'DESCRIPTION:' . preg_replace( "/\r|\n/", ' ', $content ) . "\r\n";
	}

	$ical_event .= 'LAST-MODIFIED:' . date( 'Ymd', time() ) . 'T' . date( 'His', time() ) ."\r\n" .
		"END:VEVENT\r\n";
	$ical_event .=  "END:VCALENDAR";

	return $ical_event;
}



add_action( 'rest_api_init', function () {
	register_rest_route( 'verowa/v1', '/agenda_event/(?P<current_batch>[-a-zA-Z0-9_]+)/', array(
		'methods' => 'GET',
		'callback' => 'verowa_get_agenda_events',
	) );
} );

/**
 *
 * @param array $data
 *
 * @return stdClass
 */
function verowa_get_agenda_events($data)
{
	$result = new stdClass();

	$str_date8 = trim($_GET['date']);
	$arr_list_ids = isset($_GET['arr_list_ids']) ? $_GET['arr_list_ids'] : [];

	$format_in = 'Y-m-d H:i:s';
	$obj_date_filter = 'now';

	$_SESSION['verowa_agenda_current_batch'] = $data['current_batch'];
	$_SESSION['verowa_agenda_filter'] = [];
	$_SESSION['verowa_agenda_filter']['arr_list_ids'] = $arr_list_ids;

	if(strlen($str_date8) > 0)
	{
		$_SESSION['verowa_agenda_filter']['date8_displays_from'] = $str_date8;
		$str_date_filter = substr($str_date8, 0, 4) . '-' . substr($str_date8, 4, 2) . '-' .
			substr($str_date8, 6, 2) . ' 00:00:00';
		$obj_date_filter = DateTime::createFromFormat($format_in, $str_date_filter);
	}

	// check if the date is proper set.
	$obj_date_filter = false == $obj_date_filter ? 'now' :  $obj_date_filter;

	$batch_size = get_option('verowa_agenda_batch_size', 50);
	$int_offset = (intval($data['current_batch']) * $batch_size) - $batch_size;

	$arr_events = verowa_get_agenda_events_from_db( '', implode(',', $arr_list_ids), $batch_size,
		$int_offset, $obj_date_filter);

	$result->has_further_results = count($arr_events) == $batch_size ? true : false;

	foreach ( $arr_events as $arr_single_event) {
		$str_content .= show_single_verowa_event( $arr_single_event );
	}

	$result->content = $str_content;

	return $result;
}


add_action(
	'rest_api_init',
	function () {
		register_rest_route(
			'verowa/v1',
			'/plugin_info',
			array(
				'methods' => 'GET',
				'callback' => 'verowa_return_plugin_info',
			)
		);
	}
);

function verowa_return_plugin_info() {
	if( ! function_exists( 'get_plugin_data' ) ) {
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    }

	$str_dir = dirname(__DIR__);
	$plugin_data = get_plugin_data($str_dir . '/verowa-connect.php');

	return [
		'version' => $plugin_data['Version'],
		'php_version' => phpversion(),
		'$str_dir' => $str_dir
	];
}

add_action(
	'rest_api_init',
	function () {
		register_rest_route(
			'verowa/v1',
			'/update_event',
			array(
				'methods' => 'GET',
				'callback' => 'force_update_single_event',
			)
		);
	}
);

function force_update_single_event()
{
	$obj_update = new Verowa_Update_Controller();
	$obj_update->update_verowa_events_in_db($_GET['id'] ?? 0);
	return 0; // alles OK
}


?>