<?php
/*
 * Diese Funktion wird ausgeführt, sobald das Verowa Connect Plugin aktiviert wird.
 * Diese Funktion legt bei Installation eine Seite Agenda an (falls sie nicht existiert)
 * und legt Standartwerte (Options) fest.
 */
function verowa_plugin_activate() {
	global $wpdb;

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

	// Test if or when the function would be called
	$str_dir = dirname(__DIR__);
	$plugin_data = get_plugin_data($str_dir . '/verowa-connect.php');
	$str_mail = 'Verowa Connect: ' . $plugin_data['Version'] . ' <br />';
	$str_mail .= get_site_url();
	verowa_send_mail(SUPPORT_MAIL, 'verowa_plugin_activate', $str_mail);

	// Flag to check if the functino call during a update.
	$db_version = $plugin_data['Version'];
	update_option( 'verowa_db_version', $db_version );



	$str_charset = $wpdb->get_charset_collate();
	$str_templates_tablename = $wpdb->prefix . 'verowa_templates';
	$str_events_tablename = $wpdb->prefix . 'verowa_events';
	$str_persons_tablename = $wpdb->prefix . 'verowa_person';
	$str_persongroups_tablename = $wpdb->prefix . 'verowa_person_groups';


	$arr_insert_formats = array( '%s', '%s', '%s', '%s', '%s', '%s', '%s' );

	$agenda_post = array(
		'post_title' => __( 'Agenda', 'verowa-connect' ),
		'post_content' => '[verowa_agenda]',
		'post_type' => 'page',
		'post_status' => 'publish',
	);

	$agenda_id = get_page_by_title( $agenda_post['post_title'] );

	if ( $agenda_id == NULL ) {
		wp_insert_post( $agenda_post );
	}

	// Default-Anzahl für Dropdowns ist 2
	if ( false == get_option( 'how_many_verowa_dropdowns', false ) ) {
		update_option( 'how_many_verowa_dropdowns', '2' );
	}

	$create_template_table_query = 'CREATE TABLE `' . $str_templates_tablename . '` (' .
		'`template_id` INT UNSIGNED NOT NULL AUTO_INCREMENT, ' .
		'`template_name` VARCHAR(100) NOT NULL, ' .
		'`info_text` TEXT NOT NULL COMMENT "Infos zum template", ' .
		'`type` VARCHAR(80) NOT NULL, ' .
		'`display_where` VARCHAR(50) NOT NULL, ' .
		'`header` TEXT NOT NULL, ' .
		'`entry` TEXT NOT NULL, ' .
		'`separator` TEXT NOT NULL, ' .
		'`footer` TEXT NOT NULL, ' .
		'`modified_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP AFTER `footer`,' .
		'`created_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP AFTER `modified_when`,' .
		'PRIMARY KEY (`template_id`), ' .
		'UNIQUE INDEX `template_id_UNIQUE` (`template_id` ASC)) ' . $str_charset . ';';

	// Verowa Events Tabelle
	$create_event_table_query = 'CREATE TABLE `' . $str_events_tablename . '` (' .
		'`event_id` INT UNSIGNED NOT NULL DEFAULT 0,' .
		'`datetime_from` DATETIME NOT NULL,' .
		'`datetime_to` DATETIME NOT NULL,' .
		'`list_ids` TEXT NOT NULL COMMENT ";a;b;c;",' .
		'`layer_ids` TEXT NOT NULL COMMENT ";a;b;c;",' .
		'`target_groups` TEXT NOT NULL COMMENT ";a;b;c;",' .
		'`with_subscription` TINYINT UNSIGNED NULL DEFAULT 0,' .
		'`content` TEXT NOT NULL COMMENT "JSON",' .
		'`hash` VARCHAR(32) NOT NULL, ' .
		'`modified_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP AFTER `hash`,' .
		'`created_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP AFTER `modified_when`,' .
		'`deprecated` TINYINT NOT NULL DEFAULT 0, ' .
		'PRIMARY KEY (`event_id`)) ' .
		'COMMENT = "Verowa Events werden hier gespeichert" ' . $str_charset . ';';

	// Verowa Persons Tabelle
	$create_persons_table_query = 'CREATE TABLE `' . $str_persons_tablename . '` (' .
		'`person_id` INT UNSIGNED NOT NULL,' .
		'`content` TEXT NOT NULL COMMENT "JSON",' .
		'`hash` VARCHAR(32) NOT NULL, ' .
		'`modified_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP AFTER `hash`,' .
		'`created_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP AFTER `modified_when`,' .
		'`deprecated` TINYINT NOT NULL DEFAULT 0, ' .
		'PRIMARY KEY (`person_id`)) ' . $str_charset . ';';

	// Verowa Persongroup Tabelle
	$create_persongroups_table_query = 'CREATE TABLE `' . $str_persongroups_tablename . '` (' .
		'`pgroup_id` INT UNSIGNED NOT NULL,' .
		'`person_ids` TEXT NOT NULL COMMENT ";a;b;c;",' .
		'`functions_in_group` TEXT NOT NULL COMMENT "JSON with all the group functions of the members", ' .
		'`hash` VARCHAR(32) NOT NULL, ' .
		'`modified_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP AFTER `hash`,' .
		'`created_when` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP AFTER `modified_when`,' .
		'`deprecated` TINYINT NOT NULL DEFAULT 0, ' .
		'PRIMARY KEY (`pgroup_id`)) ' .
		'COMMENT = "Personengruppen werden hier gespeichert" ' . $str_charset . ';';

	// dbDelta() checks if the tables already exist and only adds them if not
	dbDelta( array( $create_template_table_query, $create_event_table_query, $create_persons_table_query, $create_persongroups_table_query ) );

	$templates_in_db_query = 'SELECT COUNT(*) FROM `' . $str_templates_tablename . '`;';
	$count_templates_in_db = $wpdb->get_var( $templates_in_db_query );

	if ( 0 == $count_templates_in_db ) {
		verowa_add_default_templates_to_db( $arr_insert_formats );

		// set default options for templates
		add_option('verowa_default_persondetails_template', 1);
		add_option('verowa_default_personlist_template', 2);
		add_option('verowa_default_eventdetails_template', 3);
		add_option('verowa_default_eventlist_template', 4);
	}

	// add eventdetail page
	$wp_post_event = get_page_by_path('veranstaltung');
	if (null == $wp_post_event)
	{
		// Create post object
		$event_post = [
		  'post_title'    => 'Veranstaltungsdetails',
		  'post_name' => 'veranstaltung',
		  'post_type' => 'page',
		  'post_content'  => '<!-- wp:shortcode -->[verowa_generate_post_event]<!-- /wp:shortcode -->',
		  'post_status'   => 'publish',
		  'post_author'   => 1,
		  'comment_status' => 'closed',
		  'post_category' => []
		];

		// Insert the post into the database
		$ret = wp_insert_post( $event_post );
	}

	// add persondetail page
	$wp_post_person = get_page_by_path('person');
	if (null == $wp_post_person)
	{
		// Create post object
		$person_post = [
		  'post_title'    => 'Personendetails',
		  'post_name' => 'person',
		  'post_type' => 'page',
		  'post_content'  => '<!-- wp:shortcode -->[verowa_generate_post_person]<!-- /wp:shortcode -->',
		  'post_status'   => 'publish',
		  'post_author'   => 1,
		  'comment_status' => 'closed',
		  'post_category' => []
		];

		wp_insert_post( $person_post );
	}

	activate_verowa_data_hooks();
}



function verowa_plugin_deactivate() {
	deactivate_verowa_data_hooks();
}



/**
 * Add Default Templates to DB
 *
 */
function verowa_add_default_templates_to_db( $arr_data_formats ) {
	global $wpdb;

	// Persondetails Template
	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_id' => 1,
			'template_name' => __( 'Persondetails', 'verowa-connect' ),
			'info_text' => '',
			'type' => 'persondetails',
			'display_where' => '',
			'header' => '',
			'entry' => '<div class="person">' . PHP_EOL .
			'<h1 class="verowa-person-title">{NAME}</h1>' . PHP_EOL .
			'[[?IMAGE_URL:<div class="person_image"><img src="{IMAGE_URL}" /></div>]]' . PHP_EOL .
			'<div class="person_description">' . PHP_EOL .
			'	[[?PROFESSION:<span class="person_profession">{PROFESSION}</span>]]' . PHP_EOL .
			'	[[?SHORT_DESC:<span class="person_excerpt">{SHORT_DESC}</span>]]' . PHP_EOL .
			'	[[?DESC_TASKS:<h3 class="aufgabenbereiche">' . __( 'Tasks', 'verowa-connect' ) . PHP_EOL .
			'	</h3><span class="person_tasks">{DESC_TASKS}</span>]]' . PHP_EOL .
			'	<h3 class="kontakt">' . __( 'Contact', 'verowa-connect' ) . '</h3>' . PHP_EOL .
			'	<span class="person_meta"> ' . PHP_EOL .
			'	[[?HAS_PRIVATE_ADDRESS:<span class="address-type">{HAS_PRIVATE_ADDRESS}</span>]]' . PHP_EOL .
			'	[[?PRIVATE_STREET:<span class="address">{PRIVATE_STREET}</span>]]' . PHP_EOL .
			'	[[?PRIVATE_ZIP_CITY:<span class="postcode-town">{PRIVATE_ZIP_CITY}</span>]]' . PHP_EOL .
			'	[[?HAS_BUSINESS_ADDRESS:<span class="address-type">{HAS_BUSINESS_ADDRESS}</span>]]' . PHP_EOL .
			'	[[?BUSINESS_STREET:<span class="address">{BUSINESS_STREET}</span>]]' . PHP_EOL .
			'	[[?BUSINESS_ZIP_CITY:<span class="postcode-town">{BUSINESS_ZIP_CITY}</span>]]' . PHP_EOL .
			'	[[?EMAIL:<span class="email"><a href="mailto:{EMAIL}">E-Mail</a></span>]]' . PHP_EOL .
			'	[[?BUSINESS_PHONE:<span class="phone business">{BUSINESS_PHONE}</span>]]' . PHP_EOL .
			'	[[?PRIVATE_PHONE:<span class="phone private">{PRIVATE_PHONE}</span>]]' . PHP_EOL .
			'	[[?MOBILE_PHONE:<span class="phone mobile">{MOBILE_PHONE}</span>]]' . PHP_EOL .
			'	</span>' . PHP_EOL .
			'	[[?DESC_PERSONAL:<span class="person_description">{DESC_PERSONAL}</span>]]' . PHP_EOL .
			'</div>' . PHP_EOL .
			'</div>',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);

	// Personlist Template
	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_id' => 2,
			'template_name' => __( 'Personlist', 'verowa-connect' ),
			'info_text' => '',
			'type' => 'personlist',
			'display_where' => 'content',
			'header' => '',
			'entry' => '<div class="person">' . PHP_EOL .
			'[[?IMAGE_URL:<div class="person_image">{IMAGE_URL}</div>]]' . PHP_EOL .
			'<div class="person_description">' . PHP_EOL .
			'<h4 class="name">{PERSON_NAME}</h4>' . PHP_EOL .
			'[[?FUNCTION_IN_GROUP:<p class="group_function">{FUNCTION_IN_GROUP}</p>]]' . PHP_EOL .
			'[[?SHORT_DESC:<p class="short_desc">{SHORT_DESC}</p>]]' . PHP_EOL .
			'[[?PROFESSION:<p class="profession">{PROFESSION}</p>]]' . PHP_EOL .
			'<div class="person_meta">' . PHP_EOL .
			'<ul>' . PHP_EOL .
			'[[?ADDRESS:<li class="address">{ADDRESS}</li>]]' . PHP_EOL .
			'[[?ZIP_CITY:<li class="postcode-town">{ZIP_CITY}</li>]]' . PHP_EOL .
			'[[?EMAIL:<li class="email"><a href="mailto:{EMAIL}">E-Mail</a></li>]]' . PHP_EOL .
			'[[?PHONE:<li class="phone">{PHONE}</li>]]' . PHP_EOL .
			'</ul>' . PHP_EOL .
			'</div' . PHP_EOL .
			'</div>' . PHP_EOL .
			'</div>',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);

	// Eventdetails Template
	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_id' => 3,
			'template_name' => __( 'Eventdetails', 'verowa-connect' ),
			'info_text' => '',
			'type' => 'eventdetails',
			'display_where' => '',
			'header' => '',
			'entry' => '[[?IMAGE_URL:<div class="image verowa-event-picture"><img src="{IMAGE_URL}" /></div>]]' . PHP_EOL .
			'<h1 class="verowa-event-title">{TITLE}</h1>' . PHP_EOL .
			'[[?TOPIC:<h2>{TOPIC}</h2>]]' . PHP_EOL .
			'[[?DATETIME_FROM_LONG:<p class="datum">{DATETIME_FROM_LONG}</p>]]' . PHP_EOL .
			'[[?LOCATION_WITH_ROOM:<p class="town">{LOCATION_WITH_ROOM}</p>]]' . PHP_EOL .
			'[[?WITH_SACRAMENT:<p class="with_sacrament">{WITH_SACRAMENT}</p>]]' . PHP_EOL .
			'[[?SHORT_DESC:<div class="short_description">{SHORT_DESC}</div>]]' . PHP_EOL .
			'[[?LONG_DESC:<div class="long_description">{LONG_DESC}</div>]]' . PHP_EOL .
			'[[?FILE_LIST:<p class="files">{FILE_LIST}</p>]]' . PHP_EOL .
			'<div style="margin-bottom: 10px;" class="verowa-event-detail-meta-data">' . PHP_EOL .
			'[[?COORGANIZERS:<p class="coorganizer">{COORGANIZERS}</p>]]' . PHP_EOL .
			'[[?SUBSCRIPTION_INFO:<div class="subscription">{SUBSCRIPTION_INFO}</div>]]' . PHP_EOL .
			'' . PHP_EOL .
			'[[?SERVICE_4_PERSONS:<p class="organists">{SERVICE_4_PERSONS}</p>]]' . PHP_EOL .
			'[[?COLLECTION:<p class="collection">{COLLECTION}</p>]]' . PHP_EOL .
			'[[?BAPTISM_OFFER:<p class="baptism_offer">{BAPTISM_OFFER}</p>]]' . PHP_EOL .
			'[[?CHILDCARE:<p class="childcare">{CHILDCARE}</p>]]' . PHP_EOL .
			'[[?CATERING:<p class="catering"><b>{CATERING}</b></p>]]' . PHP_EOL .
			'</div>' . PHP_EOL .
			'' . PHP_EOL .
			'[[?ORGANIZER:{ORGANIZER}]]',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);

	// Eventlist Template
	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_id' => 4,
			'template_name' => __( 'Eventlist', 'verowa-connect' ),
			'info_text' => '',
			'type' => 'eventlist',
			'display_where' => 'content',
			'header' => '',
			'entry' => '<div class="event_list_item element-item event-{EVENT_ID} {CATEGORIES}" data-date="{DATE_FROM_8}" ' . PHP_EOL .
			'data-id="{EVENT_ID}"> ' . PHP_EOL .
			'<div class="event_date">{DATE_FROM_LONG}</div> ' . PHP_EOL .
			'<div class="event_container"> ' . PHP_EOL .
			'<div class="event_short_content"> ' . PHP_EOL .
			'{TIME_MIXED_LONG} ' . PHP_EOL .
			'<span class="event_title">{TITLE}</span> ' . PHP_EOL .
			'[[?TOPIC:<span class="event_topic">{TOPIC}</span>]] ' . PHP_EOL .
			'[[?LOCATION_WITH_ROOM:<span class="event_location">{LOCATION_WITH_ROOM}</span>]] ' . PHP_EOL .
			'</div> ' . PHP_EOL .
			'[[?IMAGE_URL:<div class="event_image"><img src="{IMAGE_URL}" /></div>]] ' . PHP_EOL .
			'<div class="event_toggle"><div class="toggle_button" ><i class="fas fa-angle-down"></i></div></div> ' . PHP_EOL .
			'<div class="event_content collapse event{EVENT_ID}" ></div> ' . PHP_EOL .
			'<div class="event_button_list"><div class="buttons"> ' . PHP_EOL .
			'[[?CALENDAR_EXPORT:<span class="ical"><a href="#" class="icalhandler" data-id="{EVENT_ID}"> ' . PHP_EOL .
			'	<i class="far fa-calendar-alt"></i>{CALENDAR_EXPORT}</a></span><span class="details-buttons">]] ' . PHP_EOL .
			'[[?SUPSCRIPTION_BUTTON:{SUPSCRIPTION_BUTTON}]] ' . PHP_EOL .
			'<a href="/veranstaltung/{EVENT_ID}/"><button class="detail">{DETAILS_BUTTON_TEXT}</button></a></span></div></div> ' . PHP_EOL .
			'</div> ' . PHP_EOL .
			'</div>',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);

	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_name' => 'Eventlist expand',
			'info_text' => '',
			'type' => 'eventlist',
			'display_where' => 'content',
			'header' => '',
			'entry' => '<div class="event_list_item element-item event-{EVENT_ID} {CATEGORIES}" data-date="{DATE_FROM_8}" data-id="{EVENT_ID}">' . PHP_EOL .
			'<div class="event_date"><a href="/veranstaltung/{EVENT_ID}/">{DATE_FROM_LONG}</a></div>' . PHP_EOL .
			'<div class="event_container">' . PHP_EOL .
			'<a href="/veranstaltung/{EVENT_ID}/"><div class="event_short_content">{TIME_MIXED_LONG}' . PHP_EOL .
			'<span class="event_title">{TITLE}</span>' . PHP_EOL .
			'[[?TOPIC:<span class="event_topic">{TOPIC}</span>]]' . PHP_EOL .
			'[[?DATETIME_LONG:<span class="event_location">{DATETIME_LONG}</span>]]' . PHP_EOL .
			'</div></a>' . PHP_EOL .
			'[[?IMAGE_URL:<div class="event_image"><img src="{IMAGE_URL}" /></div>]]' . PHP_EOL .
			'<a href="/veranstaltung/{EVENT_ID}/"><div>[[?ORGANIZER_NAME:<p style="margin-bottom: 0;">' . PHP_EOL .
			'[[?LAYER_IDS % ;5;:Prediger||Kontakt]]: {ORGANIZER_NAME}</p>]]' . PHP_EOL .
			'[[?COORGANIZER_NAMES:<p style="margin-bottom: 0;">Mitwirkende: {COORGANIZER_NAMES}</p>]]</a>' . PHP_EOL .
			'</div></div>' . PHP_EOL .
			'<div class="event_button_list_new"><div class="buttons"><span class="details-buttons">' . PHP_EOL .
			'[[?SUPSCRIPTION_BUTTON:{SUPSCRIPTION_BUTTON}]]</span></div></div></div>',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);
	// Eventlist in Widget Template
	$wpdb->insert(
		$wpdb->prefix . 'verowa_templates',
		array(
			'template_name' => __( 'Eventlist in Widget', 'verowa-connect' ),
			'info_text' => '',
			'type' => 'eventlist',
			'display_where' => 'widget',
			'header' => '',
			'entry' => '<div class="event_list_wrapper">' . PHP_EOL .
			'<div class="event_date_text">{DATETIME_LONG}</div>' . PHP_EOL .
			'<a href="/veranstaltung/{EVENT_ID}/">' . PHP_EOL .
			'<div class="event_title">{TITLE}</div>' . PHP_EOL .
			'[[?LOCATION_WITH_ROOM:<div class="event_location">{LOCATION_WITH_ROOM}</div>]]' . PHP_EOL .
			'</a>' . PHP_EOL .
			'</div>',
			'separator' => '',
			'footer' => ''
		),
		$arr_data_formats
	);
}
?>