<?php
/* Seiten-Rendering für die Verowa Admin-Seite, wo zum Beispiel der API-Key eingetragen wird.
 *
 */

function verowa_options_configuration_page() {
	// nur falls ein API-Key übergeben wurde, wird auch gespeichert!
	if ( isset( $_POST['verowa_api_key'] ) ) {
		// keine Validierung, da Form nur für Admins zugänglich
		check_admin_referer( 'verowa_admin_page' );

		// Optionsblock "Allgemein"
		$instance = sanitize_key( $_POST['verowa_instance'] );
		update_option( 'verowa_instance', $instance );

		$api_key = sanitize_text_field( $_POST['verowa_api_key'] );
		update_option( 'verowa_api_key', $api_key );

		// Optionsblock "Veranstaltungen"
		update_option( 'show-to-time', isset( $_POST['show-to-time'] ) ? 'on' : false);
		update_option( 'show_organizer', isset( $_POST['show_organizer'] ) ? 'on' : false);
		
		// Optionsblock "Personen"
		update_option( 'verowa_person_has_detail_page',
			isset( $_POST['verowa_person_has_detail_page'] ) ? 'on' : false );
		update_option( 'verowa_person_show_group_function',
			isset( $_POST['verowa_person_group_function'] ) ? 'on' : false );
		update_option( 'verowa_person_show_profession',
			isset( $_POST['verowa_person_profession'] ) ? 'on' : false );
		update_option( 'verowa_person_show_address',
			isset( $_POST['verowa_person_address'] ) ? 'on' : false );
		update_option( 'verowa_person_show_person_email',
			isset( $_POST['verowa_person_email'] ) ? 'on' : false );
		update_option( 'verowa_person_show_person_phone',
			isset( $_POST['verowa_person_phone'] ) ? 'on' : false );
		update_option( 'verowa_person_show_short_desc',
			isset( $_POST['verowa_person_short_desc'] ) ? 'on' : false );
	}

	// Personlist Templates
	if ( isset( $_POST['verowa_select_template_personlist'] ) ) {
		update_option( 'verowa_default_personlist_template', intval( $_POST['verowa_select_template_personlist'] ) );
	}

	// Persondetails Templates
	if ( isset( $_POST['verowa_select_template_persondetails'] ) ) {
		update_option( 'verowa_default_persondetails_template', intval( $_POST['verowa_select_template_persondetails'] ) );
	}

	// Eventlist Templates
	if ( isset( $_POST['verowa_select_template_eventlist'] ) ) {
		update_option( 'verowa_default_eventlist_template', intval( $_POST['verowa_select_template_eventlist'] ) );
	}

	// Eventdetails Templates
	if ( isset( $_POST['verowa_select_template_eventdetails'] ) ) {
		update_option( 'verowa_default_eventdetails_template', intval( $_POST['verowa_select_template_eventdetails'] ) );
	}

	// alles neu aus der DB laden
	$instance = get_option( 'verowa_instance', true );
	$api_key = get_option( 'verowa_api_key', true );
	$show_to_time = get_option( 'show-to-time', false );
	$show_organizer = get_option( 'show_organizer', 'on' );
	
	$person_detail_page = get_option( 'verowa_person_has_detail_page', false );
	$person_group_function = get_option( 'verowa_person_show_group_function', false );
	$person_profession = get_option( 'verowa_person_show_profession', false );
	$person_address = get_option( 'verowa_person_show_address', false );
	$person_email = get_option( 'verowa_person_show_person_email', false );
	$person_phone = get_option( 'verowa_person_show_person_phone', false );
	$person_short_desc = get_option( 'verowa_person_show_short_desc', false );

	$int_personlist_default_template = get_option( 'verowa_default_personlist_template', 0 );
	$int_persondetails_default_template = get_option( 'verowa_default_persondetails_template', 0 );
	$int_eventlist_default_template = get_option( 'verowa_default_eventlist_template', 0 );
	$int_eventdetails_default_template = get_option( 'verowa_default_eventdetails_template', 0 );


	echo '<div class="wrap">' .
		' <img src="' . plugins_url( '../images/verowa.png', __FILE__ ) . '" />' .
		'<h1>' . __( 'Verowa options', 'verowa-connect' ) . '</h1>' .
		'<div id="verowa-import-layer-message"></div>' . 
		'<form action="" method="POST">';

	// Optionsblock "Allgemein"
	echo '<div class="card">' .
		'<strong>' . __( 'General', 'verowa-connect' ) . '</strong>' .
		'<table>' .
		'<tr><td>' . __( 'Parish ID', 'verowa-connect' ) . '</td>' .
		'<td><input type="text" name="verowa_instance" style="width:400px;" value="' . esc_attr( $instance ) .
		'" /></td></tr>' .

		'<tr><td>' . __( 'API key', 'verowa-connect' ) . '</td>' .
		'<td><input type="text" name="verowa_api_key" style="width:400px;" value="' . esc_attr( $api_key ) .
		'" /></td></tr>' .
		
		'</table>'. wp_nonce_field( 'verowa_admin_page' ) .
		'</div>';
	
	// Optionsblock "Veranstaltungen"
	echo '<div class="card">' .
		'<strong>' . __( 'Events', 'verowa-connect' ) . '</strong><br />';

		
	echo verowa_checkbox_html(
		array(
			'name' => 'show-to-time',
			'text' => __( 'Show ending time', 'verowa-connect' ),
			'value' => $show_to_time
		)
	);
	
	echo verowa_checkbox_html(
		array(
			'name' => 'show_organizer',
			'text' => __( 'Show contact person', 'verowa-connect' ),
			'value' => $show_organizer
		)
	);
	

	if ( function_exists( 'verowa_section_for_importing_layers' ) ) {
		verowa_section_for_importing_layers( $instance, $api_key );
	}

	echo '</div>';

	// Display the dropdown for the Default Personlist Template
	echo '<div class="card">' . 
		'<br /><strong>' . __( 'Default Personlist Template', 'verowa-connect' ) . '</strong><br />' .
		verowa_show_template_dropdown( 'personlist', $int_personlist_default_template ) . '</br>' . 
		verowa_person_options_html() . '<br />';

	// Display the dropdown for the Default Personlist Template
	echo '<br /><strong>' . __( 'Default Persondetails Template', 'verowa-connect' ) . '</strong><br />' .
		verowa_show_template_dropdown( 'persondetails', $int_persondetails_default_template ) . '<br />';

	// Display the dropdown for the Default Personlist Template
	echo '<br /><strong>' . __( 'Default Eventlist Template', 'verowa-connect' ) . '</strong><br />' .
		verowa_show_template_dropdown( 'eventlist', $int_eventlist_default_template ) . '<br />';

	// Display the dropdown for the Default Personlist Template
	echo '<br /><strong>' . __( 'Default Eventdetails Template', 'verowa-connect' ) . '</strong><br />' .
		verowa_show_template_dropdown( 'eventdetails', $int_eventdetails_default_template )  . '</div>';


	// Submit-Button
	echo '<div class="card">' .
		'<input type="submit" value="' . __( 'Save Options', 'verowa-connect' ) . '" ' .
			'class="button button-primary" />' .
		'</div>' .
		'</form>';	
		
	echo '</div>';
}

function verowa_person_options_html() {
	global $post, $wpdb;

	$selected_template_id = isset( $_POST['verowa_select_show_person_template'] ) ? 
		intval( $_POST['verowa_select_show_person_template'] ) : get_option( 'verowa_show_person_template_default' );

	if ( $post->ID > 0 && get_post_meta( $post->ID, 'verowa_has_person_options_on_post_level', false ) ) {
		$person_detail_page = get_post_meta( $post->ID, 'verowa_person_has_detail_page', true ) == true ? 'on' : '';
		$person_group_function = get_post_meta( $post->ID, 'verowa_person_show_group_function', true ) == true ? 'on' : '';
		$person_profession = get_post_meta( $post->ID, 'verowa_person_show_profession', true ) == true ? 'on' : '';
		$person_address = get_post_meta( $post->ID, 'verowa_person_show_address', true ) == true ? 'on' : '';
		$person_email = get_post_meta( $post->ID, 'verowa_person_show_person_email', true ) == true ? 'on' : '';
		$person_phone = get_post_meta( $post->ID, 'verowa_person_show_person_phone', true ) == true ? 'on' : '';
		$person_short_desc = get_post_meta( $post->ID, 'verowa_person_short_desc', true ) == true ? 'on' : '';
	} else {
		$person_detail_page = get_option( 'verowa_person_has_detail_page', false ) == true ? 'on' : '';
		$person_group_function = get_option( 'verowa_person_show_group_function', false ) == true ? 'on' : '';
		$person_profession = get_option( 'verowa_person_show_profession', false ) == true ? 'on' : '';
		$person_address = get_option( 'verowa_person_show_address', false ) == true ? 'on' : '';
		$person_email = get_option( 'verowa_person_show_person_email', false ) == true ? 'on' : '';
		$person_phone = get_option( 'verowa_person_show_person_phone', false ) == true ? 'on' : '';
		$person_short_desc = get_option( 'verowa_person_show_short_desc', false ) == true ? 'on' : '';
	}

	$html_return = '<br /><strong>' . __( 'Personlist Template Options', 'verowa-connect' ) . '</strong><br />';

	verowa_db_update_person_group();
	
	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_has_detail_page',
			'text' => __( 'WITHOUT detail pages', 'verowa-connect' ),
			'value' => $person_detail_page
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_group_function',
			'text' => __( 'Show group function', 'verowa-connect' ),
			'value' => $person_group_function
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_short_desc',
			'text' => __( 'Show short text', 'verowa-connect' ),
			'value' => $person_short_desc
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_profession',
			'text' => __( 'Show profession', 'verowa-connect' ),
			'value' => $person_profession
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_address',
			'text' => __( 'Show address', 'verowa-connect' ),
			'value' => $person_address
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_email',
			'text' => __( 'Show e-mail', 'verowa-connect' ),
			'value' => $person_email
		)
	);

	$html_return .= verowa_checkbox_html(
		array(
			'name' => 'verowa_person_phone',
			'text' => __( 'Show phone number', 'verowa-connect' ),
			'value' => $person_phone
		)
	);

	return $html_return;
}


// Hilfsfunktion, um die Checkboxen als markiert auszuzeichnen
function verowa_checkbox_html( $args ) {
	$str_html = '<label><input type="checkbox" name="' . $args['name'] . '" style="margin-right: 10px"';
	$str_html .= ( 'on' == $args['value']) ? ' checked' : '';
	$str_html .= ' />' . $args['text'] . '</label><br />';

	return $str_html;
}


function verowa_db_update_person_group() {
	global $wpdb;

	$select_groups_query = 'SELECT `post_id` FROM `' . $wpdb->prefix . 'postmeta` WHERE `meta_key` = "_verowa_person_assign" AND `meta_value` = "persongroup";';
	$arr_person_groups = $wpdb->get_results( $select_groups_query, ARRAY_A );

	// post ids mit gruppen 612, 604, 156, 2086, 2114, 2116, 2118, 2120, 2122, 2124, 2126
	foreach ( $arr_person_groups as $single_group ) {
		$int_group_id = get_post_meta( intval( $single_group['post_id'] ), '_verowa_person_group', true );
		
		update_post_meta( intval( $single_group['post_id'] ), '_person_singles', array( 0 => 'group-' . $int_group_id ) );

	}
}
?>