<?php
namespace Ppg\Verowa_Connect;
use Stripe\Error\Base;

/**
 * Require a instance for each form field.
 *
 * verowa_formfields_rendering description.
 *
 * @version 1.0
 * @author mipfi
 */
class Verowa_Formfields_Rendering
{
	private $str_input_type;
	private $arr_default_value;
	private $str_options;
	private $str_required;
	private $str_helptext_html;
	private $arr_all_options;
	private $field_value;
	private $arr_single_formfield;
	private $str_placeholder;
	private $str_field_name;

	public function __construct($arr_single_formfield, $str_input_group = '') {
		$this->arr_default_value = [];
		$this->str_default_value = '';
		$this->arr_single_formfield = $arr_single_formfield;
		$this->str_placeholder = '';
		$this->str_input_type = $arr_single_formfield['type'];

		// == wegnehmen falls es sie gibt
		$this->str_options = false !== strpos( $arr_single_formfield['options'], '==' ) ?
				substr( $arr_single_formfield['options'], 0, -2 ) : $arr_single_formfield['options'];

		$str_key_required = array_key_exists('is_required', $arr_single_formfield)  ? 'is_required' : 'required';
		$this->str_required = $arr_single_formfield[$str_key_required] == 1 ? '&nbsp;*' : '';

		$this->str_field_name = key_exists('field_name', $this->arr_single_formfield) ?
			$this->arr_single_formfield['field_name'] : 'field_' . $this->arr_single_formfield['field_id'];

		if('' != $str_input_group)
		{
			$str_sub_feld_name = $this->str_field_name;
			$this->str_field_name = $str_input_group . '[' . $this->str_field_name . ']';
		}

		// helptext auslesen
		if(false !== strpos($this->arr_single_formfield['helptext'], '}') &&
			'{' !== $this->arr_single_formfield['helptext'][0])
		{
			$str_helptext_html = preg_split( '/[{}]/', $this->arr_single_formfield['helptext'],
				-1, PREG_SPLIT_NO_EMPTY)[0];

			$this->str_helptext_html = strlen( $str_helptext_html ) > 0 ?
				'<i class="fa fa-question-circle" aria-hidden="true" style="font-size: 15px;" title="' .
				$str_helptext_html . '"></i>' : '';
		}
		elseif('{' !== $this->arr_single_formfield['helptext'][0])
		{
			$this->str_helptext_html = strlen( $arr_single_formfield['helptext'] ) > 0 ?
				'<i class="fa fa-question-circle" aria-hidden="true" style="font-size: 15px;" title="' .
				$arr_single_formfield['helptext'] . '"></i>' : '';
		}


		// Default Wert auslesen /(.*)({.*})(.*)/
		if(key_exists('default_value', $arr_single_formfield))
		{
			$this->str_default_value = $arr_single_formfield['default_value'];
			if( strpos($this->str_default_value, '}') !== false &&
				strpos($this->str_default_value, '{') !== false ) {
				$this->str_default_value =
					preg_split( '/[{}]/', $this->arr_single_formfield['default_value'], -1, PREG_SPLIT_NO_EMPTY )[0];
			}

		} elseif ( false !== strpos( $this->str_options, '{' ) && false !== strpos( $this->str_options, '}' ) ) {
			$this->str_options = substr( $this->str_options, 0, -1 );

			$this->arr_all_options = explode( '{', $this->str_options );

			$this->str_options = $this->arr_all_options[0];
			$this->str_default_value = $this->arr_all_options[1];
		}


		// Label und Shorttitle trennen im Formular nehmen wir den ganzen Titel
		if ( strpos( $arr_single_formfield['label'], '{{' ) !== false &&
			strpos( $arr_single_formfield['label'], '}}' ) !== false ) {
			$arr_title_pieces = verowa_separate_subs_label_shorttitle( $arr_single_formfield['label'] );

			$arr_single_formfield['label'] = $arr_title_pieces[0];
		}

		if('' != $str_input_group)
		{
			// Feldwert setzen falls es ihn gibt
			$this->field_value = isset( $_POST[$str_input_group][$str_sub_feld_name] ) ?
				$_POST[$str_input_group][$str_sub_feld_name] : $str_default_value;
		}
		else
		{
			// Feldwert setzen falls es ihn gibt
			$this->field_value = isset( $_POST[$this->str_field_name] ) ?
				$_POST[$this->str_field_name] : $str_default_value;
		}


	}



	public function print_input_control($str_input_group = '') {
		echo $this->handle_control_request();
	}




	public function get_input_control_html($str_input_group = '') {
		return $this->handle_control_request();
	}




	/**
	 * Returns a HTML string with the input controls depending on the type.
	 *
	 * @param string $str_input_type
	 *
	 * @return string
	 */
	protected function handle_control_request () {
		$str_html = '';

		// Welcher Typ hat das Feld?
		switch ( $this->str_input_type ) {
			case 'checkbox':
				$str_html = $this->get_checkbox_input();
				break;
			case 'contact':
				$str_html = $this->get_contact_input();
				break;
			case 'date':
				$str_html = $this->get_date_input();
				break;
			case 'datetime':
				$str_html = $this->get_datetime_input();
				break;
			case 'dropdown':
				$str_html = $this->get_dropdown_input();
				break;
			case 'email':
				$str_html = $this->get_general_input('ct-input' , 'email');
				break;
			case 'fieldprop':
				$str_html = $this->get_fieldprop_input();
				break;
			case 'hidden':
				$str_html = $this->get_hidden_input();
				break;
			case 'radio':
				$str_html = $this->get_radio_input();
				break;
			case 'seats':
			case 'number':
				$str_html = $this->get_number_input();
				break;
			case 'text':
				$str_html = $this->get_text_input();
				break;
			case 'tel':
			case 'phone':
				$this->str_placeholder = 'placeholder="079 123 45 67"';
				$str_html = $this->get_general_input('ct-input-phone' , 'tel');
				break;
			case 'time':
				$str_html = $this->get_general_input('ct-input ct-input-time' , 'time');
				break;
			case 'multiple_choice':
				$str_html = $this->get_multiple_choice();
				break;
			case 'title':
				$str_html = '<div class="ct-title">' .
				str_replace( '[%title%]', $this->arr_single_formfield['label'], $this->str_options ) .
				'</div>';
				break;
			//default:
			//    echo '<pre>' . print_r($this, true) . '</pre>';
			//    break;
		}

		return $str_html;
	}




	private function get_text_input() {
		$str_html = '<div class="ct-input">' .
			'<label for="' . $this->str_field_name . '">' .
			__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;' .
			$this->str_helptext_html . '</label>';

		if ( intval( $this->str_options ) > 100 ) {
			$str_html .= '<textarea name="' . $this->str_field_name .
			'" id="' . $this->str_field_name . '" ' . $this->str_placeholder . '>' .
			$this->field_value . '</textarea>';
		} else {

			$str_html .= '<input type="text" name="' . $this->str_field_name .
			'" id="' . $this->str_field_name . '" ' . $this->str_placeholder . ' value="' .
			$this->field_value . '"/>';
		}

		$str_html .= '</div>';

		return $str_html;
	}




	private function get_number_input() {
		$arr_formfield_options = explode( ';', $this->str_options );

		$int_min = $arr_formfield_options[0];
		$int_max = $arr_formfield_options[1];

		$str_html = '<div class="ct-input"><label for="' . $this->str_field_name . '">' .
		__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;' .
		$this->str_helptext_html . '</label><input type="number" name="' . $this->str_field_name . '"' .
		' id="' . $this->str_field_name . '" value="' . $this->field_value . '" ' .
		'min="' . $int_min . '" max="' . $int_max . '" /></div>';

		return $str_html;
	}




	private function  get_dropdown_input() {
		$str_html = '<div><label for="' . $this->str_field_name . '">' .
			__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;</label>';

		$str_html .= '<select id="' . $this->str_field_name . '" name="' .
			$this->str_field_name . '" style="width: auto;" >';

		$this->arr_formfield_options = explode( PHP_EOL, $this->str_options );

		$str_selected = '';

		for ( $i = 0; $i < count( $this->arr_formfield_options ); $i++ ) {
			$this->str_selected = $this->field_value == trim( $this->arr_formfield_options[$i] ) ?
				'selected' : '';

			$str_html .= '<option value="' . trim( $this->arr_formfield_options[$i] ) . '" ' . $str_selected . ' >' .
				$this->arr_formfield_options[$i] . '</option>';
		}

		$str_html .= '</select>' . $this->str_helptext_html . '</div>';

		return $str_html;
	}




	private function get_fieldprop_input()
	{
		$str_html = $this->arr_single_formfield['custom_fields'];
		$str_options = explode(';', $this->str_options);
		foreach($str_options as $int_ff_id){
			if( 'fieldprop' != $this->arr_single_formfield[$int_ff_id]['type'] ){
				$obj_formfields = new Verowa_Formfields_Rendering($this->arr_single_formfield[$int_ff_id]);
				$str_field_html = $obj_formfields->get_input_control_html();
			}

			$str_html = str_replace('[[' . $int_ff_id . ']]', $str_field_html, $str_html);
		}
		return $str_html;
	}




	private function get_checkbox_input() {
		$str_selected = $this->field_value == 'on' ? 'checked' : '';

		return '<div class="ct-input verowa-single-checkbox">' .
			'<label for="cf_cb_id_' . $this->arr_formfield_options[$i] . '">' .
			'<input type="hidden" name="' . $this->str_field_name . '[]" value="off" />' .
			'<input type="checkbox" name="' . $this->str_field_name .'[]" id="cf_cb_id_'
			. $this->arr_formfield_options[$i] . '" value="' . $this->arr_formfield_options[$i] .
			'" ' . $str_selected . ' />' . trim($this->arr_formfield_options[$i] .
			$this->arr_single_formfield['label'] . $this->str_required) . '&nbsp;' . $this->str_helptext_html .
			'</label></div>';
	}




	private function get_radio_input() {

		$str_html = '<div class="ct-input verowa-input-radio">';
		$int_field_id = $this->arr_single_formfield['field_id'];

		$this->arr_formfield_options = explode( '\r\n', $this->str_options );

		$str_html .= '<label for="' . $this->str_field_name . '">' .
			__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;' .
			$this->str_helptext_html . '</label>' .
			'<div class="subs-input-radio-container">';

		$str_selected = '';

		for ( $i = 0; $i < count( $this->arr_formfield_options ); $i++ ) {
			if( strpos($this->arr_formfield_options[$i], ';') > 0 )
			{
				$arr_field_value = explode( ';', $this->arr_formfield_options[$i]);
				$str_field_value = $arr_field_value[0];
				$str_option = $arr_field_value[1];
			}
			else
			{
				$str_field_value = $this->arr_formfield_options[$i];
				$str_option = $this->arr_formfield_options[$i];
			}

			$str_selected = $this->field_value == $str_field_value ? 'checked' : '';

			$str_html .= '<div class="subs-input-radio"><label for="cf_rb_id_' . $int_field_id
				. '_' . $i . '">';

			$str_html .= '<input type="radio" name="' . $this->str_field_name .
				'" id="cf_rb_id_' . $int_field_id . '_' . $i . '" ' .
				'value="' . $str_field_value . '" ' . $str_selected . ' />&nbsp;' .
				$str_option . '</br>' .
				'</label></div>';
		}

		$str_html .= '</div></div>';

		return $str_html;
	}




	private function get_date_input() {
		$this->arr_formfield_options = explode( ';', $this->str_options );

		$date_min = $this->arr_formfield_options[0];
		$date_max = $this->arr_formfield_options[1];

		$str_html = '<div class="ct-input"><label for="' . $this->str_field_name . '">' .
			__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;' .
			$this->str_helptext_html . '</label></br><input type="date" name="' . $this->str_field_name . '" ' .
			'id="' . $this->str_field_name . '" value="' . $this->field_value . '" ' .
			'min="' . $date_min . '" max="' . $date_max . '" /></div>';

		return $str_html;
	}




	private function get_datetime_input()
	{
		$str_div_class = $this->arr_single_formfield['related_fields'] != '' ? 'ff_renting_' . $this->arr_single_formfield['related_fields'] : '';
		$str_affected = $this->arr_single_formfield['affected_items'] != '' ? 'data-affecteditems="' . $this->arr_single_formfield['affected_items'] . '"' : '';

		$str_html = '<div style="padding: 5px 0px;" class="' . $str_div_class . '" ' . $str_affected . ' ><label for="' .
		$this->str_field_name . '_' . $this->arr_single_formfield['field_id'] . '">' . $this->arr_single_formfield['display_name'] . '&nbsp;' . $this->str_required .
		'<input type="date" name="' . $str_arr_field_name . '[' . $this->str_field_name . '_date]" id="' . $this->str_field_name .
		'_' . $this->arr_single_formfield['field_id'] . '"/></label>&nbsp;von:&nbsp;<input type="time" name="' . $str_arr_field_name .
		'[' . $this->str_field_name . '_von]"/>&nbsp;bis:&nbsp;<input type="time" name="' .
		$str_arr_field_name . '[' . $this->str_field_name . '_bis]"/></div>';

		return $str_html;
	}




	private function get_contact_input() {
		$str_checked = $_POST['billing_is_different'] == 'on' ? 'checked' : '';
		$has_billing = $this->arr_single_formfield['options'] == 'no_billing' ? false : true;
		$str_html = '<div class="vc_renting_form_address_wrapper" >';

		if(strlen(trim($this->arr_single_formfield['label'])) > 0)
		{
			'<h3>' . $this->arr_single_formfield['label'] . '</h3>';
		}

		if($has_billing) {
			$str_html .= '<div><label for="diffrent_contact"><input type="hidden" name="billing_is_different" value="off"/>' .
				'<input type="checkbox" name="billing_is_different" id="diffrent_contact" value="on" ' . $str_checked .
				' />&nbsp;abweichende Rechnungsadresse</label></div>';
		}

		$str_html .= '<div class="vc_renting_form_contact_wrapper">';

		if ( key_exists('renting_persons_contact', $this->arr_single_formfield) &&
			 count( $this->arr_single_formfield['renting_persons_contact'] ) > 0 ) {
			$str_title_style = $str_checked == 'checked' ? '' : 'display: none;';

			$str_html .= '<div id="renting-persons" style="width: 50%; padding-right: 7.5px;">';
			$str_html .= '<h4 style="' . $str_title_style . '" id="rentin-persons-billing-title">Kontakt</h4>';

			foreach ( $this->arr_single_formfield['renting_persons_contact'] as $renting_form_field ) {
				// Prevents a recursive call
				if('contact' != $renting_form_field['type'])
				{
					$obj_formfields = new Verowa_Formfields_Rendering($renting_form_field, 'arr_renting_persons_contact');
					$str_html .= $obj_formfields->get_input_control_html();
				}
			}

			$str_html .= '</div></div>';
		}

		if ( $has_billing && key_exists('renting_persons_billing', $this->arr_single_formfield) &&
			count( $this->arr_single_formfield['renting_persons_billing'] ) > 0 ) {
			$str_display_style = $str_checked == 'checked' ? '' : 'display: none;';

			$str_html .= '<div id="renting-persons-billing" style="' . $str_display_style . ' width: 50%; padding-left: 7.5px;">';

			$str_html .= '<h4>Rechnung</h4>';

			foreach ( $this->arr_single_formfield['renting_persons_billing'] as $renting_form_field ) {
				// Prevents a recursive call
				if('contact' != $renting_form_field['type'])
				{
					$obj_formfields = new Verowa_Formfields_Rendering($renting_form_field, 'arr_renting_persons_billing');
					$str_html .= $obj_formfields->get_input_control_html();
				}
			}

			$str_html .= '</div>';
		}

		$str_html .= '</div>';

		return $str_html;
	}




	private function get_multiple_choice()
	{
		$arr_cb_options = explode( '\r\n', $this->str_options );

		$str_div_class = $this->arr_single_formfield['related_fields'] != '' ? 'ff_renting_' . $this->arr_single_formfield['related_fields'] : '';
		$str_affected = $this->arr_single_formfield['affected_items'] != '' ? 'data-affecteditems="' . $this->arr_single_formfield['affected_items'] . '"' : '';

		$str_html .= '<div class="multiple-choice-block"><h4>' . $this->arr_single_formfield['label'] . '&nbsp;' . $this->str_required . '</h4>';

		$counter = 0;
		$str_checked = '';
		$arr_default_values = [];

		if ( $this->arr_single_formfield['default_value'] != '' ) {
			$default_value = preg_split( '/[{}]/', $this->arr_single_formfield['default_value'], -1, PREG_SPLIT_NO_EMPTY );

			$arr_default_values = explode( ';', $default_value[0] );
		}

		foreach ( $arr_cb_options as $cb_option ) {
			$counter++;

			if ($counter % 2 == 0) {
				$str_class = 'rf-option-right';
			} else {
				$str_class = 'rf-option-left';
			}

			$arr_value_name = explode(';', $cb_option);

			if ( $_POST[$this->str_field_name][$this->str_field_name] != '' ) {
				$str_checked = in_array( $arr_value_name[0], $_POST[$this->str_field_name][$this->str_field_name] ) ? 'checked' : '';
			} else if ( count( $arr_default_values ) > 0 ) {
				$str_checked = in_array( $arr_value_name[0], $arr_default_values ) ? 'checked' : '';
			}

			$display_name = str_replace( '<br />', '', $arr_value_name[1] );

			$str_html .= '<div><label for="' . $display_name . '_' . $this->arr_single_formfield['field_id'] . '">' .
				'<input type="checkbox" name="' . $this->str_field_name . '[]" value="' .
				$arr_value_name[0] . '" id="' . $display_name . '_' . $this->arr_single_formfield['field_id'] . '" ' . $str_checked .
				' />&nbsp;' . $display_name . '</label></div>';

		}

		$str_html .= '</div>';
		return $str_html;
	}



	private function get_hidden_input()
	{
		return '<input type="hidden" name="' . $this->str_field_name . '" value="' .
			$this->str_default_value . '"/>';
	}




	private function get_general_input($str_wrapper_class, $str_type)
	{
		$str_html = '<div class="' . $str_wrapper_class . '"><label for="' . $this->str_field_name . '">' .
		__( $this->arr_single_formfield['label'], 'verowa-subscriptions' ) . $this->str_required . '&nbsp;' .
		$this->str_helptext_html . '</label><input type="' . $str_type . '" name="' . $this->str_field_name .
		'" id="' . $this->str_field_name . '" value="' . $this->field_value . '"/></div>';
		return $str_html;
	}
}