<?php
/**
 * Funktionen die überall nützlich sind
 *
 */

/**
 * Parses the template and fills in the values
 *

 * HINT: Diese Funktion ist noch noch für wahnsinnige Geschwindigkeit ausgelegt. Falls das dereint ein Problem
 * werden sollte, kann folgendes Konzept implementiert werden:
 * 1. Eine Funktion vorlagern, die via Regex im Template alle Placeholder sucht (bei den IFs und die {Texte}!)
 *    und sie in ein Array schreibt. (Das gibt zwar EINMAL mehr Aufwand, dafür sparen wir den später 50-MAL.
 *    Ausserdem wird damit unser Code save vor exzessiven Placeholder-Variationen, weil wir für zusätzliche
 *    Placeholder nur Zeit brauchen, wenn sie effektiv gebraucht werden. Nice!)
 * 2. Dann füllen wir in der Foreach-Schleife nur noch die Placeholder, die für das Template effektiv verwendet
 *    werden. (Denn wenn wir nichts Unnötiges ins Placeholder-Array schreiben, müssen wir damit später auch
 *    keinen str_replace durchführen!)
 *
 * @param mixed $str_code
 * @param mixed $arr_placeholders
 * @return mixed
 *
 */
function verowa_parse_template( $str_code, $arr_placeholders ) {
	$str_cond_beginning = '[[?';
	$str_cond_ending = ']]';
	$str_else_separator = '||';
	$str_cond_separator = ':';

	// examples in templates:
	// "<h1>{TITLE}</h1>"
	// "Kontakt: {ORGANIZER_NAME}"
	// "[[?COORGANIZER_NAMES:<p class="coorgs">Mitwirkende: {COORGANIZER_NAMES}</p>]]"
	// "Art: [[?LAYER_IDS % ;1;:Gottesdienst||Veranstaltung]]"

	if ( strlen( $str_code ) > 0 ) {

		// HINT: Whenever we need special conditions (e.g. whether something is > 1) we just prepare another key
		// (e.g. HAS_MULTIPLE_COORGANIZERS).

		// LATER: Tests should also be negatible with ! and combinable with AND or OR.

		// the conditions are processed only if there is the same amount of opening and closing brackets
		$count_cond_beginnings = substr_count( $str_code, $str_cond_beginning );
		$count_cond_endings = substr_count( $str_code, $str_cond_ending );

		if ( $count_cond_beginnings == $count_cond_endings ) {
			while ( $count_cond_beginnings > 0 ) {
				// we always start with the innermost condition; so we search for the first closing brackets and
				// the corresponding opening brackets––they are the closest ones on the left-hand side
				$pos_first_cond_ending = strpos( $str_code, $str_cond_ending );

				$pos_matching_cond_beginning = strrpos(
					substr( $str_code, 0, $pos_first_cond_ending ),
					$str_cond_beginning
				);

				// now we want a substring with the whole condition but without the brackets, e.g.
				// "LOCATIONS:<div class="event_location">{LOCATIONS}</div>"
				$str_curr_condition = substr(
					$str_code,
					$pos_matching_cond_beginning + strlen( $str_cond_beginning ),
					$pos_first_cond_ending - $pos_matching_cond_beginning - strlen( $str_cond_beginning )
				);

				// this string we divide at the position of the separator in the key (left) and the content (right)
				// (if there is no separator, we flush the whole part)
				$pos_first_cond_separator = strpos ($str_curr_condition, $str_cond_separator);
				$str_content = '';

				if ( $pos_first_cond_separator !== false ) {
					$str_key = trim( substr( $str_curr_condition, 0, $pos_first_cond_separator ) );

					$condition_is_true = false;

					// do we find a "="? (e.g. "LOCATIONS=Ref. Kirche Brugg");
					// if so, we try to match the value with the value of the corresponding placeholder
					if ( strpos( $str_key, '=' ) > 0) {
						$arr_key_parts = explode('=', $str_key);
						$arr_key_parts[0] = trim( $arr_key_parts[0] );
						if ( array_key_exists( $arr_key_parts[0], $arr_placeholders ) &&
							$arr_placeholders[$arr_key_parts[0]] == trim( $arr_key_parts[1] ) ) {
							$condition_is_true = true;
						}
					}

					// else we look if we find a "%" (e.g. "LAYER_IDS % ;6;");
					// if so, we try to find the value as part of the correspondig placeholder value
					// (this can be an array or a string)
					else if ( strpos( $str_key, '%' ) > 0) {
						$arr_key_parts = explode('%', $str_key);
						$arr_key_parts[0] = trim( $arr_key_parts[0] );
						$arr_key_parts[1] = trim( $arr_key_parts[1] );
						if ( array_key_exists( $arr_key_parts[0], $arr_placeholders ) ) {
							if ( is_array( $arr_placeholders[$arr_key_parts[0]] ) ) {
								if ( in_array( $arr_key_parts[1], $arr_placeholders[$arr_key_parts[0]] ) ) {
									$condition_is_true = true;
								}
							} else {
								if ( strpos( $arr_placeholders[$arr_key_parts[0]], $arr_key_parts[1] ) !== false ) {
									$condition_is_true = true;
								}
							}
						}
					}

					// otherwise we just need to check if the value is not empty
					else if ( array_key_exists( $str_key, $arr_placeholders ) && strlen( $arr_placeholders[$str_key]) > 0 ) {
						$condition_is_true = true;
					}

					// now we look, if the content has an alternative content in case the condition fails
					$str_content_raw = substr(
							$str_curr_condition,
							$pos_first_cond_separator + strlen( $str_cond_separator )
						);

					$pos_else_separator = strpos( $str_content_raw, $str_else_separator );

					if ( false === $pos_else_separator ) {
						$str_content_true = $str_content_raw;
						$str_content_false = '';
					} else {
						$str_content_true = substr( $str_content_raw, 0, $pos_else_separator);
						$str_content_false = substr( $str_content_raw,
							$pos_else_separator + strlen( $str_else_separator ) );
					}

					// if the condition matches we take its content; otherwise we take the alternative
					$str_content = true == $condition_is_true ? $str_content_true : $str_content_false;
				}

				// then we concat the string again
				$str_code = substr( $str_code, 0, $pos_matching_cond_beginning ) . $str_content .
					substr( $str_code, $pos_first_cond_ending + strlen( $str_cond_ending ) );

				// now there’s one condition less
				$count_cond_beginnings -= 1;
			}
		} else {
			return __( 'Error in template: unequal number of beginnings and ends of conditions.', 'verowa-connect' );
		}


		// ** Platzhalter ersetzen, z.B. "{LOCATIONS}"

		$arr_search = [];
		$arr_replace = [];

		foreach ( $arr_placeholders as $key => $value ) {
			$arr_search[] = '{' . $key . '}';
			$arr_replace[] = $value;
		}

		$str_code = str_replace( $arr_search, $arr_replace, $str_code );
	}

	return $str_code;
}



/**
 * Summary of verowa_get_person_template
 *
 * @param int $int_template_id
 * @param string $str_display_where
 *
 * @return array|null|object
 */
function verowa_get_person_template( $int_template_id = 0, $str_display_where = '') {
	global $wpdb;

	$person_template_query = '';
	$arr_return = [];

	if ( $int_template_id > 0 ) {
		$person_template_query .= 'SELECT * FROM `' . $wpdb->prefix . 'verowa_templates`' .
			' WHERE `template_id` = ' . $int_template_id;
	} else {
		$person_template_query .= 'SELECT * FROM `' . $wpdb->prefix . 'verowa_templates`';
	}

	if ( $str_display_where != '' ) {
		$person_template_query .= ' AND `display_where` = "' . $str_display_where . '"';
	}

	$person_template_query .= ';';

	$arr_return = $wpdb->get_results( $person_template_query, ARRAY_A );

	return $arr_return;
}


/**
 * Geht alle Seiten durch und speichert die eingetragenen Listen ids in der Option _verowa_list_assign
 *
 */
function verowa_update_list_id_option() {
	$args = array(
		'posts_per_page' => -1,
		'post_status' => 'published',
		'orderby' => 'date',
		'post_type' => 'page',
		'order' => 'DESC'
	);

	$posts = get_posts( $args );

	// Mit diesem Pattern holen wir die Listen Shortcodes mit den Attributen aus den Seiten.
	// Von dort holen wir dann die Listen ids
	$str_pattern = '/'. get_shortcode_regex( array( 'verowa_event_list', 'verowa_event_liste',
		'verowa_event_liste_dynamic', 'verowa_subscriptions_form' ) ) .'/s';
	$arr_list_ids = array();

	// Alle posts durchgehen. Wir schauen ob der Shortcode im Content hinzugefügt wurde
	// und ob eine Liste ausgewählt wurde
	foreach ( $posts as $post ) {
		$int_list_id = get_post_meta( $post->ID, '_verowa_list_assign', true );

		// Wir schauen ob für die Seite eine Liste ausgewählt wurde
		if ( $int_list_id != 0 ) {
			$arr_list_ids[] = $int_list_id;
		}

		preg_match_all( $str_pattern, $post->post_content, $arr_matches );

		// Die Shortcode Attribute werden in $arr_matches[3] gespeichert
		foreach ( $arr_matches[3] as $str_attributes ) {
			// Alle attribute separieren
			$arr_shortcode_attributes = explode( ' ', trim( $str_attributes ));

			// Den Wert vom Shortcode separieren
			foreach ( $arr_shortcode_attributes as $single_attribute ) {
				$arr_seperated_atts = explode( '=', $single_attribute );

				if ( $arr_seperated_atts[0] == 'id' ) {
					$arr_list_ids[] = intval( $arr_seperated_atts[1] );
				}
			}
		}
	}

	$arr_existing_list_ids = json_decode( get_option( 'verowa_list_ids' ), true );

	// Wir holen auch alle liste ids aus den Agenda Filter dropdowns
	$int_count_agenda_dropdowns = intval( get_option( 'how_many_verowa_dropdowns', false ) );

	for ( $i = 1; $i <= $int_count_agenda_dropdowns; $i++ ) {
		$str_agenda_list_ids = get_option( 'verowa_dropdown_' . $i, '' );

		if ( $str_agenda_list_ids != '' ) {
			$arr_agenda_list_ids = array_map( 'intval', explode( ', ', $str_agenda_list_ids ) );

			$arr_list_ids = array_merge( $arr_list_ids, $arr_agenda_list_ids );
		}
	}

	$arr_list_ids = array_unique($arr_list_ids);

	// Wenn es schon listen ids eingetragen gibt fügen wir die neuen einfach hinzu
	if ( count( $arr_existing_list_ids ) > 0 ) {
		$arr_list_ids = array_merge( $arr_existing_list_ids, $arr_list_ids );
	}

	// Updaten wenn es listen ids gibt
	if ( count( $arr_list_ids ) > 0 ) {
		update_option( 'verowa_list_ids', json_encode( array_unique( $arr_list_ids ) ) );
	}
}


/**
 * Updatet ein Event in der DB
 *
 */
function verowa_update_event_in_db( $arr_event, $bool_has_subscription, $str_hash, $arr_ids) {
	global $wpdb;

	$str_events_tablename = $wpdb->prefix . 'verowa_events';
	$arr_event_data_formats = array( '%s', '%s', '%s', '%s', '%s', '%d', '%s', '%s' );
	$arr_event_where_formats = array( '%d' );

	$arr_event_data = [
		'datetime_from' => $arr_event['date_from'],
		'datetime_to' => $arr_event['date_to'],
		'list_ids' => $arr_ids['list_ids'],
		'layer_ids' => $arr_ids['layer_ids'],
		'target_groups' => $arr_ids['target_group_ids'],
		'with_subscription' => $bool_has_subscription,
		'content' => json_encode( $arr_event ),
		'deprecated' => 0,
		'hash' => $str_hash
	];

	$ret_update = $wpdb->update(
		$str_events_tablename,
		$arr_event_data,
		array(
			'event_id' => $arr_event['event_id']
		),
		$arr_event_data_formats,
		$arr_event_where_formats
	);
}

/**
 * Insert an event into the DB
 *
 */
function verowa_insert_event_in_db( $arr_event, $bool_has_subscription, $arr_ids ) {
	global $wpdb;

	$str_events_tablename = $wpdb->prefix . 'verowa_events';

	$arr_event_insert_formats = array( '%d', '%s', '%s', '%s', '%s', '%s', '%d', '%s', '%s', '%d' );

	$str_content = json_encode( $arr_event );

	// Alles hashen. Mit dem Hash kann einfach geprüft werden ob etwas geändert wurde
	$str_hash = verowa_generate_event_hash( $arr_event, $arr_ids, $bool_has_subscription, $str_content );

	$wpdb->insert(
		$str_events_tablename,
		array(
			'event_id' => intval( $arr_event['event_id'] ),
			'datetime_from' => $arr_event['date_from'],
			'datetime_to' => $arr_event['date_to'],
			'list_ids' => $arr_ids['list_ids'],
			'layer_ids' => $arr_ids['layer_ids'],
			'target_groups' => $arr_ids['target_group_ids'],
			'with_subscription' => $bool_has_subscription,
			'content' => $str_content,
			'hash' => strval( $str_hash ),
			'deprecated' => 0
		),
		$arr_event_insert_formats
	);
}



/**
 * Insert a person into the DB
 *
 */
function verowa_insert_person_in_db( $arr_person, $str_hash ) {
	global $wpdb;

	$str_persons_tablename = $wpdb->prefix . 'verowa_person';
	$arr_person_insert_formats = array( '%d', '%s', '%s', '%d' );

	$str_content = json_encode( $arr_person );

	$wpdb->insert(
		$str_persons_tablename,
		array(
			'person_id' => $arr_person['person_id'],
			'content' => $str_content,
			'hash' => $str_hash,
			'deprecated' => 0
		),
		$arr_person_insert_formats
	);
}



/**
 * Insert a persongroup into the DB
 *
 */
function verowa_insert_persongroup_in_db( $arr_person_group, $str_person_ids, $str_members_group_functions ) {
	global $wpdb;

	$str_persongroups_tablename = $wpdb->prefix . 'verowa_person_groups';
	$arr_pgroup_insert_formats = array( '%d', '%s', '%s', '%s', '%d' );

	// Alles hashen. Mit dem Hash kann einfach geprüft werden ob etwas geändert wurde
	$str_hash = verowa_generate_persongroup_hash( $arr_person_group['group_id'],
		$str_person_ids, $str_members_group_functions );

	$wpdb->insert(
		$str_persongroups_tablename,
		array(
			'pgroup_id' => intval( $arr_person_group['group_id'] ),
			'person_ids' => $str_person_ids,
			'functions_in_group' => $str_members_group_functions,
			'hash' => $str_hash,
			'deprecated' => 0
		),
		$arr_pgroup_insert_formats
	);
}




/**
 * Get an Event from the DB
 * @param array $arr_list_id
 * @param mixed $layer_id
 * @param mixed $obj_date_from
 * @param mixed $obj_date_to
 * @param mixed $order_by
 * @param mixed $int_limit
 * @param mixed $int_offset
 * @return array[]
 */
function verowa_get_event_from_db( $arr_list_id, $layer_id, $obj_date_from = '',  $obj_date_to = '',
	$order_by = 'datetime_from ASC', $int_limit = 0, $int_offset = 0 ) {
	global $wpdb;

	$arr_ret = [];
	$str_events_tablename = $wpdb->prefix . 'verowa_events';
	$query = 'SELECT * FROM `' . $str_events_tablename . '`';

	// Setup filter
	$arr_filter = [];
	if($obj_date_from)
	{
		$arr_filter [] = '`datetime_from` >= "' .  $obj_date_from->format( "Y-m-d" ) . ' 00:00:00"';
	}

	if($obj_date_to != '')
	{
		$arr_filter [] = '`datetime_to` <= "' .  $obj_date_to->format( "Y-m-d" ) . ' 23:59:59"';
	}


	foreach ( $arr_list_id as $single_list_id ) {
		$arr_filter [] = '`list_ids` like "%;' . $single_list_id . ';%"';
	}

	if ( 0 !== count( $arr_filter ) ) {
		$query .= ' WHERE ';
		$query .= implode(' AND ', $arr_filter);
	}

	$query .= ' ORDER BY ' . $order_by;

	if ( $int_limit > 0 ) {
		$query .= ' LIMIT ' . $int_limit . ' OFFSET ' . $int_offset;
	}

	$query .= ';';

	$result = $wpdb->get_results( $query );

	foreach ( $result as $obj_event ) {
		$arr_event = [
			'event_id' => $obj_event->event_id,
			'datetime_from' => $obj_event->datetime_from,
			'datetime_to' => $obj_event->datetime_to,
			'list_ids' => $obj_event->list_ids,
			'layer_ids' => $obj_event->layer_ids,
			'target_groups' => $obj_event->target_groups,
			'with_subscription' => $obj_event->with_subscription
		];

		$arr_content = json_decode( $obj_event->content, JSON_OBJECT_AS_ARRAY );

		if ( count( $arr_content['rooms'] ) > 0 ) {
			$arr_content['room'] = $arr_content['rooms'][0];
		}

		$arr_ret[] = array_merge( $arr_event, $arr_content );
	}

	return $arr_ret;
}



/**
 * Updatet eine Person in der DB
 *
 */
function verowa_update_person_in_db( $arr_person, $str_hash ) {
	global $wpdb;

	$str_person_tablename = $wpdb->prefix . 'verowa_person';
	$arr_person_data_formats = array( '%s', '%s' );
	$arr_person_where_formats = array( '%d' );

	$wpdb->update(
		$str_person_tablename,
		array(
			'content' => json_encode( $arr_person ),
			'hash' => $str_hash
		),
		array(
			'person_id' => $arr_person['person_id']
		),
		$arr_person_data_formats,
		$arr_person_where_formats
	);
}



/**
 * Updatet eine Persongruppe in der DB
 *
 */
function verowa_update_persongroup_in_db( $arr_persongroup, $str_hash,
	$str_person_ids, $str_members_group_functions ) {

	global $wpdb;

	$str_persongroups_tablename = $wpdb->prefix . 'verowa_person_groups';
	$arr_persongroups_data_formats = array( '%s', '%s', '%s' );
	$arr_persongroups_where_formats = array( '%d' );

	$wpdb->update(
		$str_persongroups_tablename,
		array(
			'person_ids' => $str_person_ids,
			'functions_in_group' => $str_members_group_functions,
			'hash' => $str_hash
		),
		array(
			'pgroup_id' => $arr_persongroup['group_id']
		),
		$arr_persongroups_data_formats,
		$arr_persongroups_where_formats
	);
}



/**
 * Bring die target_groups, layer_ids und list_ids in ein ;1;2;3; Format zum Speichern in der DB
 *
 */
function verowa_prepare_layer_list_target_group( $arr_event, $str_list_ids ) {
	$arr_ret = array(
		'target_group_ids' => '',
		'layer_ids' => '',
		'list_ids' => ''
	);

	$arr_target_group_ids = array();
	$arr_layer_ids = array();
	$arr_list_ids_for_event = array();

	// Alle target_group ids ins Format ;1;2;3; bringen (falls target_groups beim event angegeben sind)
	if ( is_array( $arr_event['target_groups'] ) && count( $arr_event['target_groups'] ) > 0 ) {
		foreach ( $arr_event['target_groups'] as $single_target_group ) {
			$arr_target_group_ids[] = $single_target_group['id'];
		}

		$arr_ret['target_group_ids'] = ';' . implode( ';', $arr_target_group_ids ) . ';';
	}

	// Alle layer ids ins Format ;1;2;3; bringen (falls layers beim event angegeben sind)
	if ( is_array( $arr_event['layers'] ) && count( $arr_event['layers'] ) > 0 ) {
		foreach ( $arr_event['layers'] as $single_layer ) {
			$arr_layer_ids[] = $single_layer['id'];
		}

		$arr_ret['layer_ids'] = ';' . implode( ';', $arr_layer_ids ) . ';';
	}

	$arr_ret['list_ids'] = ';' . str_replace( ',', ';', $str_list_ids ) . ';';

	return $arr_ret;
}



/**
 * Generiert den md5 für ein event aus den event infos
 *
 */
function verowa_generate_event_hash( $arr_event, $arr_ids, $bool_has_subscription, $str_content ) {

	return md5( strval( $arr_event['event_id'] ) .
		';df=' . $arr_event['date_from'] . ';dt=' . $arr_event['date_to'] .
		';li=' . $arr_ids['list_ids'] . ';ly=' . $arr_ids['layer_ids'] . ';tg=' . $arr_ids['target_group_ids'] .
		';sc=' . strval( $bool_has_subscription ) . ';cn=' . $str_content );
}



/**
 * Generiert den md5 für eine person aus den personen infos
 *
 */
function verowa_generate_person_hash( $int_person_id, $str_content ) {

	return md5( $int_person_id . $str_content );
}



/**
 * Generiert den md5 für eine Personengruppe aus den personen infos
 *
 */
function verowa_generate_persongroup_hash( $int_group_id, $str_person_ids, $str_members_group_functions ) {

	return md5( $int_group_id . $str_person_ids . $str_members_group_functions );
}



/**
 * Setzt ein event auf deprecated
 *
 */
function verowa_set_event_to_deprecated( $int_event_id ) {
	global $wpdb;

	$str_events_tablename = $wpdb->prefix . 'verowa_events';
	$arr_event_data_formats = array( '%d' );
	$arr_event_where_formats = array( '%d' );

	$ret_update = $wpdb->update(
		$str_events_tablename,
		array(
			'deprecated' => 1
		),
		array(
			'event_id' => $int_event_id
		),
		$arr_event_data_formats,
		$arr_event_where_formats
	);
}



/**
 * Setzt eine Person auf deprecated
 *
 */
function verowa_set_person_to_deprecated( $int_person_id ) {
	global $wpdb;

	$str_person_tablename = $wpdb->prefix . 'verowa_person';
	$arr_person_data_formats = array( '%d' );
	$arr_person_where_formats = array( '%d' );

	$wpdb->update(
		$str_person_tablename,
		array(
			'deprecated' => 1,
		),
		array(
			'person_id' => $int_person_id
		),
		$arr_person_data_formats,
		$arr_person_where_formats
	);
}



/**
 * Setzt eine Personengruppe auf deprecated
 *
 */
function verowa_set_persongroup_to_deprecated( $int_group_id ) {
	global $wpdb;

	$str_persongroups_tablename = $wpdb->prefix . 'verowa_person_groups';
	$arr_persongroups_data_formats = array( '%d' );
	$arr_persongroups_where_formats = array( '%d' );

	$wpdb->update(
		$str_persongroups_tablename,
		array(
			'deprecated' => 1,
		),
		array(
			'pgroup_id' => $int_group_id
		),
		$arr_persongroups_data_formats,
		$arr_persongroups_where_formats
	);
}



/**
 * Get the person content from the DB
 *
 */
function verowa_get_person_content_from_db( $int_person_id ) {
	global $wpdb;

	$arr_person_data = array();

	$str_get_person_query = 'SELECT `content` FROM `' . $wpdb->prefix . 'verowa_person` WHERE `person_id` = ' .
		$int_person_id . ';';

	$arr_person_data = $wpdb->get_results( $str_get_person_query, ARRAY_A );

	return $arr_person_data[0];
}



/**
 * Get a specific template from the DB
 *
 */
function verowa_get_template( $int_template_id, $str_type = '', $str_display_where = '' ) {
	global $wpdb;

	$arr_template_data = array();
	$str_get_template_query = '';

	$str_get_template_query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_templates` WHERE `template_id` = ' .
		$int_template_id;

	if ( $str_type != '' ) {
		$str_get_template_query .= ' AND `type` = "' . $str_type . '"';
	}

	if ( $str_display_where != '' ) {
		$str_get_template_query .= ' AND `display_where` = "' . $str_display_where . '"';
	}

	$str_get_template_query .= ';';

	$arr_template_data = $wpdb->get_results( $str_get_template_query, ARRAY_A );

	$arr_return = !empty( $arr_template_data ) ? $arr_template_data[0] : [];

	return $arr_return;
}



/**
 * Get the event content from the DB
 *
 */
function verowa_get_event_content_from_db( $int_event_id ) {
	global $wpdb;

	$arr_event_data = array();

	/*
	$str_get_event_query = 'SELECT `content` FROM `' . $wpdb->prefix . 'verowa_events` WHERE `event_id` = ' .
	$int_event_id . ' AND `deprecated` = 0;';
	 */
	$str_get_event_query = 'SELECT `content` FROM `' . $wpdb->prefix . 'verowa_events` WHERE `event_id` = ' .
		$int_event_id;

	$arr_event_data = $wpdb->get_results( $str_get_event_query, ARRAY_A );

	return json_decode( $arr_event_data[0]['content'], true );
}



/**
 * Get the events from the DB
 *
 * @param string $event_ids e.g. ids '15,4,23'
 * @param string  $list_ids e.g. ids '15,4,23'
 * @param int $max_events
 * @param int $int_offset
 * @param string|DateTime $obj_date
 * @return array|null|object
 */
function verowa_get_agenda_events_from_db( $event_ids = '', $list_ids = '',
	$max_events = 0, $int_offset = 0, $obj_date = 'now' ) {
	global $wpdb;

	$arr_event_data = [];
	$arr_restrictions = [];

	if ( $obj_date === 'now' ) {
		$obj_date = new DateTime();
	}

	$arr_restrictions[] = '`datetime_to` >= "' .  $obj_date->format( 'Y-m-d H:i:s' ) . '"';

	if ( strlen( $event_ids ) > 0 ) {
		$arr_restrictions[] = '`event_id` IN (' . $event_ids . ')';
	}

	if ( strlen( $list_ids ) > 0 ) {
		$arr_restrictions[] = verowa_helper_combine_query_for_ids( 'list_ids', $list_ids, 'AND' );
	}

	$str_restrictions = count( $arr_restrictions ) == 0 ? '1' : implode( ' AND ', $arr_restrictions );
	$str_limit = $max_events > 0 ? ' LIMIT ' . $max_events : '';
	$str_limit .= $int_offset > 0 ? ' OFFSET ' . $int_offset : '';


	$str_get_event_query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_events` ' .
		'WHERE ' . $str_restrictions . ' ORDER BY `datetime_from` ASC' . $str_limit;

	$arr_event_data = $wpdb->get_results( $str_get_event_query, ARRAY_A );

	if ( count( $arr_event_data ) > 0 ) {
		for ( $i = 0; $i < count( $arr_event_data ); $i++ ) {
			$arr_event_data[$i]['content'] = json_decode( $arr_event_data[$i]['content'], true );
		}
	}

	return $arr_event_data;
}


/**
 * Get the events from the DB (Do not use for agenda)
 *
 * Ids must be separated by commas ("15,4,23").
 * Restrictions can be combined, e.g. layers and target grous.
 * If multiple list, tgroup or layer ids are given, the events must match only one of them.
 *
 * The event’s content will be parsed to a nested array, e.g. ['content']['long_desc'].
 */
function verowa_get_multiple_events_from_db( $event_ids = '', $list_ids = '', $tgoup_ids = '', $layer_ids = '',
	$max_events = 0, $int_offset = 0, $obj_date = 'now' ) {
	global $wpdb;

	$arr_event_data = [];
	$arr_restrictions = [];

	if ( $obj_date === 'now' ) {
		$obj_date = new DateTime();
	}

	$arr_restrictions[] = '`datetime_to` >= "' .  $obj_date->format( 'Y-m-d H:i:s' ) . '"';

	if ( strlen( $event_ids ) > 0 ) {
		$arr_restrictions[] = '`event_id` IN (' . $event_ids . ')';
	}

	if ( strlen( $list_ids ) > 0 ) {
		$arr_restrictions[] = verowa_helper_combine_query_for_ids( 'list_ids', $list_ids );
	}

	if ( strlen( $tgoup_ids ) > 0 ) {
		$arr_restrictions[] = verowa_helper_combine_query_for_ids( 'target_groups', $tgoup_ids );
	}

	if ( strlen( $layer_ids ) > 0 ) {
		$arr_restrictions[] = verowa_helper_combine_query_for_ids( 'layer_ids', $layer_ids );
	}

	$str_restrictions = count( $arr_restrictions ) == 0 ? '1' : implode( ' AND ', $arr_restrictions );
	$str_limit = $max_events > 0 ? ' LIMIT ' . $max_events : '';
	$str_limit .= $int_offset > 0 ? ' OFFSET ' . $int_offset : '';


	$str_get_event_query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_events` ' .
		'WHERE ' . $str_restrictions . ' ORDER BY `datetime_from` ASC' . $str_limit;

	$arr_event_data = $wpdb->get_results( $str_get_event_query, ARRAY_A );

	if ( count( $arr_event_data ) > 0 ) {
		for ( $i = 0; $i < count( $arr_event_data ); $i++ ) {
			$arr_event_data[$i]['content'] = json_decode( $arr_event_data[$i]['content'], true );
		}
	}

	return $arr_event_data;
}

/**
 *
 * @param string $field_name
 * @param string $str_ids
 * @param string $str_condition 'OR' or 'AND'
 * @return string
 */
function verowa_helper_combine_query_for_ids ($field_name, $str_ids, $str_condition = 'OR') {
	$arr_restrictions = [];
	foreach ( explode( ',', $str_ids ) as $single_id ) {
		$arr_restrictions[] = '`' . $field_name . '` LIKE "%;' . trim( $single_id ) . ';%"';
	}

	return '(' . implode(' ' . $str_condition . ' ', $arr_restrictions) . ')';
}


/**
 * Get multiple persons by id
 *
 */
function verowa_get_multiple_persons( $arr_person_ids = null) {
	global $wpdb;
	$arr_persons = array();

	$str_get_persons_query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_person`';

	if($arr_person_ids !== null)
	{
		$str_get_persons_query .= ' WHERE `person_id` IN (' .
		implode( ', ', $arr_person_ids ) . ')';
	}

	$arr_persons = $wpdb->get_results( $str_get_persons_query, ARRAY_A );

	return $arr_persons;
}



/**
 * Get all the persons for a group
 *
 */
function verowa_get_persons_for_group( $int_group_id ) {
	global $wpdb;

	$arr_persongroup_infos = array();
	$arr_group_persons = array();
	$arr_person_info = array();

	$str_get_person_ids_query = 'SELECT `person_ids`, `functions_in_group` FROM ' .
		'`' . $wpdb->prefix . 'verowa_person_groups` WHERE `pgroup_id` = ' . $int_group_id . ';';

	$arr_persongroup_infos = $wpdb->get_results( $str_get_person_ids_query, ARRAY_A );

	$arr_group_functions = json_decode( $arr_persongroup_infos[0]['functions_in_group'], true );

	// Wir entfernen das ; am Anfang und Ende des Strings
	$arr_person_ids = explode( ';',  substr( substr( $arr_persongroup_infos[0]['person_ids'],
		1, strlen( $arr_persongroup_infos[0]['person_ids'] ) - 1 ), 0, -1 ) );

	foreach ( $arr_person_ids as $person_id ) {
		$arr_person = verowa_get_person_content_from_db( $person_id );
		$arr_person_info[$person_id] = json_decode( $arr_person['content'], true );

		if ( is_array( $arr_group_functions ) && count( $arr_group_functions ) > 0 ) {
			$arr_person_info[$person_id]['function_in_group'] = strlen( $arr_group_functions[$person_id] ) > 0 ?
				$arr_group_functions[$person_id] : '';
		}
	}

	return $arr_person_info;
}



/**
 * Get all templates for a specific type
 *
 */
function verowa_get_templates_by_type( $str_template_type ) {
	global $wpdb;

	$arr_templates = array();

	$str_get_templates_query = 'SELECT * FROM `' . $wpdb->prefix . 'verowa_templates` WHERE `type` = "' .
		$str_template_type . '";';

	$arr_templates = $wpdb->get_results( $str_get_templates_query, ARRAY_A );

	return $arr_templates;
}

function verowa_general_delete_deprecated($str_table_name)
{
	global $wpdb;
	$wpdb->delete(
		$str_table_name,
		array(
			'deprecated' => 1 // value in column to target for deletion
		),
		array(
			'%d' // format of value being targeted for deletion
		)
	);
}

function verowa_date8_to_date10ch( $date8 )
{
	return substr( $date8, 6, 2 ) . '.' . substr( $date8, 4, 2 ) . '.' . substr( $date8, 0, 4 );
}