<?php

/**
 * Handle the WP DB Update. When the plugin is activate or the update cron is running
 *
 *
 * @version 1.0
 * @author PPG
 */
class Verowa_Update_Controller
{
	private $arr_list_ids_for_event;
	private $obj_debug;
	private $arr_list_ids;

	private $wordpress_liste;
	private $verowa_groups_call_string;
	private $arr_verowa_groups;
	private $str_events_tablename;

	function __construct()
	{
		global $wpdb;

		$this->str_events_tablename = $wpdb->prefix . 'verowa_events';

		/**** Hier unten tragen wir alle Events, Personen und Personengruppen in die Tabellen ein ****/
		// Zuerst müssen wir die Option welche alle listen ids tracked updaten oder erstellen (falls wir das hier das erste mal machen)
		verowa_update_list_id_option();
		$this->arr_list_ids = json_decode( get_option( 'verowa_list_ids' ), true );
		$this->arr_list_ids_for_event = verowa_api_call( 'geteventslistmap', implode( ',', $this->arr_list_ids ) .
			'/0', true );

		// Update LayerIds
		$hierarchical_array_for_dropdown = verowa_get_hierarchical_layers_tree();
		update_option( 'verowa_hierarchical_layers_tree', json_encode($hierarchical_array_for_dropdown) , false );

		// Array, um Events mit Bereichen zu versehen.
		$this->wordpress_liste = get_option( 'verowa_wordpress_listengruppe', true);
		$this->verowa_groups_call_string = $this->wordpress_liste . '-e';
		$this->arr_verowa_groups = verowa_api_call( 'getlistsbygroup', $this->verowa_groups_call_string, true );

		$this->obj_debug = new Verowa_Connect_Debugger();
	}

	public function update_agenda_filters()
	{
		$filter_array = array();

		$dropdown_count = 1;
		$nb_dropdowns = get_option( 'how_many_verowa_dropdowns', false );

		while ( $dropdown_count <= $nb_dropdowns ) {
			$filter_options = explode( ', ', get_option( 'verowa_dropdown_' . $dropdown_count, true ) );

			foreach ( $filter_options as $group_id ) {
				$group_key = array_search( $group_id, array_column( $this->arr_verowa_groups, 'list_id' ) );
				$filter_array[] = array(
					'list_id' => $this->arr_verowa_groups[$group_key]['list_id'],
					'event_ids' => explode( ',', $this->arr_verowa_groups[$group_key]['event_ids'] )
				);
			}

			$dropdown_count++;
		}

		// Call String für Events
		$verowa_call_string = '%20/0/1000'; // erstmal nur 1000 Events aus der API
		$arr_api_events = verowa_api_call( 'geteventsbylist', $verowa_call_string, true );
		$events = array();

		foreach ( $arr_api_events['events'] as $key => $value ) {
			$temp_events_cat = '';

			foreach ( $filter_array as $filter ) {
				$temp_cat = array_search( $value['event_id'], $filter['event_ids'], true );
				if ( false !== $temp_cat ) {
					$temp_events_cat .= ' .events-' . $filter['list_id'];
				}
			}

			$value['event_cats'] = $temp_events_cat;
			$events[] = $value;
		}

		if ( function_exists( 'update_option' ) ) {
			add_option( 'verowa_dynamic_agenda_filter', '' );
			add_option( 'verowa_dynamic_agenda_events', '' );
			add_option( 'verowa_dynamic_agenda_filter_array', '' );
		}

		// Eventually we need this but I guess not now...
		//wp_cache_delete ( 'alloptions', 'options' );

		if ( !empty( $this->arr_verowa_groups ) ) {
			update_option( 'verowa_dynamic_agenda_filter', json_encode($this->arr_verowa_groups) , false );
		}

		if ( !empty( $events ) ) {
			update_option( 'verowa_dynamic_agenda_events', $events, false );
		}

		if ( !empty( $filter_array ) ) {
			update_option( 'verowa_dynamic_agenda_filter_array', $filter_array, false );
		}

	}

	/**
	 * Summary of update_verowa_events_in_db
	 *
	 * @param mixed $update_event_id Nur diese Event wird abgefragt
	 */
	public function update_verowa_events_in_db($update_event_id = 0)
	{
		global $wpdb;

		$arr_api_event_ids = [];
		$arr_event = [];

		// Zuerst holen wir die IDs und die Infos für die Listenbilder (denn beim Call für die Event-DETAILS haben
		// wir nur die Infos zum Detailbild, nicht zum Listenbild);
		// eigentlich kommen hier noch mehr Infos mit, aber die brauchen wir nicht, weil sie eh mit dem Detail-Call
		// weiter unten nochmals geladen werden
		if($update_event_id > 0)
		{
			$arr_api_event_ids = [ $update_event_id ];
		}
		else
		{
			$arr_api_event_ids = verowa_api_call( 'geteventids', '', true );
		}

		if ( count($arr_api_event_ids) > 0 ) {


			$get_event_by_hash_query = 'SELECT `event_id`, `hash` FROM `' . $this->str_events_tablename . '`';
			if($update_event_id > 0)
			{
				$get_event_by_hash_query .= ' WHERE `event_id` = ' . $update_event_id;
			}
			$get_event_by_hash_query .= ';';

			$arr_obj_event_hashes = $wpdb->get_results( $get_event_by_hash_query, OBJECT_K );

			$arr_api_event_infos = 	verowa_get_eventdetails($arr_api_event_ids);

			foreach ( $arr_api_event_infos as $single_event ) {

				//Set Event Subscription
				$has_subscription = false;
				if (isset ($single_event['subscription_type']) ){
					if ( 'none' != $single_event['subscription_type'] ) {
						$has_subscription = true;
					} else {
						if ( $single_event['subscribe_person_id'] > 1 || strlen( $single_event['subscribe_date'] ) == 8 ) {
							$has_subscription = true;
						}
					}
				}

				// Listen ids, layer ids und target groups ins Format ;1;2;3; umschreiben
				$arr_ids = verowa_prepare_layer_list_target_group(
					$single_event, $this->arr_list_ids_for_event[$single_event['event_id']] );

				$arr_event[$single_event['event_id']] = $single_event;

				// set the image displayed on the detail page
				$arr_event[$single_event['event_id']]['detail_image'] = $single_event['image_url'];
				$arr_event[$single_event['event_id']]['detail_image_width'] = $single_event['image_width'];
				$arr_event[$single_event['event_id']]['detail_image_height'] = $single_event['image_height'];

				// Wenn es bereits einen Eintrag gibt, wird der Hash neu berechnet und verglichen
				if ( key_exists( $single_event['event_id'], $arr_obj_event_hashes) ) {
					$str_hash = verowa_generate_event_hash(
						$arr_event[$single_event['event_id']],
						$arr_ids,
						$has_subscription,
						json_encode( $arr_event[$single_event['event_id']] )
					);

					// Wenn die Hashes nicht übereinstimmen, gibt es Änderungen und wir updaten die DB
					if ( $arr_obj_event_hashes[$single_event['event_id']]->hash !== $str_hash ) {
						verowa_update_event_in_db(
							$arr_event[$single_event['event_id']],
							$has_subscription,
							$str_hash,
							$arr_ids
						);

					}
				} else {
					verowa_insert_event_in_db(
						$arr_event[$single_event['event_id']],
						$has_subscription,
						$arr_ids
					);
				}

				// Alle events die es in der DB gibt aber im neuen Call nicht, werden auf deprecated gesetzt.
				$arr_deprecated_event_ids = array_diff( array_keys($arr_obj_event_hashes), $arr_api_event_ids );

				if ( count( $arr_deprecated_event_ids ) > 0 ) {
					foreach( $arr_deprecated_event_ids as $single_id ) {
						verowa_set_event_to_deprecated( intval( $single_id ) );
					}
				}

				// Alle deprecated Events werden gelöscht.
				verowa_general_delete_deprecated( $this->str_events_tablename );
			}
		} else {
			if(VEROWA_DEBUG)
			{
				$str_mail = get_site_url();
				$str_mail = 'Es wurden keine Events von der API übertragen<br />';
				verowa_send_mail(SUPPORT_MAIL, 'WP Update cron', $str_mail);
			}
		}
	}

	public function update_verowa_persons_in_db()
	{
		global $wpdb;

		$arr_all_persons = verowa_api_call( 'getpersonsbyid', '0', true );

		if ( count($arr_all_persons) > 0 ) {
			$obj_person_ids_in_db = $wpdb->get_results(
				'SELECT GROUP_CONCAT(person_id SEPARATOR ",") AS `person_ids`' .
				' FROM `' . $wpdb->prefix . 'verowa_person`;' );
			$arr_person_ids_in_db = explode(',', $obj_person_ids_in_db[0]->person_ids);

			$arr_person_ids_from_verowa = array();
			$str_person_hash = '';

			foreach ( $arr_all_persons as $single_person ) {
				$arr_all_person_data = array();

				// Wir notieren uns alle person_ids um nachher mit denen in der DB zu vergleichen.
				$arr_person_ids_from_verowa[] = $single_person['person_id'];

				$arr_person_data = verowa_api_call( 'getpersondetails', $single_person['person_id'], true );

				if ( $arr_person_data != null && count( $arr_person_data ) > 0 ) {
					// merge the two info-arrays together
					$arr_all_person_data = array_merge( $single_person, $arr_person_data );

					// set the image displayed on the detail page
					$arr_all_person_data['detail_image'] = $arr_person_data['image_url'];
					$arr_all_person_data['detail_image_width'] = $arr_person_data['image_width'];
					$arr_all_person_data['detail_image_height'] = $arr_person_data['image_height'];
				} else {
					$arr_all_person_data = $single_person;
				}

				// set the image displayed in the list
				$arr_all_person_data['list_image'] = $single_person['image_url'];
				$arr_all_person_data['list_image_width'] = $single_person['image_width'];
				$arr_all_person_data['list_image_height'] = $single_person['image_height'];

				$str_person_hash = verowa_generate_person_hash( $arr_all_person_data['person_id'],
					json_encode( $arr_all_person_data ) );

				// Wenn es diese Person bereits gibt updaten wir sie
				if ( in_array( $arr_all_person_data['person_id'], $arr_person_ids_in_db ) ) {
					$get_person_hash = 'SELECT `hash` FROM `' . $wpdb->prefix . 'verowa_person`' .
						' WHERE `person_id` = ' . $arr_all_person_data['person_id'] . ';';
					$arr_person_hash = $wpdb->get_results( $get_person_hash, ARRAY_A );

					if ( $arr_person_hash[0]['hash'] !== $str_person_hash ) {
						verowa_update_person_in_db( $arr_all_person_data, $str_person_hash );
					}
				} else {
					verowa_insert_person_in_db( $arr_all_person_data, $str_person_hash );
				}
			}


			// Alle Personen die es in der DB gibt aber im neuen Call nicht, werden auf deprecated gesetzt.
			$arr_deprecated_person_ids = array_diff( $arr_person_ids_in_db, $arr_person_ids_from_verowa );

			if ( count( $arr_deprecated_person_ids ) > 0 ) {
				foreach( $arr_deprecated_person_ids as $single_person_id ) {
					verowa_set_person_to_deprecated( intval( $single_person_id ) );
				}
			}

			/**** Personengruppen updaten ****/
			$arr_persongroup_ids_from_verowa = array();
			$arr_deprecated_persongroup_ids = array();
			$arr_groups = verowa_api_call( 'getpersongroups', '' );

			$obj_persongroups_ids_in_db = $wpdb->get_results(
				'SELECT GROUP_CONCAT(pgroup_id SEPARATOR ",") AS `pgroup_ids`' .
				' FROM `' . $wpdb->prefix . 'verowa_person_groups`;' );

			$arr_persongroups_ids_in_db = explode(',', $obj_persongroups_ids_in_db[0]->pgroup_ids);

			foreach ( $arr_groups as $single_group ) {
				$arr_group_members = array();
				$arr_person_ids = array();
				$arr_members_group_functions = array();

				// Wir notieren uns alle group_ids um nachher mit denen in der DB zu vergleichen.
				$arr_persongroup_ids_from_verowa[] = $single_group['group_id'];

				$arr_group_members = verowa_api_call( 'getpersonsbygroup', $single_group['group_id'], true ) ?? [];

				foreach ( $arr_group_members as $single_member ) {
					$arr_person_ids[] = $single_member['person_id'];

					// We also store the group function for each member in an array. [person_id] => group_function
					if ( strlen( $single_member['function_in_group'] ) > 0 ) {
						$arr_members_group_functions[$single_member['person_id']] = $single_member['function_in_group'];
					}
				}

				$str_person_ids = ';' . implode( ';', $arr_person_ids ) . ';';

				// Alles hashen. Mit dem Hash kann einfach geprüft werden ob etwas geändert wurde
				$str_person_group_hash = verowa_generate_persongroup_hash( $single_group['group_id'],
					$str_person_ids, json_encode( $arr_members_group_functions ) );

				if ( in_array( $single_group['group_id'], $arr_persongroups_ids_in_db ) ) {
					$get_persongroup_hash = 'SELECT `hash` FROM `' . $wpdb->prefix . 'verowa_person_groups`' .
						' WHERE `pgroup_id` = ' . $single_group['group_id'] . ';';
					$arr_persongroup_hash = $wpdb->get_results( $get_persongroup_hash, ARRAY_A );

					// We only update the db if something changed (if the hashes are not the same anymore)
					if ( $arr_persongroup_hash[0]['hash'] !== $str_person_group_hash ) {
						verowa_update_persongroup_in_db( $single_group, $str_person_group_hash,
							$str_person_ids, json_encode( $arr_members_group_functions ) );
					}
				} else {
					verowa_insert_persongroup_in_db( $single_group, $str_person_ids,
						json_encode( $arr_members_group_functions ) );
				}
			}

			// Alle Personengruppen die es in der DB gibt aber im neuen Call nicht, werden auf deprecated gesetzt.
			$arr_deprecated_persongroup_ids = array_diff( $arr_persongroups_ids_in_db,
				$arr_persongroup_ids_from_verowa );

			if ( count( $arr_deprecated_persongroup_ids ) > 0 ) {
				foreach( $arr_deprecated_persongroup_ids as $single_pgroup_id ) {
					verowa_set_persongroup_to_deprecated( intval( $single_pgroup_id ) );
				}
			}

			// Alle deprecated Events werden gelöscht.
			$str_person_tablename = $wpdb->prefix . 'verowa_person';
			verowa_general_delete_deprecated($str_person_tablename);
		}
		else
		{
			if(VEROWA_DEBUG)
			{
				$str_mail = 'Es wurden keine Personen von der API übertragen<br />';
				$str_mail .= get_site_url();
				verowa_send_mail(SUPPORT_MAIL, 'WP Update cron', $str_mail);
			}
		}
	}

}

/** MPf: Test vor Update Tracking and further DB Updates */
add_action( 'upgrader_process_complete', 'vc_upgrader_process_complete', 10, 2 );

function vc_upgrader_process_complete($upgrader_object, $options)
{
	if( array_search( 'verowa-connect/verowa-connect.php', $options['plugins'] ) )
	{
		$str_mail = 'Version: ' . $upgrader_object->plugin_info['Version'];
		mail('m.pfister@picture-planet.ch', 'Verowa Connect Update', $str_mail);
	}
}