<?php
/*
 * Enthält Funktionen, die entweder für die einzelne Personenanzeige verwendet
 * werden oder aber für eine Gruppe von Personen als Shortcode, die im Post festgelegt werden
 * und über das Widget angezeigt werden können.
 * Die Funktion show_a_person_from_verowa ist für kleinere Boxen, wo nicht alle Details aufgelistet werden.
*/

add_shortcode( 'verowa_person', 'verowa_person' );
add_shortcode( 'verowa_personen', 'verowa_personen' );


// Einzelne Person, die mit [verowa_person id=129] überall aufgerufen werden kann.
// Die Funktion ist ein Wrapper und heisst genau wie der shortcode, der oben angelegt wird.
function verowa_person( $atts ) {
	ob_start();

	// Get the Template
	$int_selected_template = get_post_meta( $post->ID, 'verowa_personlist_template', true );

	if ( $int_selected_template == 0 ) {
		$int_selected_template = intval( get_option( 'verowa_default_personlist_template' ) );
	}

	$arr_template = verowa_get_template( $int_selected_template );

	//$arr_single_person = verowa_api_call( 'getpersonsbyid', $atts['id'], true );
	$arr_single_person = verowa_get_person_content_from_db( $atts['id'] );


	// Add the header
	echo $arr_template['header'];

	show_a_person_from_verowa( $arr_single_person );

	// Add the footer
	echo $arr_template['footer'];

	return ob_get_clean();
}



// Zeigt alle ausgewählten Personen an, allenfalls inkl. Überschriften und Gruppen
function verowa_personen( $atts = [] ) {
	global $post;

	ob_start();

	$atts = shortcode_atts(
		array(
			'id' => 0,
			'comp_tag' => '',
		),
		$atts,
		'verowa_personen'
	);


	$arr_all_person_ids = $atts['id'] > 0 ? $atts['id'] : get_post_meta($post->ID, '_person_singles', true);
	$str_single_or_group = get_post_meta($post->ID, '_verowa_person_assign', true);
	$str_comp_tag = strlen( $atts['comp_tag'] ) > 0 ? $atts['comp_tag'] : 'pr';

	// Get the Template
	$int_selected_template = get_post_meta( $post->ID, 'verowa_personlist_template', true );

	if ( $int_selected_template == 0 ) {
		$int_selected_template = intval( get_option( 'verowa_default_personlist_template' ) );
	}

	$arr_template = verowa_get_template( $int_selected_template );

	// falls die Personen-IDs als String zurückkommen (p1,p24,p12), packen wir sie in ein Array mit Zahlen
	if ( is_string( $arr_all_person_ids ) ) {
		$arr_all_person_ids = explode( ',', $arr_all_person_ids );
		$arr_all_person_ids_polished = array();

		foreach ($arr_all_person_ids as $single_person) {
			$single_person = trim( $single_person );

			// falls am Anfang ein P steht, kommt es weg (weil P[erson] = Default
			if ( strtolower (substr( $single_person, 0, 1 ) == 'p' ) ) {
				$single_person = substr( $single_person, 1 );
			}

			$arr_all_person_ids_polished[] = $single_person;
		}

		$arr_all_person_ids = $arr_all_person_ids_polished;
	}

	// nur weiter, falls wir Content haben
	// $arr_all_person_ids kann personen-IDs, Gruppen-IDs UND Überschriften beinhalten
	if ( is_array( $arr_all_person_ids ) && count( $arr_all_person_ids) > 0 ) {
		$arr_person_ids = array();

		foreach ( $arr_all_person_ids as $single_person ) {
			if ( is_numeric( $single_person ) ) {
				$arr_person_ids[] = $single_person;
			}
		}

		// wir holen nur die einzelnen personen. Gruppen werden weiter unten separat geholt
		//$arr_single_members = verowa_api_call( 'getpersonsbyid', implode( ',', $arr_person_ids ) . '[' . $str_comp_tag . ']' , true );
		$arr_single_members = verowa_get_multiple_persons( $arr_person_ids );

		$arr_single_members_polished = array();

		// neues Array, Key = Person-ID
		if ( is_array( $arr_single_members ) && count ( $arr_single_members ) > 0 ) {
			foreach ( $arr_single_members as $single_member ) {
				$arr_single_members_polished[$single_member['person_id']] = $single_member;
			}
		}

		// wir fahren mit $arr_all_person_ids weiter, denn hier stimmt die Reihenfolge
		echo '<div class="person-container single-persons">';

		// Add the header
		echo $arr_template['header'];

		// ACHTUNG: $single_person kann eine ID sein, eine Gruppen-ID ('group-123') oder eine Überschrift (!)
		foreach ( $arr_all_person_ids as $single_person ) {
			// wir haben eine Personen-ID
			if ( is_numeric( $single_person ) ) {
				show_a_person_from_verowa( $arr_single_members_polished[$single_person] );
			}
			// wir müssen eine Gruppe holen
			elseif ( false !== strpos( $single_person, 'group-' ) ) {
				$group_id = str_replace( 'group-', '', $single_person );
				//$arr_group_members = verowa_api_call( 'getpersonsbygroup', $group_id . '[' . $str_comp_tag . ']', true );
				$arr_group_members = verowa_get_persons_for_group( intval( $group_id ) );

				foreach ( $arr_group_members as $single_person ) {

					show_a_person_from_verowa( $single_person );
				}
			}
			// oder es ist eine Überschrift
			else {
				echo '<div class="persons_headline"><h3>' . $single_person . '</h3></div>';
			}
		}

		// Add the footer
		echo $arr_template['footer'];

		echo '</div>';
	}

	return ob_get_clean();
}



// Ausgabe der einzelenen Person, als Variable die zugehörige Personen-ID.
// Wird verwendet vom Widget und den Shortcodes verowa_person und verowa_personen
function show_a_person_from_verowa( $arr_gruppenmitglied ) {
	global $post, $wpdb;

	$arr_placeholder = array();
	$str_person_name = '';

	if ( isset( $arr_gruppenmitglied['content'] ) ) {
		$arr_person = json_decode( $arr_gruppenmitglied['content'], true );
	} else {
		$arr_person = $arr_gruppenmitglied;
	}

	// Optionen
	$int_personlist_template = intval( get_post_meta( $post->ID, 'verowa_personlist_template', true ) );

	if ( $int_personlist_template == 0 ) {
		$int_personlist_template = intval( get_option( 'verowa_default_personlist_template' ) );
	}

	$arr_personlist_template = verowa_get_template( $int_personlist_template );

	// gewisse spezielle Einträge überschreiben die Vorgaben aus den Plugin-Einstellungen
	if ( $post->ID > 0 && get_post_meta( $post->ID, 'verowa_has_person_options_on_post_level', false ) ) {
		$person_detail_page = get_post_meta( $post->ID, 'verowa_person_has_detail_page', true );
		$person_group_function = get_post_meta( $post->ID, 'verowa_person_show_group_function', true );
		$person_profession = get_post_meta( $post->ID, 'verowa_person_show_profession', true );
		$person_address = get_post_meta( $post->ID, 'verowa_person_show_address', true );
		$person_email = get_post_meta( $post->ID, 'verowa_person_show_person_email', true );
		$person_phone = get_post_meta( $post->ID, 'verowa_person_show_person_phone', true );
		$person_short_desc = get_post_meta( $post->ID, 'verowa_person_show_short_desc', true );
	}
	// sonst übernehmen wir einfach die vom Plugin
	else {
		$person_detail_page = get_option( 'verowa_person_has_detail_page', false );
		$person_group_function = get_option( 'verowa_person_show_group_function', false );
		$person_profession = get_option( 'verowa_person_show_profession', false );
		$person_address = get_option( 'verowa_person_show_address', false );
		$person_email = get_option( 'verowa_person_show_person_email', false );
		$person_phone = get_option( 'verowa_person_show_person_phone', false );
		$person_short_desc = get_option( 'verowa_person_show_short_desc', false );
	}

	$arr_einzelne_person = $arr_person;

	if ( is_array( $arr_einzelne_person ) && count( $arr_einzelne_person ) > 0 ) {
		if ( 'on' != $person_detail_page ) {
			$detail_exists = true;
			$str_link_pre = '<a href="' . get_bloginfo( 'url' ) . '/person/' . $arr_einzelne_person['person_id'] . '/">';
			$str_link_post = '</a>';
		} else {
			$detail_exists = false;
			$str_link_pre = '';
			$str_link_post = '';
		}

		$arr_placeholder['PERSON_ID'] = $arr_einzelne_person['person_id'];

		if ( strlen( $arr_einzelne_person['list_image'] ) > 0 ) {
			$arr_placeholder['IMAGE_URL'] = $str_link_pre . '<img src="' . $arr_einzelne_person['list_image'] . '" />' .
				$str_link_post;
		}

		$str_person_name .= $str_link_pre . $arr_einzelne_person['firstname'];

		if ( strlen( $arr_einzelne_person['firstname'] ) > 0 && strlen( $arr_einzelne_person['lastname'] ) > 0) {
			$str_person_name .= ' ';
		}

		$str_person_name .= $arr_einzelne_person['lastname'] . $str_link_post;

		$arr_placeholder['PERSON_NAME'] = $str_person_name;

		if ( strlen( $arr_einzelne_person['function_in_group'] ) > 0 && 'on' == $person_group_function ) {
			$arr_placeholder['FUNCTION_IN_GROUP'] = $arr_einzelne_person['function_in_group'];
		}

		if ( strlen( $arr_einzelne_person['short_desc'] ) > 0 && 'on' == $person_short_desc ) {
			$arr_placeholder['SHORT_DESC'] = $arr_einzelne_person['short_desc'];
		}

		if ( strlen( $arr_einzelne_person['profession'] ) > 0 && 'on' == $person_profession ) {
			$arr_placeholder['PROFESSION'] = $arr_einzelne_person['profession'];
		}

		if ( $arr_einzelne_person['postcode'] > 0 && 'on' == $person_address ) {
			$arr_placeholder['ADDRESS'] = $arr_einzelne_person['address'];
			$arr_placeholder['ZIP_CITY'] = $arr_einzelne_person['postcode'] . ' ' . $arr_einzelne_person['city'];
		}

		if ( strlen( $arr_einzelne_person['email'] ) > 0 && 'on' == $person_email ) {
			$arr_placeholder['EMAIL'] = $arr_einzelne_person['email'];
		}

		if ( strlen( $arr_einzelne_person['phone'] ) > 0 && 'on' == $person_phone ) {
			$arr_placeholder['PHONE'] = $arr_einzelne_person['phone'];
		}

		$str_output = verowa_parse_template( $arr_personlist_template['entry'], $arr_placeholder ) . $arr_personlist_template['separator'];

		echo $str_output;
	}

}

?>