<?php
function verowa_subscriptions_form_validation () {

	$int_seats_count = 0;
	$no_error_exist = true;
	$int_event_id = intval( $_POST['event_id'] );

	$arr_event_details = verowa_get_event_content_from_db($int_event_id);

	// max. Anzahl Plätze pro Anmeldung
	$int_max_seats_per_subs = $arr_event_details['subscribe_form']['template_options']['max_seats_per_subs'];

	$str_datetime_now = date_i18n( 'Ymd' ) . date_i18n( 'His' );

	if ( empty( $arr_event_details['subscribe_time'] ) ) {
		$arr_event_details['subscribe_time'] = '2359';
	}

	// Load settings
	$ret_option = get_option( 'verowa_subscriptions_settings' );
	$arr_options = $ret_option != false ? json_decode( $ret_option, true ) : [];

	$arr_formfields = verowa_subscriptions_form_fields( $arr_event_details['subscribe_form']['subscribe_formfields'], $arr_options );

	/***** Validierung *****/

	$is_recaptcha_enable = false;

	if( array_key_exists( 'recaptcha_key_public', $arr_options ) &&
		strlen( $arr_options['recaptcha_key_public'] ) > 0 &&
		array_key_exists( 'recaptcha_key_secret', $arr_options ) &&
		strlen( $arr_options['recaptcha_key_secret'] ) > 0 ) {

		$is_recaptcha_enable = true;
    }

	if ( !$_SESSION['error'] ) {
		$_SESSION['error'] = array ();
	}

	// 0 oder negative event_id macht keinen Sinn -> Fehler
	if ( $int_event_id <= 0 ) {
		$_SESSION['error'][] = __('invalid event selection.', 'verowa-subscriptions');
	}


	// Fehler wenn Anmeldefrist überschritten
	if ( !empty( $arr_event_details['subscribe_date'] ) &&
		$arr_event_details['subscribe_date'] . $arr_event_details['subscribe_time'] . '59' < $str_datetime_now ) {

		// Übersetzung: Anmeldefrist abgelaufen.
		$_SESSION['error'][] = __( 'Registration deadline expired.', 'verowa-subscriptions' );
	}

	// Custom field types überprüfen
	foreach ( $arr_formfields as $single_formfield ) {

		$int_length = strlen ( strval ( $_POST[$single_formfield['field_name']] ) );
		$bool_required = $single_formfield['required'] == 0 ? false : true;

		// == für die "weiteren Personen" entfernen
		$single_formfield['options'] = false !== strpos( $single_formfield['options'], '==' ) ?
			substr( $single_formfield['options'], 0, -2 ) : $single_formfield['options'];


		// Default Wert auslesen /(.*)({.*})(.*)/
		if ( false !== strpos( $single_formfield['options'], '{' ) && false !== strpos( $single_formfield['options'], '}' ) ) {
			$single_formfield['options'] = substr( $single_formfield['options'], 0, -1 );

			$arr_all_options = explode( '{', $single_formfield['options'] );

			$single_formfield['options'] = $arr_all_options[0];
			$str_default_value = $arr_all_options[1];
		}

		// Label und Shorttitle trennen im Formular nehmen wir den ganzen Titel
		if ( strpos( $single_formfield['label'], '{{' ) !== false && strpos( $single_formfield['label'], '}}' ) !== false ) {
			$arr_title_pieces = verowa_separate_subs_label_shorttitle( $single_formfield['label'] );

			$single_formfield['label'] = $arr_title_pieces[0];
		}

		// Wir gehen alle Felder durch und testen Sie je nach feldtyp
		switch ( $single_formfield['type'] ) {
			case 'firstname':
			case 'lastname':
			case 'street':
			case 'zip_city':
			case 'text':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				$int_max_length = intval( $arr_formfield_options[0] );
				$int_min_length = !empty( $arr_formfield_options[1] ) ? intval( $arr_formfield_options[1] ) : 0;

				if ( true === $bool_required && $int_length <= 0 ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'must not be empty', 'verowa-subscriptions' ) . '.';
				} else if ( $int_length > $int_max_length ) {
					$_SESSION['error'][] = sprintf( __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'could not be more than %d characters long (currently: %d).',
						'verowa-subscriptions' ), $int_max_length,  $int_length );
				} else if ( $int_length < $int_min_length ) {
					$_SESSION['error'][] = sprintf( __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'could not be less than %d characters long (currently: %d).',
						'verowa-subscriptions' ), $int_min_length,  $int_length );
				}

				break;
			case 'subs_email':
			case 'email':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				$int_max_length = intval( $arr_formfield_options[0] );
				$int_min_length = !empty( $arr_formfield_options[1] ) ? intval( $arr_formfield_options[1] ) : 0;

				//Check email length
				if ( true === $bool_required && $int_length <= 0 ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'must not be empty', 'verowa-subscriptions' ) . '.';
				} else if ( $int_length > $int_max_length ) {
					$_SESSION['error'][] = sprintf( __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'could not be more than %d characters long (currently: %d).',
						'verowa-subscriptions' ), $int_max_length,  $int_length );
				} else if ( $int_length < $int_min_length ) {
					$_SESSION['error'][] = sprintf( __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'could not be less than %d characters long (currently: %d).',
						'verowa-subscriptions' ), $int_min_length,  $int_length );
				} else if ( is_email( $_POST[$single_formfield['field_' . $single_formfield['field_id']]] ) == false
					&& $_POST[$single_formfield['field_' . $single_formfield['field_id']]] != '' ) {

					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__('invalid e-mail address.', 'verowa-subscriptions') . '.';
				}

				break;
			case 'phone':
			case 'tel':
				//Check phone number validity
				if ( true === $bool_required && $int_length <= 0 ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'must not be empty', 'verowa-subscriptions' ) . '.';
				}
				else if ( !preg_match( '/^\+?[0-9 ]{10,15}$/', $_POST['field_' . $single_formfield['field_id']] )
					&& $_POST['field_' . $single_formfield['field_id']] != '' ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__('must be between 10 and 15 characters long and may only contain numbers, spaces and the plus sign (+).',
						'verowa-subscriptions');
				}

				break;
			case 'seats':
				$int_seats_count += intval( $_POST[$single_formfield['field_name']] );
			case 'number':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				$int_min = intval( $arr_formfield_options[0] );
				$int_max = intval( $arr_formfield_options[1] );

				if ( true === $bool_required && $int_length <= 0) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'must not be empty', 'verowa-subscriptions' ) . '.';
				} else if ( $_POST[$single_formfield['field_name']] ) {
					if ( false == is_numeric( $_POST[$single_formfield['field_name']] ) ) {
						$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
							__( 'Please enter a number', 'verowa-subscriptions' ) . '.';
					} else {
						if ( floor( $_POST[$single_formfield['field_name']] ) != $_POST[$single_formfield['field_name']] ) {
							$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
								__( 'Please enter a whole number', 'verowa-subscriptions' ) . '.';
						} else {
							if ( $_POST[$single_formfield['field_name']] < $int_min ) {
								$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
									__( 'Not allowed to be lower than', 'verowa-subscriptions' ) . ' ' . $int_min . '.';
							}
							else if ( $_POST[$single_formfield['field_name']] > $int_max ) {
								$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
									__( 'Not allowed to be higher than', 'verowa-subscriptions' ) . ' ' . $int_max . '.';
							}
						}
					}
				}

				break;
			case 'dropdown':
				$arr_formfield_options = explode( PHP_EOL, $single_formfield['options'] );

				for ( $i = 0; $i < count( $arr_formfield_options ); $i++ ) {
					$arr_formfield_options[$i] = trim( $arr_formfield_options[$i] );
				}

				if ( true === $bool_required && $int_length <= 0 ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'Please select an option', 'verowa-subscriptions' ) . '.';
				}
				else if ( in_array ( $_POST[$single_formfield['field_name']], $arr_formfield_options ) == false ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'Invalid Choice', 'verowa-subscriptions' ) . '.';
				}

				break;
			case 'checkbox':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				if ( true === $bool_required && count( $_POST[$single_formfield['field_name']] ) <= 0 ) {

					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'Please select an option', 'verowa-subscriptions' ) . '.';
					$_POST[$single_formfield['field_name']] = [];
				}
				else if ( !empty( $_POST[$single_formfield['field_name']] ) ) {
					foreach ( $_POST[$single_formfield['field_name']] as $single_checkbox ) {

						if ( in_array( $single_checkbox, $arr_formfield_options ) == false
							&& $_POST[$single_formfield['field_name']] != '' ) {

							$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
								__( 'Invalid Choice', 'verowa-subscriptions' ) . '.';
						}
					}
				}

				break;
			case 'radio':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				if ( true === $bool_required && $int_length <= 0 ) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'Please select an option', 'verowa-subscriptions' ) . '.';
					$_POST[$single_formfield['field_name']] = '';
				}
				else if ( in_array( $_POST[$single_formfield['field_name']], $arr_formfield_options ) == false
					&& $_POST[$single_formfield['field_name']] != '' ) {

					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'Invalid Choice', 'verowa-subscriptions' ) . '.';
				}

				break;
			case 'date':
				$arr_formfield_options = explode( ';', $single_formfield['options'] );

				if ( !empty( $arr_formfield_options[0] ) && !empty( $arr_formfield_options[1] ) ) {
				$int_date_min = intval( substr( $arr_formfield_options[0], 0, 4 ) . substr( $arr_formfield_options[0], 5, 2 ) .
					substr( $arr_formfield_options[0], 8, 2 ) );
				$int_date_max = intval( substr( $arr_formfield_options[1], 0, 4 ) . substr( $arr_formfield_options[1], 5, 2 ) .
					substr( $arr_formfield_options[1], 8, 2 ) );
				$int_post_date = intval( substr( $_POST[$single_formfield['field_name']], 0, 4 ) .
					substr( $_POST[$single_formfield['field_name']], 5, 2 ) . substr( $_POST[$single_formfield['field_name']], 8, 2 ) );

				// Datum als DD.MM.YYYY zur Ausgabe
				$str_date_min = substr( $arr_formfield_options[0], 8, 2 ) . '.' . substr( $arr_formfield_options[1], 5, 2 ) .
					'.' . substr( $arr_formfield_options[0], 0, 4 );
				$str_date_max = substr( $arr_formfield_options[1], 8, 2 ) . '.' . substr( $arr_formfield_options[1], 5, 2 ) .
					'.' . substr( $arr_formfield_options[1], 0, 4 );

				if ( true === $bool_required && $int_length <= 0) {
					$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) . ': ' .
						__( 'must not be empty', 'verowa-subscriptions' ) . '.';
				}
				else if ( $_POST[$single_formfield['field_name']] ) {
					if ( $int_post_date < $int_date_min || $int_post_date > $int_date_max ) {
						$_SESSION['error'][] = __( $single_formfield['label'], 'verowa-subscriptions' ) .
							': Bitte geben Sie ein gültiges Datum ein. Datum muss zwischen ' . $str_date_min . ' und ' .
							$str_date_max . ' liegen.';
					}
				}
				}

				break;
		}
	}

	if ( $int_seats_count > $int_max_seats_per_subs ) {
		$_SESSION['error'][] = 'Sie dürfen maximal nur ' . $int_max_seats_per_subs . ' Personen erfassen (momentan: ' .
			$int_seats_count . ').';
		}

	if ( $is_recaptcha_enable ) {
		// Anfrage
		$request = file_get_contents( 'https://www.google.com/recaptcha/api/siteverify?secret=' .
		$arr_options['recaptcha_key_secret'] . '&response=' . $_POST['recaptcha_token'] );

		 // JSON-Antwort dekodieren
		 $request = json_decode( $request );

		if ( $request->success == true && $request->score <= 0.6 ) {
			$_SESSION['error'][] = __('reCaptcha has prevented the form from being sent. ' .
				'Please try to register again. If the error occurs again, please contact the secretariat.', 'verowa-subscriptions');
		}
	}

	if ( isset( $_SESSION['error'] ) && count( $_SESSION['error'] ) > 0 ) {
		$no_error_exist = false;
	}

	return $no_error_exist;
}


/**
 * Display a List of alle public events with subscriptions.
 *
 * @param array $arr_events
 * @param array $arr_options
 * @param int $event_id
 * @param array $arr_month_kurz
 * @return array
 */
function verowa_subscription_show_events( $arr_events, $arr_options, $event_id, $arr_month_kurz ) {
	$is_show_form = true;

	// Wird dem Benutzer angezeigt, kann eine Evenliste, einen einzelnen Event oder eine Info beinhalten.
	$str_content = '';
	$str_content .= '<div class="nl-subscribe">';

	// Events sind im body drin.
	$str_today10 = date_i18n( 'Y-m-d' );
	$radiofield_count = 0;

	$arr_events_today = is_array( $arr_events ) ? $arr_events : [];
	$events_today_exist = false;

	$events_today_exist = substr( $arr_events_today['date_from'], 0, 10 ) == $str_today10 ? true : false;

	//foreach ( $arr_events_today as $events ) {
	//    if ( substr( $events['date_from'], 0, 10 ) == $str_today10 ) {
	//        $events_today_exist = true;
	//    }
	//}



	if ( 0 == count( $arr_events_today ) ) {
		if ( $arr_options['only_today'] == 'on' ) {
			$str_content .= '<strong>' . __( 'There are no public events taking place today.',
				'verowa-subscriptions' ) . '</strong>';
			$is_show_form = false;
		} else {
			$str_content .= '<strong>' . __( 'There will be no public events in the next few days.',
				'verowa-subscriptions', 'verowa-subscriptions' ) .'</strong>';
			$is_show_form = false;
		}
	} else {
		if ( $arr_options['only_today'] == 'on' && $events_today_exist == false ) {
			$str_content .= '<strong>' . __( 'There are no public events taking place today.',
				'verowa-subscriptions' ) . '</strong>';
			$is_show_form = false;
		}
	}

	if ($is_show_form) {
		$str_content .= '<div class="ct-events">';

		$str_curr_event_date = '';

		foreach ( $arr_events_today as $single_event ) {
			$str_content .= '<h3>';

		//$str_content .= __( 'Registration', 'verowa-subscriptions' );
			//$str_content .= $arr_events_today[0]['title'];

			if ( isset( $arr_options['event_detail_link'] ) && $arr_options['event_detail_link'] != '' && 'on' == $arr_options['show_event_link'] ) {
					$str_event_link = str_replace( '{%event_id%}', $single_event['event_id'], $arr_options['event_detail_link'] );
					$str_content .= '<a href="' . $str_event_link . '">' . $single_event['title'] . '</a></br>' . $single_event['date_text'];
			} else {
				$str_content .= $single_event['title'] . '</br>' . $single_event['date_text'];
			}

			if ( $arr_options['only_today'] !== 'on' ) {
				$str_content .= '</h3>';
			}

			$str_field_id = 'event_' . $radiofield_count++;

			$str_new_event_date = date_i18n( 'j. M. Y', strtotime( $single_event['date_from'] ) );

			$str_event_date_from8 = substr( $single_event['date_from'], 0, 4 ) .
				substr( $single_event['date_from'], 5, 2 ) . substr( $single_event['date_from'], 8, 2 );

			$str_date_today8 = date_i18n( 'Ymd' );

			$bool_anmeldung_date = false;
			$str_anmelde_schluss = '';

			// Anmeldefrist ausgeben, falls gesetzt
			if ( $single_event['subscribe_date'] != '0' && $single_event['subscribe_date'] != '' ) {
				$bool_anmeldung_date = true;
				$str_event_line .= __( 'Subscription', 'verowa-subscriptions' ) . ' ';
				$str_anmelde_schluss = '<span style=" white-space: nowrap;">' . __( 'until', 'verowa-subscriptions' ) . ' ';
				$str_subs_time = '';
				$str_subs_date = date_i18n( 'j', strtotime( $single_event['subscribe_date'] ) ) . '. ' .
					$arr_month_kurz[substr( $single_event['subscribe_date'], 4, 2 )];

				if ( '' != $single_event['subscribe_time'] ) {
					$str_subs_time = intval( substr( $single_event['subscribe_time'], 0, 2 ) ) . '.' .
						substr( $single_event['subscribe_time'], 2, 2 ) . ' Uhr';

					if ( $single_event['subscribe_date'] == $str_date_today8 ) {
						$str_anmelde_schluss .= $str_subs_time . '</span>';
					} else {
							$str_anmelde_schluss .= $str_subs_date . ', ' . $str_subs_time . '</span>';
					}
				} else {
				// Falls das Datum = dem Startdatum der Veranstaltung ist, geben wir höchstens die Zeit aus
					if ( $single_event['subscribe_date'] == $str_event_date_from8 ) {
						$str_anmelde_schluss = '';
				} else {
						$str_anmelde_schluss .= $str_subs_date . '</span>';
					}
				}
			}

			$int_weekday = date_i18n( 'w', strtotime( $single_event['date_from'] ) );
			$int_seats_total = $single_event['seats_online'] + $single_event['seats_entrance'];

			$str_seats = '';

			if ( 'on' != $arr_options['hide_bookable_seats'] && $single_event['seats_online'] != -1 ) {
				if ( 'on' != $arr_options['hide_free_seats'] ) {
					$str_seats = ', reservierbar';
				} else {
					$str_seats = __( 'reservable seats', 'verowa-subscriptions' );
			}

				$str_seats .= ': ' . $single_event['seats_online'];
			}

			if ( 'on' != $arr_options['hide_free_seats'] ) {
				if ( $int_seats_total > 0 ) {
					$str_seats = __( 'free seats:', 'verowa-subscriptions' ) . ' ' . $int_seats_total . $str_seats;
				} else if ( $int_seats_total == 0 ) {
					$str_seats = __( 'free seats:', 'verowa-subscriptions' ) . ' 0' . $str_seats;
				} else if ( 'on' != $arr_options['hide_numbers_when_infinite'] ) {
					$str_seats = __( 'free seats: unlimited' , 'verowa-subscriptions' );
				}
			}


			if ( $arr_options['only_today'] == 'on' ) {
				if ( substr( $single_event['date_from'], 0, 10 ) == $str_today10 ) {
					if ( $str_new_event_date != $str_curr_event_date ) {
						$str_content .=  ' ' . $str_new_event_date . '</h3>';
						$str_curr_event_date = $str_new_event_date;
					}

					$str_content .= verowa_subscriptions_show_days(
						$str_field_id,
						$str_event_line,
						$str_seats,
						$single_event,
						$str_anmelde_schluss,
						$bool_anmeldung_date
					);
				}
			} else {
				if ( $str_new_event_date != $str_curr_event_date ) {
					$str_curr_event_date = $str_new_event_date;
				}

				$str_content .= verowa_subscriptions_show_days(
					$str_field_id,
					$str_event_line,
					$str_seats,
					$single_event,
					$str_anmelde_schluss,
					$bool_anmeldung_date
				);
			}
		} // foreach

		$str_content .= '</div>';
	}

	return [
		'content' => $str_content,
		'is_show_form' => $is_show_form
	];
}


/**
 * verowa_subscriptions_show_days
 *
 * @param  mixed $str_field_id
 * @param  mixed $str_event_line
 * @param  mixed $str_seats
 * @param  array $arr_event
 * @param  string $str_anmelde_schluss
 * @param  bool $bool_anmeldung_date
 *
 * @return string
 */
function verowa_subscriptions_show_days( $str_field_id, $str_event_line, $str_seats, $arr_event, $str_anmelde_schluss, $bool_anmeldung_date ) {

	$str_ret = '<div class="ct_block">';

	$str_time_now = date_i18n( 'Hi' );
	$str_date_now = date_i18n( 'Ymd' );

	$bool_subs_time_elapsed = false;

	if ( !empty( $arr_event['subscribe_date'] ) && !empty( $arr_event['subscribe_time'] ) ) {
		if ( intval( $arr_event['subscribe_date'] ) < intval( $str_date_now ) ) {
			$bool_subs_time_elapsed = true;
		} else if ( intval( $arr_event['subscribe_date'] ) == intval( $str_date_now ) &&
			intval( $arr_event['subscribe_time'] ) < intval( $str_time_now ) ) {

			$bool_subs_time_elapsed = true;
		}
	} else if ( !empty( $arr_event['subscribe_date'] ) ) {
		if ( intval( $arr_event['subscribe_date'] ) < intval( $str_date_now ) ) {
			$bool_subs_time_elapsed = true;
		}
	}

	$str_ret .= '<div class="row"><label for="' . $str_field_id . '">';
	$str_ret .= '<input type="hidden" name="event_id" id="' . $str_field_id . '"' .
			' value="' . $arr_event['event_id'] . '" />';
	$str_ret .= $str_event_line;

	$str_ret .= $str_anmelde_schluss;

	if ( 0 == $arr_event['seats_entrance'] && 0 == $arr_event['seats_online'] ) {
		$str_ret .= ' (AUSGEBUCHT)';
	}
	else if ( true == $bool_subs_time_elapsed ) {
		$str_ret .= ' (ANMELDEFRIST ABGELAUFEN)';
	}
	else if ( strlen( $str_seats ) > 0 ) {
		$str_ret .= ' (' . $str_seats . ')';
	}

	if ( ( ( strlen( $arr_event['subscribe_date'] ) > 0 && true == $bool_subs_time_elapsed ) || 0 == $arr_event['seats_online'] )
		&& $arr_event['seats_entrance'] > 0 ) {

		$str_ret .= ' – NUR NOCH SPONTANER BESUCH MÖGLICH';
	}

	$str_ret .= '</label></div></div>'; // ct_block

	return $str_ret;
}



/**
 * verowa_subscriptions_form_fields
 *
 * @param  array  	$arr_subs_form_fields
 * @param  array  	$arr_options
 * @param  string  	$str_arr_key
 *
 * @return array
 */
function verowa_subscriptions_form_fields( $arr_subs_form_fields, $arr_options) {

	// Felder kommen alle in dieses Array
	$arr_formfields = [];
	//echo '<pre>';
	//debug_print_backtrace();
	//echo '</pre>';

	// var_dump($arr_subs_form_fields);

	echo '<hr />';
	// Custom fields dazu holen
	foreach ( $arr_subs_form_fields as $single_form ) {
		switch ($single_form['type']) {
			case 'firstname':
			case 'lastname':
			case 'street':
			case 'zip_city':
				$arr_formfields[] = array(
					'field_id' => $single_form['field_id'],
					'type' => 'text',
					'label' => $single_form['label'],
					'position' => $single_form['position'],
					'required' => $single_form['required'],
					'helptext' => $single_form['helptext'],
					'options' => $single_form['options'],
					'field_name' => $single_form['type']
				);

				break;
			case 'phone':
				$arr_formfields[] = array(
					'field_id' => $single_form['field_id'],
					'type' => 'phone',
					'label' => $single_form['label'],
					'position' => $single_form['position'],
					'required' => $single_form['required'],
					'helptext' => $single_form['helptext'],
					'options' => $single_form['options'],
					'field_name' => 'field_' . $single_form['field_id']
				);

				break;
			case 'subs_email':
			case 'email':
				$arr_formfields[] = array(
					'field_id' => $single_form['field_id'],
					'type' => 'email',
					'label' => $single_form['label'],
					'position' => $single_form['position'],
					'required' => $single_form['required'],
					'helptext' => $single_form['helptext'],
					'options' => $single_form['options'],
					'field_name' => 'field_' . $single_form['field_id']
				);

				break;
			case 'seats':
				$arr_formfields[] = array(
					'type' => 'seats',
					'label' => $single_form['label'],
					'position' => $single_form['position'],
					'required' => $single_form['required'],
					'helptext' => $single_form['helptext'],
					'options' => $single_form['options'],
					'field_name' => 'nb_seats_' . $single_form['field_id']
				);

				break;
			default:

				$single_form['field_name'] = 'customfield_' . $single_form['field_id'];
				$arr_formfields[] = $single_form;

				break;
		}
	}

	// Felder nach Position sortieren
	$arr_column_position = array_column( $arr_formfields, 'position');
	array_multisort(
		$arr_column_position,
		SORT_ASC,
		$arr_formfields
	);

	return $arr_formfields;
}



/**
 * verowa_subscriptions_print_links
 *
 * @param  array  	$event_detail_body
 *
 * @return void
 */
function verowa_subscriptions_print_links( $arr_event_details, $arr_options ) {

	$arr_month_kurz = [
		'01' => 'Jan.',
		'02' => 'Feb.',
		'03' => 'März',
		'04' => 'April',
		'05' => 'Mai',
		'06' => 'Juni',
		'07' => 'Juli',
		'08' => 'Aug.',
		'09' => 'Sept.',
		'10' => 'Okt.',
		'11' => 'Nov.',
		'12' => 'Dez.'
	];

	$str_date_now = date_i18n( 'Ymd' );

	$str_datetime_now = $str_date_now . date_i18n( 'His' );

	// check for additional restrictions
	if ( 0 == $arr_options['max_count'] && 0 == $arr_options['max_days'] ) {
		$event_detail_body = $arr_event_details; // no restrictions > no actions needed
	} else {
		$event_detail_body = [];
		$events_count = 0;

		// max_days = 1 means only "today"
		if ( $arr_options['max_days'] > 0 ) {
			$str_max_datetime = date_i18n( 'Y-m-d 23:59:59',
				strtotime( $str_date_now . ' +' . ( $arr_options['max_days'] - 1 ) . ' days' ));
		} else {
			$str_max_datetime = '';
		}

		// $arr_event_details could be null
		if( is_array($arr_event_details) ){
			foreach ( $arr_event_details as $single_event ) {
				if ( ( $arr_options['max_count'] > 0 && $events_count >= $arr_options['max_count'] )
					|| ( $arr_options['max_days'] > 0 && ( $single_event['date_from'] > $str_max_datetime ) ) ) {
					break; // quit, if a restriction is hit
				}

				$event_detail_body[] = $single_event;
				$events_count++;
			}
		}
	}

	if ( empty( $event_detail_body ) ) {
		if ( $arr_options['only_today'] == 'on' ) {
			// Heute finden bei uns keine öffentlichen Veranstaltungen mit Anmeldung statt.
			echo '<strong>' . __('There are no public events with registration taking place today.',
				'verowa-subscriptions') . '</strong><br/><br/>';
		} else {
			// In den nächsten Tagen finden bei uns keine Veranstaltungen mit Anmeldung statt.
			echo '<strong>' . __('There will be no public events with registration in the next few days.',
				'verowa-subscriptions', 'verowa-subscriptions') . '</strong><br/><br/>';
		}
	} else {

		$str_line_raw = '<p class="subscription-list"><span class="event-datetime">{EVENT-DATE-LONG}, {EVENT-TIME-FROM}</span>' .
			'<span class="event-title"><a href="{EVENT-DETAILS-URL}">{EVENT-TITLE}</a></span>' .
			'<span class="subscription-link"><a href="{EVENT-SUBSCRIPTION-URL}" target="_blank" style="margin-left:20px">Anmeldung</a></span></p>';

		foreach ( $event_detail_body as $single_event ) {

			if ( empty( $single_event['subscribe_time'] ) ) {
				$single_event['subscribe_time'] = '2359';
			}

			// Wir machen nur weiter wenn wir entweder kein Anmeldedatum haben, oder es noch nicht vorbei ist
			if ( empty( $single_event['subscribe_date'] ) ||
				$single_event['subscribe_date'] . $single_event['subscribe_time'] . '59' >= $str_datetime_now ) {

			$str_event_link = str_replace( '{%event_id%}', $single_event['event_id'], $arr_options['event_detail_link'] );

				$str_date_from = date_i18n( 'j', strtotime( $single_event['date_from'] ) ) . '. ' .
				$arr_month_kurz[substr( $single_event['date_from'], 5, 2 )] . ' ' .
				substr( $single_event['date_from'], 0, 4 );

			$str_list_link = $str_line_raw;
			$str_list_link = str_replace( '{EVENT-DETAILS-URL}', $str_event_link, $str_list_link );
			$str_list_link = str_replace( '{EVENT-TITLE}', $single_event['title'], $str_list_link );
			$str_list_link = str_replace( '{EVENT-DATE-LONG}', $str_date_from, $str_list_link );
			$str_list_link = str_replace( '{EVENT-TIME-FROM}', $single_event['datetime_text'], $str_list_link );
			$str_list_link = str_replace( '{EVENT-SUBSCRIPTION-URL}', 'https://' . $_SERVER['HTTP_HOST'] .
				'/subscription-form?subs_event_id=' . $single_event['event_id'], $str_list_link );

				echo $str_list_link;
			}
		}
	}
}



/**
 * verowa_subscriptions_backform
 *
 * @param  array  	$arr_formfields
 * @param  array  	$arr_form_data
 *
 * @return string
 */
function verowa_subscriptions_backform( $arr_formfields, $arr_form_data ) {
	$str_return = '';
	$ret_option = get_option( 'verowa_subscriptions_settings' );
	$arr_options = $ret_option != false ? json_decode( $ret_option, true ) : [];
	$arr_formfields_allowed = [];
	$str_rollover = '';
	$str_disabled = '';
	$str_class = 'subscription-back-button-enabled';

	// Array mit allen Feldern welche wieder gefüllt werden sollen.
	$arr_formfields_allowed[0]['subscribe_form']['subscribe_formfields'] = verowa_subscriptions_get_formfields_for_back( $arr_formfields );

	$arr_cf_refined = verowa_subscriptions_form_fields( $arr_formfields_allowed, $arr_options );

	$str_return .= '<form action="https://' . $_SERVER['HTTP_HOST'] . '/subscription-form/?subs_event_id=' .
		$arr_form_data['event_id'] . '"  method="POST">';

	foreach ( $arr_cf_refined as $single_field ) {
		if ( $single_field['type'] != 'checkbox' ) {
			$str_return .= '<input type="hidden" name="' . $single_field['field_name'] . '" ' .
				'value="' . $arr_form_data[$single_field['field_name']] . '"/>';
		} else {
			foreach ( $arr_form_data[$single_field['field_name']] as $single_checkbox ) {
				$str_return .= '<input type="hidden" name="' . $single_field['field_name'] . '[]" ' .
					'value="' . $single_checkbox . '"/>';
			}
		}
	}

	if ( strlen( $str_return ) > 0 && count( $arr_cf_refined ) > 0 ) {
		if ( $_SESSION['back_to_form'] == false ) {
			$str_rollover = $_SESSION['response'];

			$str_class = 'subscription-back-button-disabled';
			$str_disabled = 'disabled';
		}

		$str_return .= '<br /><span title="' . $str_rollover . '"><button name="subscription_back_button" class="' .
			$str_class . '" ' . $str_disabled . ' id="subscription-back-button">' .
			__( 'enter more persons', 'verowa-subscriptions' ) . '</button></span>';
	}

	$str_return .= '</form>';

	return $str_return;
}



/**
 * verowa_subscriptions_get_formfields_for_back
 *
 * @param  array  	$arr_formfields
 *
 * @return array
 */
function verowa_subscriptions_get_formfields_for_back( $arr_formfields ) {
	$arr_formfields_allowed = [];

	foreach ( $arr_formfields as $single_formfield ) {
		if ( false !== strpos( $single_formfield['options'], '==' ) ) {
			$arr_formfields_allowed[] = $single_formfield;
		}
	}

	return $arr_formfields_allowed;
}



/**
 * verowa_separate_subs_label_shorttitle
 *
 * @param  string  	$str_label
 *
 * @return array
 */
function verowa_separate_subs_label_shorttitle( $str_label ) {
	$arr_title_pieces = [];

	// Wenn es einen Shorttitle hat dann hat es am Schluss immer "}}". Nehmen wir weg
	$str_label = substr( $str_label, 0, -2 );

	$arr_title_pieces = explode( '{{', $str_label );

	return $arr_title_pieces;
}