<?php
use Ppg\Verowa_Connect\Verowa_Formfields_Rendering;

add_shortcode( 'verowa_subscriptions_form', 'verowa_subscriptions_form' );


function verowa_subscriptions_form( $atts ) {
	global $wp_session;

	$atts = shortcode_atts(
		array(
		'id' => 0,
		'event_id' => 0,
		'max_count' => 0,
		'max_days' => 0
		),
		$atts,
		'verowa_subscriptions_form'
	);

	// Standard-Daten aus Verowa Connect
	$verowa_api_key = get_option( 'verowa_api_key', false );
	$verowa_member = get_option( 'verowa_instance', false );
	$verowa_api_url = 'https://api.verowa.ch';
	$send_form_method = 'subscribe_to_event';
	$postfix = '';

	$list_id = $atts['id'];
	$event_id = isset($atts['event_id']) ? intval($atts['event_id']) : 0;
	$max_count = isset( $atts['max_count'] ) ? intval( $atts['max_count'] ) : 0;
	$max_days = isset( $atts['max_days'] ) ? intval( $atts['max_days'] ) : 0;

	// prepare API-URLs
	$str_send_url = $verowa_api_url . '/' . $send_form_method;

	// Load options
	$ret_option = get_option( 'verowa_subscriptions_settings' );
	$arr_options = $ret_option != false ? json_decode( $ret_option, true ) : [];
	$arr_options['max_count'] = $max_count;
	$arr_options['max_days'] = $max_days;

	// Damit kann man einfach an verschiedene Stellen die reCaptcha Codes einbauen.
	$is_recaptcha_enable = false;
	if( array_key_exists( 'recaptcha_key_public', $arr_options ) &&
		strlen( $arr_options['recaptcha_key_public'] ) > 0 &&
		array_key_exists( 'recaptcha_key_secret', $arr_options ) &&
		strlen( $arr_options['recaptcha_key_secret'] ) > 0 ) {

		$is_recaptcha_enable = true;
	}

	ob_start ();


	if ( isset( $_SESSION['error'] ) ) {
		foreach ( $_SESSION['error'] as $error ) {
			echo '<p style="color: red;">' . $error . '</p>';
		}
	}

	// Das Formular wurde von der Agenda aufgerufen
	if ( 0 != $event_id ) {
		$arr_event_details = verowa_get_event_content_from_db($event_id);
	} else {
		$current_date = new DateTime();
		$arr_events = verowa_get_event_from_db([ $list_id ], 0, $current_date );
	}


	if ( $is_recaptcha_enable ) {
		echo '<script src="https://www.google.com/recaptcha/api.js?render=' .
			$arr_options['recaptcha_key_public'] . '"></script>
		<script>
			grecaptcha.ready(function() {
				grecaptcha.execute(\''. $arr_options['recaptcha_key_public'] .
					'\', {action: \'login\'}).then(function(token) {
					document.getElementById(\'recaptcha_token\').value = token;
				});
			});
		</script>';
	} // end rechaptcha

	if ( 0 != $event_id ) {
		verowa_subscriptions_print_form( $arr_event_details, $arr_options, $is_recaptcha_enable, $event_id );
	} else {
		verowa_subscriptions_print_links( $arr_events, $arr_options );
	}

	return ob_get_clean ();
}

/**
 * verowa_subscriptions_print_form
 *
 * @param  array   $arr_event_details
 * @param  array   $arr_options
 * @param  bool    $is_recaptcha_enable
 * @param  int 	   $event_id				Es werden die Details dieses Events angezeigt.
 *
 * @return void
 */
function verowa_subscriptions_print_form ( $arr_event_details, $arr_options, $is_recaptcha_enable, $event_id = 0 ) {

	$arr_weekdays = array (
		0 => __( 'Sun', 'verowa-subscriptions' ) . '.',
		1 => __( 'Mon', 'verowa-subscriptions' ) . '.',
		2 => __( 'Tue', 'verowa-subscriptions' ) . '.',
		3 => __( 'Wed', 'verowa-subscriptions' ) . '.',
		4 => __( 'Thu', 'verowa-subscriptions' ) . '.',
		5 => __( 'Fri', 'verowa-subscriptions' ) . '.',
		6 => __( 'Sat', 'verowa-subscriptions' ) . '.'
	);

	$arr_month_kurz = [
		'01' => 'Jan.',
		'02' => 'Feb.',
		'03' => 'März',
		'04' => 'April',
		'05' => 'Mai',
		'06' => 'Juni',
		'07' => 'Juli',
		'08' => 'Aug.',
		'09' => 'Sept.',
		'10' => 'Okt.',
		'11' => 'Nov.',
		'12' => 'Dez.'
	];

	echo '<div class="verowa-contact-tracing big-form">';

	echo '<form action="" method="POST">';

	$str_datetime_now = date_i18n( 'Ymd' ) . date_i18n( 'His' );

	$str_subscribe_date = date_i18n( 'j', strtotime( $arr_event_details['subscribe_date'] ) ) . '. ' .
		$arr_month_kurz[substr( $arr_event_details['subscribe_date'], 4, 2 )];

	$arr_event_content = verowa_subscription_show_events([0 => $arr_event_details], $arr_options, $event_id, $arr_month_kurz );

	$str_subscribe_time = substr( $arr_event_details['subscribe_time'], 0, 2 ) . '.' .
		substr( $arr_event_details['subscribe_time'], 2, 2 );


	$str_anmeldefrist_abgelaufen = '<strong>Die Anmeldefrist ist am ' . $str_subscribe_date;

	if ( !empty( $arr_event_details['subscribe_time'] ) ) {
		$str_anmeldefrist_abgelaufen .= ', ' . $str_subscribe_time . ' Uhr';
	} else {
		$arr_event_details['subscribe_time'] = '2359';
	}

	$str_anmeldefrist_abgelaufen .= ' abgelaufen.</strong><br/><br/>' .
		'<a href="javascript:history.back()">Zurück</a>';

	// Anmeldefrist prüfen (wenn anmeldefrist gesetzt)
	if ( $arr_event_details['subscribe_date'] != '0' ) {
		if ( empty( $arr_event_details['subscribe_date'] ) ||
			$arr_event_details['subscribe_date'] . $arr_event_details['subscribe_time'] . '59' < $str_datetime_now ) {

			$arr_event_content['is_show_form'] = false;

			echo $str_anmeldefrist_abgelaufen;
		}
	}

	$arr_event_content['is_show_form'] = true;


	if ( $arr_event_content['is_show_form'] ) {
		// Event Infos ausgeben
		if ( $arr_event_content['content'] ) {
			echo $arr_event_content['content'];
		}

		// Felder kommen alle in dieses Array
		$arr_formfields = [];
		$str_subs_form_text = isset( $arr_event_details['subscribe_form']['subscribe_form_text'] ) ?
			'<p class="verowa-subs-form-text">' . $arr_event_details['subscribe_form']['subscribe_form_text'] . '</p>' : '';

		$arr_formfields = verowa_subscriptions_form_fields( $arr_event_details['subscribe_form']['subscribe_formfields'],
			$arr_options);

		echo '<div class="ct-form">';
		echo '<div class="ct_block">';

		echo $str_subs_form_text;

		// Ausgabe der Formularfelder
		foreach ( $arr_formfields as $arr_single_formfield ) {

			$obj_formfields = new Verowa_Formfields_Rendering($arr_single_formfield);
			$obj_formfields->print_input_control();
		}

		echo '<div><i>' . __('Fields marked with an asterisk (*) are mandatory.', 'verowa-subscriptions') . '</i></div>';

		echo '</div>'; // ct_block

		echo '<div class="nl_block">';
		echo '<div class="row">';
		echo '<div class="column">';

		echo '<input type="hidden" name="subs_template_id" value="' . $arr_event_details['subscribe_person_id'] . '" /> ';
		echo '<input type="submit" name="submit_button" value="' . __('Send', 'verowa-subscriptions') . '" /> ';

		echo '</div>';
		echo '</div>'; // end Row
		echo '</div>';
		echo '</div>'; // end .nl_subscribe
		wp_nonce_field( 'send_infos', 'send_infos' );
		if( $is_recaptcha_enable ) {
			echo '<input type="hidden" name="recaptcha_response" id="recaptchaResponse" />';
			echo ' <input type="hidden" name="recaptcha_token" id="recaptcha_token" />';
		}

		echo '</form>';
		echo '</div>';
	} // end if Show Form
}

?>