<?php
/**
 * Plugin Name: Verowa Connect
 * Plugin URI: https://www.verowa.ch
 * Description: Include your Verowa data seamlessly into your WordPress project!
 * Author: Picture-Planet GmbH
 * Version: 2.6.0
 * Requires at least: 4.2
 * Requires PHP: 5.6
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: verowa-connect
 * Domain Path: /languages
 */


/*
This Plugin is a direct dependency of verowa.ch. You need to have a chruch Account on Verowa to use it.

Diese Datei lädt die ganzen Abhängigkeiten des Plugins.
*/

define( 'VEROWA_DEBUG', false );
define( 'SUPPORT_MAIL', 'm.pfister@picture-planet.ch' );

include 'log/verowa-connect-debugger.php';

// Standardseiten und Hilfsseiten
include 'general/verowa-general-functions.php';
include 'general/verowa-admin-page.php';
include 'general/verowa-activate-config.php';
include 'general/verowa-api-calls.php';
include 'general/verowa-formfields-rendering.php';
include 'general/verowa-send-mail.php';
include 'general/verowa-templates_list.php';

// Module, um virtuelle Seiten zu generieren
include 'general/verowa-post-generation.php';

// Modul, um einen einfachen Zurück Link anzuzeigen.
include 'general/verowa-back-link.php';

// Admin Pages
include 'admin/verowa_templates_edit.php';


// Event-Module
include 'events/verowa-fct-event.php';
include 'events/verowa-agenda-shortcode.php';
include 'events/verowa-agenda-dynamic.php';
include 'events/verowa-single-event-page.php';
include 'events/verowa-event-filter.php';
include 'events/verowa-event-filter-widget.php';
include 'events/verowa-agenda-dropdowns.php';
include 'events/verowa-event-list-shortcode.php';
include 'events/verowa-event-list-shortcode-dynamic.php';
include 'events/verowa-event-list-widget.php';
include 'events/verowa-assign-list.php';
include 'events/verowa-layer-functions.php';
include 'events/verowa-import-layers.php';

// Personen-Module
include 'persons/verowa-single-person-page.php';
include 'persons/verowa-assign-persons.php';
include 'persons/verowa-show-persons-shortcode.php';
include 'persons/verowa-show-persons-widget.php';

// Diverses
include 'general/verowa_update_controller.php';
include 'general/verowa-add-pages-to-search.php';
include 'general/verowa-update-cron.php';
include 'rosters/verowa-rosters.php';
include 'general/rest-routes.php';

// Renting
include 'renting/fct-verowa-renting.php';
include 'renting/verowa-renting-room-res.php';
include 'renting/verowa-renting-submit.php';
include 'renting/verowa-renting-response.php';
include 'renting/verowa-renting-validation.php';

// Verowa Subscriptions
include 'subscriptions/verowa-subscriptions.php';

add_action( 'admin_menu', 'add_verowa_credentials_submenu_pages' );
add_action( 'wp_enqueue_scripts', 'add_verowa_styles' );
add_action( 'admin_enqueue_scripts', 'add_verowa_admin_scripts' );

function add_verowa_credentials_submenu_pages() {
	add_submenu_page( 'options-general.php', __( 'Verowa options', 'verowa-connect' ),
		__( 'Verowa options', 'verowa-connect' ) , 'switch_themes', 'verowa-options',
		'verowa_options_configuration_page' );

	add_submenu_page( 'options-general.php', __( 'Verowa: Agenda filter', 'verowa-connect' ),
		__( 'Verowa: Agenda filter', 'verowa-connect' ) , 'switch_themes',
		'verowa-options-dropdowns', 'verowa_dropdown_configuration_page' );

	add_submenu_page( 'options-general.php', __( 'Verowa templates', 'verowa-connect' ),
		__( 'Verowa templates', 'verowa-connect' ) , 'switch_themes', 'verowa-options-templates',
		'verowa_templates_configuration_page' );
}



function add_verowa_styles() {

	// Later configurable via backend
	$min_extension = '.min';

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'jquery-ui-datepicker' );
	wp_enqueue_style( 'verowa-styles', plugins_url( 'style.css', __FILE__ ), array(), '1.0' );
	wp_enqueue_style( 'verowa-datepicker-style', plugins_url( 'js/jquery-ui' . $min_extension . '.css', __FILE__ ), array(), '1.11.4' );
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_script( 'verowa-connect-script', plugins_url( 'js/verowa-connect' . $min_extension . '.js', __FILE__ ),
		[], true );

	// Wir binden die Komponenten für die Agenda überall ein, damit sie schon geladen sind, wenn man darauf zugreift.
	wp_enqueue_style( 'dynamic-agenda-css', plugins_url( 'js/dynamic_agenda' . $min_extension . '.css', __FILE__ ) );
	wp_enqueue_script( 'dynamic-agenda', plugins_url( 'js/dynamic_agenda_2021' . $min_extension . '.js', __FILE__ ) );
	// minified Versionen werden nicht direkt geändert
}



function add_verowa_admin_scripts() {
	wp_enqueue_script(
		'verowa-import-layers-handler',
		plugins_url(
			'js/verowa-import-layers-handler.js',
			__FILE__
		),
		array(
			'jquery'
		),
		'1.0.0',
		true
	);

	// Erstellen des ajax-objects für das importieren der Layers mittel AJAX
	wp_localize_script(
		'verowa-import-layers-handler',
		'verowa_import_layers_handler_obj',
		array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'nonce'    => wp_create_nonce( 'verowa_import_layers' ),
		)
	);

	$arr_js_translation = array(
		'import_layers_success' => __( 'The layers were created as pages.', 'verowa-connect' )
	);

	wp_localize_script( 'verowa-import-layers-handler', 'verowa_layers_translations', $arr_js_translation );
	wp_enqueue_style('admin-styles', plugins_url( 'css/backend_style.css', __FILE__));

	$cm_settings['codeEditor'] = wp_enqueue_code_editor(array('type' => 'text/html'));
	wp_localize_script('jquery', 'cm_settings', $cm_settings);

	wp_enqueue_script('wp-theme-plugin-editor');
	wp_enqueue_style('wp-codemirror');
}

// Regel für die Personen und Eventdetails hinzufügen. flush_rewrite_rules muss aufgerufen werden damit die Regel in der DB gespeichert wird
add_action( 'init', function() {
	global $wp_rewrite;

	add_rewrite_rule(
		'^(veranstaltung|person)/([0-9]+)/?$',
		'index.php?pagename=$matches[1]&verowa_id=$matches[2]',
		'top'
	);

	// flush_rewrite_rules ist recht zeitaufwendig. Deswegen machen wir es nur wenn die Regel noch nicht drin ist.
	if ( $wp_rewrite->rules!= null && !array_key_exists( '^(veranstaltung|person)/([0-9]+)/?$', $wp_rewrite->rules ) ) {
		flush_rewrite_rules( false );
	}
});

// verowa_id für die Details in die query_vars eintragen weil man in WP nicht auf normale $_GET Parameter zugreifen kann
add_filter( 'query_vars', function( $vars ) {
    $vars[] = "verowa_id";
    return $vars;
});

// Funktionen, die bei der ersten Aktivierung ausgeführt werden
register_activation_hook( __FILE__, 'verowa_plugin_activate' );
register_deactivation_hook( __FILE__, 'verowa_plugin_deactivate' );

add_action( 'init', 'verowaconnect_plugin_init' );

/**
 * Change-log
 * MPf: Prüfungen auf den Session Status eingefügt
 */
function verowaconnect_plugin_init() {
	$int_session_status = session_status();
	if ( isset( $_COOKIE["PHPSESSID"] ) ) {
		if(PHP_SESSION_NONE == $int_session_status &&
		   PHP_SESSION_DISABLED != $int_session_status)
		{
			session_id( $_COOKIE["PHPSESSID"] );

			session_start( [
				'cookie_lifetime' => 86400,
			] );
		}
	}

	if ( PHP_SESSION_DISABLED != $int_session_status && session_id() == "" ) {
		session_start( [
			'cookie_lifetime' => 86400,
		] );

		session_regenerate_id( true );
	}

	load_plugin_textdomain( 'verowa-connect' );
}
?>